{
    "$graph": [
        {
            "class": "ExpressionTool",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "expression": " ${ inputs.main_file.secondaryFiles = Array.isArray(inputs.secondary_files) ? inputs.secondary_files : [inputs.secondary_files];\nreturn { \"file_with_secondary_files\": inputs.main_file } } ",
            "doc": "Step to put secondary input files in the same folder as a main file",
            "inputs": [
                {
                    "type": "File",
                    "id": "#combine_files.cwl/main_file"
                },
                {
                    "type": [
                        "File",
                        {
                            "type": "array",
                            "items": "File"
                        }
                    ],
                    "id": "#combine_files.cwl/secondary_files"
                }
            ],
            "id": "#combine_files.cwl",
            "outputs": [
                {
                    "type": "File",
                    "id": "#combine_files.cwl/file_with_secondary_files"
                }
            ]
        },
        {
            "class": "ExpressionTool",
            "doc": "Transpose a given array",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "expression": "$({'flattened_array': [].concat.apply([], inputs['2d-array'])})",
            "inputs": [
                {
                    "id": "#flatten-array-file.cwl/2d-array",
                    "type": {
                        "type": "array",
                        "items": {
                            "type": "array",
                            "items": "File"
                        }
                    }
                }
            ],
            "outputs": [
                {
                    "id": "#flatten-array-file.cwl/flattened_array",
                    "type": {
                        "type": "array",
                        "items": "File"
                    }
                }
            ],
            "id": "#flatten-array-file.cwl"
        },
        {
            "class": "CommandLineTool",
            "doc": "Transpose a given matrix",
            "requirements": [
                {
                    "listing": [
                        {
                            "entryname": "inputs.json",
                            "entry": "{\"array\": $(inputs.array)}"
                        }
                    ],
                    "class": "InitialWorkDirRequirement"
                }
            ],
            "baseCommand": [
                "python",
                "-c",
                "import json\n\nwith open(\"inputs.json\") as inputs_file:\n  matrix = json.load(inputs_file)[\"array\"]\n\nwith open(\"cwl.output.json\", \"w\") as output_file:\n  output_file.write(json.dumps({\n    \"transposed_array\": list(zip(*matrix))\n  }))\n"
            ],
            "inputs": [
                {
                    "id": "#matrix_transpose.cwl/array",
                    "type": {
                        "type": "array",
                        "items": {
                            "type": "array",
                            "items": "File"
                        }
                    }
                }
            ],
            "outputs": [
                {
                    "id": "#matrix_transpose.cwl/transposed_array",
                    "type": {
                        "type": "array",
                        "items": {
                            "type": "array",
                            "items": "File"
                        }
                    }
                }
            ],
            "id": "#matrix_transpose.cwl"
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mercury/bcftools-1.6:v2"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-a"
                    },
                    "doc": "First coordinate of the next file can precede last record of the current file.",
                    "id": "#bcftools-concat.cwl/allow_overlaps"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-c"
                    },
                    "doc": "Do not output PS tag at each site, only at the start of a new phase set block.",
                    "id": "#bcftools-concat.cwl/compact_PS"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-f"
                    },
                    "doc": "Read the list of files from a file.\n",
                    "id": "#bcftools-concat.cwl/file_list"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-o"
                    },
                    "doc": "Write output to a file [standard output]\n",
                    "id": "#bcftools-concat.cwl/filename"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-l"
                    },
                    "doc": "Ligate phased VCFs by matching phase at overlapping haplotypes",
                    "id": "#bcftools-concat.cwl/ligate"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-q"
                    },
                    "doc": "Break phase set if phasing quality is lower than <int> [30]",
                    "id": "#bcftools-concat.cwl/min_PQ"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "separate": false,
                        "prefix": "-O"
                    },
                    "doc": "<b|u|z|v> b: compressed BCF, u: uncompressed BCF, z: compressed VCF, v: uncompressed VCF [v]",
                    "id": "#bcftools-concat.cwl/output_type"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-r"
                    },
                    "doc": "Restrict to comma-separated list of regions\n",
                    "id": "#bcftools-concat.cwl/regions"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-R"
                    },
                    "doc": "Restrict to regions listed in a file",
                    "id": "#bcftools-concat.cwl/regions_file"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-D"
                    },
                    "doc": "Alias for -d/--rm-dups none\n",
                    "id": "#bcftools-concat.cwl/remove_duplicates"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-d"
                    },
                    "doc": "Output duplicate records present in multiple files only once: <snps|indels|both|all|none>",
                    "id": "#bcftools-concat.cwl/rm_dups"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--threads"
                    },
                    "doc": "Number of extra output compression threads [0]",
                    "id": "#bcftools-concat.cwl/threads"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "inputBinding": {
                        "position": 2
                    },
                    "id": "#bcftools-concat.cwl/vcfs"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.filename)"
                    },
                    "id": "#bcftools-concat.cwl/output"
                }
            ],
            "baseCommand": [
                "bcftools",
                "concat"
            ],
            "doc": "About:   Concatenate or combine VCF/BCF files. All source files must have the same sample\n         columns appearing in the same order. The program can be used, for example, to\n         concatenate chromosome VCFs into one VCF, or combine a SNP VCF and an indel\n         VCF into one. The input files must be sorted by chr and position. The files\n         must be given in the correct order to produce sorted VCF on output unless\n         the -a, --allow-overlaps option is specified.\n\nUsage:   bcftools concat [options] <A.vcf.gz> [<B.vcf.gz> [...]]\n",
            "id": "#bcftools-concat.cwl"
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mercury/bcftools-1.6:v2"
                }
            ],
            "inputs": [
                {
                    "type": "string",
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-o",
                        "valueFrom": "$(runtime.outdir)/$(self)"
                    },
                    "id": "#bcftools-index-tbi.cwl/output_filename"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--threads"
                    },
                    "doc": "Number of extra output compression threads [0]",
                    "id": "#bcftools-index-tbi.cwl/threads"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 2
                    },
                    "id": "#bcftools-index-tbi.cwl/vcf"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.output_filename)"
                    },
                    "id": "#bcftools-index-tbi.cwl/index"
                }
            ],
            "baseCommand": [
                "bcftools",
                "index",
                "-t"
            ],
            "doc": "About: Creates index for bgzip compressed VCF/BCF files for random access\n       using TBI (tabix index) index files, which support chromosome\n       lengths up to 2^29.\n",
            "id": "#bcftools-index-tbi.cwl"
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mercury/bcftools-1.6:v2"
                }
            ],
            "inputs": [
                {
                    "type": "string",
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-o",
                        "valueFrom": "$(runtime.outdir)/$(self)"
                    },
                    "id": "#bcftools-index.cwl/output_filename"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-t"
                    },
                    "doc": "Produce .tbi (instead of .csi) index",
                    "id": "#bcftools-index.cwl/tbi_output"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--threads"
                    },
                    "doc": "Number of extra output compression threads [0]",
                    "id": "#bcftools-index.cwl/threads"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 2
                    },
                    "id": "#bcftools-index.cwl/vcf"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.output_filename)"
                    },
                    "id": "#bcftools-index.cwl/index"
                }
            ],
            "baseCommand": [
                "bcftools",
                "index"
            ],
            "doc": "About: Creates index for bgzip compressed VCF/BCF files for random access.\n       CSI (coordinate-sorted index) is created by default. The CSI format\n       supports indexing of chromosomes up to length 2^31. TBI (tabix index)\n       index files, which support chromosome lengths up to 2^29, can be\n       created by using the -t/--tbi option or using the tabix program\n       packaged with htslib. When loading an index file, bcftools will try\n       the CSI first and then the TBI.\n",
            "id": "#bcftools-index.cwl"
        },
        {
            "class": "CommandLineTool",
            "hints": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "dukegcb/bedtools"
                }
            ],
            "inputs": [
                {
                    "id": "#bedtools-intersect.cwl/b",
                    "type": "File",
                    "doc": "<bed/gff/vcf/bam>",
                    "inputBinding": {
                        "position": 4,
                        "prefix": "-b"
                    }
                },
                {
                    "id": "#bedtools-intersect.cwl/a",
                    "type": "File",
                    "doc": "Input <bed/gff/vcf/bam> file",
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-a"
                    }
                },
                {
                    "id": "#bedtools-intersect.cwl/wa",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "doc": "Write the original entry in A for each overlap.\n",
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-wa"
                    }
                },
                {
                    "id": "#bedtools-intersect.cwl/wb",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "doc": "Write the original entry in B for each overlap.\n- Useful for knowing _what_ A overlaps. Restricted by -f and -r.\n",
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-wb"
                    }
                },
                {
                    "id": "#bedtools-intersect.cwl/loj",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "doc": "Perform a \"left outer join\". That is, for each feature in A\nreport each overlap with B.  If no overlaps are found,\nreport a NULL feature for B.\n",
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-loj"
                    }
                },
                {
                    "id": "#bedtools-intersect.cwl/wo",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "doc": "Write the original A and B entries plus the number of base\npairs of overlap between the two features.\n- Overlaps restricted by -f and -r.\nOnly A features with overlap are reported.\n",
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-wo"
                    }
                },
                {
                    "id": "#bedtools-intersect.cwl/wao",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "doc": "Write the original A and B entries plus the number of base\npairs of overlap between the two features.\n- Overlapping features restricted by -f and -r.\nHowever, A features w/o overlap are also reported\nwith a NULL B feature and overlap = 0.\n",
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-wao"
                    }
                },
                {
                    "id": "#bedtools-intersect.cwl/u",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "doc": "Write the original A entry _once_ if _any_ overlaps found in B.\n- In other words, just report the fact >=1 hit was found.\n- Overlaps restricted by -f and -r.\n",
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-u"
                    }
                },
                {
                    "id": "#bedtools-intersect.cwl/c",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "doc": "For each entry in A, report the number of overlaps with B.\n- Reports 0 for A entries that have no overlap with B.\n- Overlaps restricted by -f and -r.\n",
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-c"
                    }
                },
                {
                    "id": "#bedtools-intersect.cwl/v",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "doc": "Only report those entries in A that have _no overlaps_ with B.\n- Similar to \"grep -v\" (an homage).\n",
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-v"
                    }
                },
                {
                    "id": "#bedtools-intersect.cwl/ubam",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "doc": "Write uncompressed BAM output. Default writes compressed BAM.\n",
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-ubam"
                    }
                },
                {
                    "id": "#bedtools-intersect.cwl/s",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "doc": "Require same strandedness.  That is, only report hits in B\nthat overlap A on the _same_ strand.\n- By default, overlaps are reported without respect to strand.\n",
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-s"
                    }
                },
                {
                    "id": "#bedtools-intersect.cwl/S",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "doc": "Require different strandedness.  That is, only report hits in B\nthat overlap A on the _opposite_ strand.\n- By default, overlaps are reported without respect to strand.\n",
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-S"
                    }
                },
                {
                    "id": "#bedtools-intersect.cwl/f",
                    "type": [
                        "null",
                        "float"
                    ],
                    "doc": "Minimum overlap required as a fraction of A.\n- Default is 1E-9 (i.e., 1bp).\n- FLOAT (e.g. 0.50)\n",
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-f"
                    }
                },
                {
                    "id": "#bedtools-intersect.cwl/F",
                    "type": [
                        "null",
                        "float"
                    ],
                    "doc": "Minimum overlap required as a fraction of B.\n- Default is 1E-9 (i.e., 1bp).\n- FLOAT (e.g. 0.50)\n",
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-F"
                    }
                },
                {
                    "id": "#bedtools-intersect.cwl/r",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "doc": "Require that the fraction overlap be reciprocal for A AND B.\n- In other words, if -f is 0.90 and -r is used, this requires\nthat B overlap 90 percent of A and A _also_ overlaps 90 percent of B.\n",
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-r"
                    }
                },
                {
                    "id": "#bedtools-intersect.cwl/e",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "doc": "Require that the minimum fraction be satisfied for A OR B.\n- In other words, if -e is used with -f 0.90 and -F 0.10 this requires\nthat either 90 percent of A is covered OR 10 percent of  B is covered.\nWithout -e, both fractions would have to be satisfied.\n",
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-e"
                    }
                },
                {
                    "id": "#bedtools-intersect.cwl/split",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "doc": "Treat \"split\" BAM or BED12 entries as distinct BED intervals.\n",
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-split"
                    }
                },
                {
                    "id": "#bedtools-intersect.cwl/g",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "doc": "Provide a genome file to enforce consistent chromosome sort order\nacross input files. Only applies when used with -sorted option.\n",
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-g"
                    }
                },
                {
                    "id": "#bedtools-intersect.cwl/nonamecheck",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "doc": "For sorted data, don't throw an error if the file has different naming conventions\nfor the same chromosome. ex. \"chr1\" vs \"chr01\".\n",
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-nonamecheck"
                    }
                },
                {
                    "id": "#bedtools-intersect.cwl/sorted",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "doc": "Use the \"chromsweep\" algorithm for sorted (-k1,1 -k2,2n) input.\n",
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-sorted"
                    }
                },
                {
                    "id": "#bedtools-intersect.cwl/names",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "doc": "When using multiple databases, provide an alias for each that\nwill appear instead of a fileId when also printing the DB record.\n",
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-names"
                    }
                },
                {
                    "id": "#bedtools-intersect.cwl/filenames",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "doc": "When using multiple databases, show each complete filename\ninstead of a fileId when also printing the DB record.\n",
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-filenames"
                    }
                },
                {
                    "id": "#bedtools-intersect.cwl/sortout",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "doc": "When using multiple databases, sort the output DB hits\nfor each record.\n",
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-sortout"
                    }
                },
                {
                    "id": "#bedtools-intersect.cwl/bed",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "doc": "If using BAM input, write output as BED.\n",
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-bed"
                    }
                },
                {
                    "id": "#bedtools-intersect.cwl/header",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "doc": "Print the header from the A file prior to results.\n",
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-header"
                    }
                },
                {
                    "id": "#bedtools-intersect.cwl/nobuf",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "doc": "Disable buffered output. Using this option will cause each line\nof output to be printed as it is generated, rather than saved\nin a buffer. This will make printing large output files\nnoticeably slower, but can be useful in conjunction with\nother software tools and scripts that need to process one\nline of bedtools output at a time.\n",
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-nobuf"
                    }
                },
                {
                    "id": "#bedtools-intersect.cwl/iobuf",
                    "type": [
                        "null",
                        "int"
                    ],
                    "doc": "Specify amount of memory to use for input buffer.\nTakes an integer argument. Optional suffixes K/M/G supported.\nNote: currently has no effect with compressed files.\n",
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-iobuf"
                    }
                },
                {
                    "id": "#bedtools-intersect.cwl/output",
                    "type": "string",
                    "default": "out.bed"
                }
            ],
            "outputs": [
                {
                    "id": "#bedtools-intersect.cwl/intersect_output",
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.output)"
                    }
                }
            ],
            "stdout": "$(inputs.output)",
            "baseCommand": [
                "bedtools",
                "intersect"
            ],
            "doc": "Tool:    bedtools intersect (aka intersectBed)\nVersion: v2.25.0\nSummary: Report overlaps between two feature files.\n\nUsage:   bedtools intersect [OPTIONS] -a <bed/gff/vcf/bam> -b <bed/gff/vcf/bam>\n\n\tNote: -b may be followed with multiple databases and/or \n\twildcard (*) character(s). \nOptions: \n\t-wa\tWrite the original entry in A for each overlap.\n\n\t-wb\tWrite the original entry in B for each overlap.\n\t\t- Useful for knowing _what_ A overlaps. Restricted by -f and -r.\n\n\t-loj\tPerform a \"left outer join\". That is, for each feature in A\n\t\treport each overlap with B.  If no overlaps are found, \n\t\treport a NULL feature for B.\n\n\t-wo\tWrite the original A and B entries plus the number of base\n\t\tpairs of overlap between the two features.\n\t\t- Overlaps restricted by -f and -r.\n\t\t  Only A features with overlap are reported.\n\n\t-wao\tWrite the original A and B entries plus the number of base\n\t\tpairs of overlap between the two features.\n\t\t- Overlapping features restricted by -f and -r.\n\t\t  However, A features w/o overlap are also reported\n\t\t  with a NULL B feature and overlap = 0.\n\n\t-u\tWrite the original A entry _once_ if _any_ overlaps found in B.\n\t\t- In other words, just report the fact >=1 hit was found.\n\t\t- Overlaps restricted by -f and -r.\n\n\t-c\tFor each entry in A, report the number of overlaps with B.\n\t\t- Reports 0 for A entries that have no overlap with B.\n\t\t- Overlaps restricted by -f and -r.\n\n\t-v\tOnly report those entries in A that have _no overlaps_ with B.\n\t\t- Similar to \"grep -v\" (an homage).\n\n\t-ubam\tWrite uncompressed BAM output. Default writes compressed BAM.\n\n\t-s\tRequire same strandedness.  That is, only report hits in B\n\t\tthat overlap A on the _same_ strand.\n\t\t- By default, overlaps are reported without respect to strand.\n\n\t-S\tRequire different strandedness.  That is, only report hits in B\n\t\tthat overlap A on the _opposite_ strand.\n\t\t- By default, overlaps are reported without respect to strand.\n\n\t-f\tMinimum overlap required as a fraction of A.\n\t\t- Default is 1E-9 (i.e., 1bp).\n\t\t- FLOAT (e.g. 0.50)\n\n\t-F\tMinimum overlap required as a fraction of B.\n\t\t- Default is 1E-9 (i.e., 1bp).\n\t\t- FLOAT (e.g. 0.50)\n\n\t-r\tRequire that the fraction overlap be reciprocal for A AND B.\n\t\t- In other words, if -f is 0.90 and -r is used, this requires\n\t\t  that B overlap 90 percent of A and A _also_ overlaps 90 percent of B.\n\n\t-e\tRequire that the minimum fraction be satisfied for A OR B.\n\t\t- In other words, if -e is used with -f 0.90 and -F 0.10 this requires\n\t\t  that either 90 percent of A is covered OR 10 percent of  B is covered.\n\t\t  Without -e, both fractions would have to be satisfied.\n\n\t-split\tTreat \"split\" BAM or BED12 entries as distinct BED intervals.\n\n\t-g\tProvide a genome file to enforce consistent chromosome sort order\n\t\tacross input files. Only applies when used with -sorted option.\n\n\t-nonamecheck\tFor sorted data, don't throw an error if the file has different naming conventions\n\t\t\tfor the same chromosome. ex. \"chr1\" vs \"chr01\".\n\n\t-sorted\tUse the \"chromsweep\" algorithm for sorted (-k1,1 -k2,2n) input.\n\n\t-names\tWhen using multiple databases, provide an alias for each that\n\t\twill appear instead of a fileId when also printing the DB record.\n\n\t-filenames\tWhen using multiple databases, show each complete filename\n\t\t\tinstead of a fileId when also printing the DB record.\n\n\t-sortout\tWhen using multiple databases, sort the output DB hits\n\t\t\tfor each record.\n\n\t-bed\tIf using BAM input, write output as BED.\n\n\t-header\tPrint the header from the A file prior to results.\n\n\t-nobuf\tDisable buffered output. Using this option will cause each line\n\t\tof output to be printed as it is generated, rather than saved\n\t\tin a buffer. This will make printing large output files \n\t\tnoticeably slower, but can be useful in conjunction with\n\t\tother software tools and scripts that need to process one\n\t\tline of bedtools output at a time.\n\n\t-iobuf\tSpecify amount of memory to use for input buffer.\n\t\tTakes an integer argument. Optional suffixes K/M/G supported.\n\t\tNote: currently has no effect with compressed files.\n\nNotes: \n\t(1) When a BAM file is used for the A file, the alignment is retained if overlaps exist,\n\tand exlcuded if an overlap cannot be found.  If multiple overlaps exist, they are not\n\treported, as we are only testing for one or more overlaps.",
            "id": "#bedtools-intersect.cwl"
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mercury/capmq:v1"
                },
                {
                    "class": "EnvVarRequirement",
                    "envDef": [
                        {
                            "envValue": "$(inputs.ref_path_dir.path)/%2s/%2s/%s",
                            "envName": "REF_PATH"
                        }
                    ]
                },
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "baseCommand": [
                "capmq"
            ],
            "inputs": [
                {
                    "id": "#capmq.cwl/ref_path_dir",
                    "type": [
                        "null",
                        "Directory"
                    ]
                },
                {
                    "id": "#capmq.cwl/input_file",
                    "inputBinding": {
                        "position": 1
                    },
                    "type": "File"
                },
                {
                    "id": "#capmq.cwl/output_filename",
                    "default": "",
                    "inputBinding": {
                        "position": 2,
                        "valueFrom": "$(self || inputs.input_file.basename)"
                    },
                    "type": "string"
                },
                {
                    "id": "#capmq.cwl/MAPQ_cap",
                    "inputBinding": {
                        "prefix": "-C"
                    },
                    "type": [
                        "null",
                        "int"
                    ],
                    "doc": "Cap MAPQ at max (default: 255)"
                },
                {
                    "id": "#capmq.cwl/dont_store_in_omi_aux_tag",
                    "inputBinding": {
                        "prefix": "-S"
                    },
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "doc": "Do not store original MAPQ in om:i aux tag"
                },
                {
                    "id": "#capmq.cwl/restore_mapq",
                    "inputBinding": {
                        "prefix": "-r"
                    },
                    "doc": "Restore original MAPQ from om:i aux tag",
                    "type": [
                        "null",
                        "boolean"
                    ]
                },
                {
                    "id": "#capmq.cwl/verbose",
                    "inputBinding": {
                        "prefix": "-v"
                    },
                    "doc": "verbose",
                    "type": [
                        "null",
                        "boolean"
                    ]
                },
                {
                    "id": "#capmq.cwl/readgroup_caps",
                    "inputBinding": {
                        "prefix": "-g"
                    },
                    "doc": "Cap MAPQ for read group IDs.\nThis can be specified more than once, and if specified\nwill override the -C paramater for those read groups.\n",
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": {
                                "type": "record",
                                "fields": [
                                    {
                                        "name": "#capmq.cwl/readgroup_caps/read_group",
                                        "type": "string"
                                    },
                                    {
                                        "name": "#capmq.cwl/readgroup_caps/cap_value",
                                        "type": "float"
                                    }
                                ]
                            },
                            "inputBinding": {
                                "valueFrom": "$(self.map(function (item){return item.read_group + \":\" + item.cap_value}))"
                            }
                        }
                    ]
                },
                {
                    "id": "#capmq.cwl/readgroup_caps_file",
                    "inputBinding": {
                        "prefix": "-G"
                    },
                    "doc": "As for -g, but group ID/max value pairs are read from a tab delimited file.",
                    "type": [
                        "null",
                        "File"
                    ]
                },
                {
                    "id": "#capmq.cwl/use_max_contamination",
                    "inputBinding": {
                        "prefix": "-f"
                    },
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "doc": "The values to -C, -g or in the file specified with -G\nare NOT maximum MAPQ scores, but estimated fraction of\ncontamination (e) from which to calculate the maximum\nMAPQ as int(10*log10(1/e)).\n"
                },
                {
                    "id": "#capmq.cwl/minimum_MAPQ",
                    "inputBinding": {
                        "prefix": "-m"
                    },
                    "type": [
                        "null",
                        "int"
                    ],
                    "doc": "Minimum MAPQ. Do not set the calculated quality\nto less than this value. Only used with -f\n(default: 0)\n"
                },
                {
                    "id": "#capmq.cwl/htslib_input_options",
                    "type": [
                        "string",
                        "null"
                    ],
                    "inputBinding": {
                        "prefix": "-I"
                    },
                    "doc": "Input format and format-options.\nThis is passed in through a object which has fields of the options set\nplus a compulsory file_format to set the file format.\n"
                },
                {
                    "id": "#capmq.cwl/htslib_output_options",
                    "type": [
                        "string",
                        "null"
                    ],
                    "inputBinding": {
                        "prefix": "-O"
                    },
                    "doc": "Output format and format-options [SAM].\nThis is passed in through a object which has fields of the options set\nplus a compulsory file_format to set the file format.\n"
                }
            ],
            "outputs": [
                {
                    "id": "#capmq.cwl/capped_file",
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.output_filename || inputs.input_file.basename)"
                    }
                }
            ],
            "id": "#capmq.cwl"
        },
        {
            "class": "CommandLineTool",
            "baseCommand": [
                "python",
                "/dict_to_interval_list.py"
            ],
            "hints": [
                {
                    "dockerPull": "mercury/dict-to-interval-list:v1",
                    "class": "DockerRequirement"
                }
            ],
            "arguments": [
                {
                    "prefix": "--output_dir",
                    "valueFrom": "$(runtime.outdir)"
                }
            ],
            "inputs": [
                {
                    "id": "#dict_to_interval_list.cwl/dictionary",
                    "type": "File",
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--path",
                        "itemSeparator": " "
                    }
                }
            ],
            "outputs": [
                {
                    "id": "#dict_to_interval_list.cwl/interval_list",
                    "type": "File",
                    "outputBinding": {
                        "glob": "*.interval_list"
                    }
                }
            ],
            "id": "#dict_to_interval_list.cwl"
        },
        {
            "class": "CommandLineTool",
            "baseCommand": [
                "bash",
                "-c"
            ],
            "requirements": [
                {
                    "dockerPull": "ubuntu:14.04",
                    "class": "DockerRequirement"
                }
            ],
            "arguments": [
                "cat \"$(inputs.interval_list.path)\" | awk  'BEGIN {\n  FS=\"\\\\t\";\n} /^@/ || $1~/$(inputs.chromosome_regex)/ {\n  print;\n}' > $(inputs.output_filename)\n"
            ],
            "inputs": [
                {
                    "type": "string",
                    "id": "#filter_interval_list.cwl/chromosome_regex"
                },
                {
                    "type": "File",
                    "id": "#filter_interval_list.cwl/interval_list"
                },
                {
                    "default": "filtered_interval_list.interval_list",
                    "type": "string",
                    "id": "#filter_interval_list.cwl/output_filename"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.output_filename)"
                    },
                    "id": "#filter_interval_list.cwl/output"
                }
            ],
            "id": "#filter_interval_list.cwl"
        },
        {
            "id": "#GenomicsDBImport.cwl",
            "baseCommand": [
                "python3",
                "/gatk-tmpdir-output-wrapper.py",
                "[\"--genomicsdb-workspace-path\"]",
                "[\"-Xmx4g\",\"-Xms4g\"]",
                "GenomicsDBImport"
            ],
            "class": "CommandLineTool",
            "doc": "Import single-sample GVCFs into GenomicsDB before joint genotyping.\n\n <p>The GATK4 Best Practice Workflow for SNP and Indel calling uses GenomicsDBImport to merge GVCFs from multiple samples.\n GenomicsDBImport offers the same functionality as CombineGVCFs and comes from the <i>Intel-Broad Center for Genomics</i>.\n The datastore transposes sample-centric variant information across genomic loci to make data more accessible to tools.\n </p>\n\n <p>To query the contents of the GenomicsDB datastore, use\n <a href='https://software.broadinstitute.org/gatk/documentation/tooldocs/current/org_broadinstitute_gatk_tools_walkers_variantutils_SelectVariants.php'>SelectVariants</a>.\n See <a href='https://software.broadinstitute.org/gatk/documentation/article?id=10061'>Tutorial#10061</a> to get started. </p>\n\n <p>Details on GenomicsDB are at\n <a href='https://github.com/Intel-HLS/GenomicsDB/wiki'>https://github.com/Intel-HLS/GenomicsDB/wiki</a>.\n In brief, GenomicsDB is a utility built on top of TileDB. TileDB is a format for efficiently representing sparse data.\n Genomics data is typically sparse in that each sample has few variants with respect to the entire reference genome.\n GenomicsDB contains code to specialize TileDB for genomics applications, such as VCF parsing and INFO field annotation\n calculation.\n </p>\n\n <h3>Input</h3>\n <p>\n One or more GVCFs produced by in HaplotypeCaller with the `-ERC GVCF` or `-ERC BP_RESOLUTION` settings, containing\n the samples to joint-genotype.\n </p>\n\n <h3>Output</h3>\n <p>\n A GenomicsDB workspace\n </p>\n\n  <h3>Usage examples</h3>\n\n  Provide each sample GVCF separately.\n  <pre>\n    gatk --java-options \"-Xmx4g -Xms4g\" GenomicsDBImport \\\n      -V data/gvcfs/mother.g.vcf.gz \\\n      -V data/gvcfs/father.g.vcf.gz \\\n      -V data/gvcfs/son.g.vcf.gz \\\n      --genomicsdb-workspace-path my_database \\\n      -L 20\n  </pre>\n\n  Provide sample GVCFs in a map file.\n\n  <pre>\n    gatk --java-options \"-Xmx4g -Xms4g\" \\\n       GenomicsDBImport \\\n       --genomicsdb-workspace-path my_database \\\n       --batch-size 50 \\\n       -L chr1:1000-10000 \\\n       --sample-name-map cohort.sample_map \\\n       --reader-threads 5\n  </pre>\n\n  The sample map is a tab-delimited text file with sample_name--tab--path_to_sample_vcf per line. Using a sample map\n  saves the tool from having to download the GVCF headers in order to determine the sample names.\n\n  <pre>\n  sample1      sample1.vcf.gz\n  sample2      sample2.vcf.gz\n  sample3      sample3.vcf.gz\n  </pre>\n\n <h3>Caveats</h3>\n <ul>\n     <li>IMPORTANT: The -Xmx value the tool is run with should be less than the total amount of physical memory available by at least a few GB, as the native TileDB library requires additional memory on top of the Java memory. Failure to leave enough memory for the native code can result in confusing error messages!</li>\n     <li>A single interval must be provided. This means each import is limited to a maximum of one contig</li>\n     <li>Currently, only supports diploid data</li>\n     <li>Input GVCFs cannot contain multiple entries for a single genomic position</li>\n     <li>The --genomicsdb-workspace-path must point to a non-existent or empty directory.</li>\n </ul>\n\n <h3>Developer Note</h3>\n To read data from GenomicsDB, use the query interface com.intel.genomicsdb.GenomicsDBFeatureReader",
            "temporaryFailCodes": [
                3
            ],
            "hints": [
                {
                    "outputDirType": "keep_output_dir",
                    "class": "http://arvados.org/cwl#RuntimeConstraints"
                }
            ],
            "requirements": [
                {
                    "class": "ShellCommandRequirement"
                },
                {
                    "class": "InlineJavascriptRequirement",
                    "expressionLib": [
                        "/**\n * File of functions to be added to cwl files\n */\n\nfunction generateGATK4BooleanValue(){\n    /**\n     * Boolean types in GATK 4 are expressed on the command line as --<PREFIX> \"true\"/\"false\",\n     * so patch here\n     */\n    if(self === true || self === false){\n        return self.toString()\n    }\n\n    return self;\n}\n\nfunction addTagToArgument(tagObject, argument, prefix){\n    var allTags = Array.isArray(tagObject) ? tagObject.join(\",\") : tagObject;\n    return [prefix + \":\" + allTags, argument];\n}\n\nfunction applyTagsToArgument(prefix, tags){\n    /**\n     * Function to be used in the field valueFrom of File objects to add gatk tags.\n     */\n\n    if(!self){\n        return null;\n    }\n    else if(!tags){\n        return generateArrayCmd(prefix);\n    }\n    else{\n        if(Array.isArray(self)){\n            if(!Array.isArray(tags) || self.length !== tags.length){\n                throw new TypeError(\"Argument '\" + prefix + \"' tag field is invalid\");\n            }\n\n            var value = self.map(function(element, i) {\n                return addTagToArgument(tags[i], element);\n            }).reduce(function(a, b){return a.concat(b)})\n\n            return value;\n        }\n        else{\n            return addTagToArgument(tags, self);\n        }\n    }\n}\n\nfunction generateArrayCmd(prefix){\n    /**\n     * Function to be used in the field valueFrom of array objects, so that arrays are optional\n     * and prefixes are handled properly.\n     *\n     * The issue that this solves is documented here:\n     * https://www.biostars.org/p/258414/#260140\n     */\n    if(!self){\n        return null;\n    }\n\n    if(!Array.isArray(self)){\n        self = [self];\n    }\n\n    var output = [];\n    self.forEach(function(element) {\n        output.push(prefix);\n        output.push(element);\n    })\n\n    return output;\n}"
                    ]
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mercury/gatk-4.0.0.0-tmpdir-output-wrapper:v2"
                }
            ],
            "inputs": [
                {
                    "doc": "Reference sequence",
                    "id": "#GenomicsDBImport.cwl/GenomicsDBImport/reference",
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "valueFrom": "$(applyTagsToArgument(\"--reference\", inputs['reference_tags']))"
                    },
                    "secondaryFiles": [
                        ".fai",
                        "^.dict"
                    ]
                },
                {
                    "doc": "BAM/SAM/CRAM file containing reads",
                    "id": "#GenomicsDBImport.cwl/GenomicsDBImport/input",
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "File",
                            "inputBinding": {
                                "valueFrom": "$(null)"
                            }
                        },
                        "File"
                    ],
                    "inputBinding": {
                        "valueFrom": "$(applyTagsToArgument(\"--input\", inputs['input_tags']))"
                    },
                    "secondaryFiles": ".crai"
                },
                {
                    "doc": "Threshold number of ambiguous bases. If null, uses threshold fraction; otherwise, overrides threshold fraction.",
                    "id": "#GenomicsDBImport.cwl/GenomicsDBImport/ambig-filter-bases",
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "prefix": "--ambig-filter-bases"
                    }
                },
                {
                    "doc": "Threshold fraction of ambiguous bases",
                    "id": "#GenomicsDBImport.cwl/GenomicsDBImport/ambig-filter-frac",
                    "type": [
                        "null",
                        "double"
                    ],
                    "inputBinding": {
                        "prefix": "--ambig-filter-frac"
                    }
                },
                {
                    "doc": "Maximum length of fragment (insert size)",
                    "id": "#GenomicsDBImport.cwl/GenomicsDBImport/max-fragment-length",
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "prefix": "--max-fragment-length"
                    }
                },
                {
                    "doc": "Name of the library to keep",
                    "id": "#GenomicsDBImport.cwl/GenomicsDBImport/library",
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "string",
                            "inputBinding": {
                                "valueFrom": "$(null)"
                            }
                        },
                        "string"
                    ],
                    "inputBinding": {
                        "valueFrom": "$(generateArrayCmd(\"--library\"))"
                    }
                },
                {
                    "doc": "Maximum mapping quality to keep (inclusive)",
                    "id": "#GenomicsDBImport.cwl/GenomicsDBImport/maximum-mapping-quality",
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "prefix": "--maximum-mapping-quality"
                    }
                },
                {
                    "doc": "Minimum mapping quality to keep (inclusive)",
                    "id": "#GenomicsDBImport.cwl/GenomicsDBImport/minimum-mapping-quality",
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "prefix": "--minimum-mapping-quality"
                    }
                },
                {
                    "doc": "Allow a read to be filtered out based on having only 1 soft-clipped block. By default, both ends must have a soft-clipped block, setting this flag requires only 1 soft-clipped block",
                    "id": "#GenomicsDBImport.cwl/GenomicsDBImport/dont-require-soft-clips-both-ends",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--dont-require-soft-clips-both-ends",
                        "valueFrom": "$(generateGATK4BooleanValue())"
                    }
                },
                {
                    "doc": "Minimum number of aligned bases",
                    "id": "#GenomicsDBImport.cwl/GenomicsDBImport/filter-too-short",
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "prefix": "--filter-too-short"
                    }
                },
                {
                    "doc": "Platform attribute (PL) to match",
                    "id": "#GenomicsDBImport.cwl/GenomicsDBImport/platform-filter-name",
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "string",
                            "inputBinding": {
                                "valueFrom": "$(null)"
                            }
                        },
                        "string"
                    ],
                    "inputBinding": {
                        "valueFrom": "$(generateArrayCmd(\"--platform-filter-name\"))"
                    }
                },
                {
                    "doc": "Platform unit (PU) to filter out",
                    "id": "#GenomicsDBImport.cwl/GenomicsDBImport/black-listed-lanes",
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "string",
                            "inputBinding": {
                                "valueFrom": "$(null)"
                            }
                        },
                        "string"
                    ],
                    "inputBinding": {
                        "valueFrom": "$(generateArrayCmd(\"--black-listed-lanes\"))"
                    }
                },
                {
                    "doc": "The name of the read group to filter out",
                    "id": "#GenomicsDBImport.cwl/GenomicsDBImport/read-group-black-list",
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "string",
                            "inputBinding": {
                                "valueFrom": "$(null)"
                            }
                        },
                        "string"
                    ],
                    "inputBinding": {
                        "valueFrom": "$(generateArrayCmd(\"--read-group-black-list\"))"
                    }
                },
                {
                    "doc": "The name of the read group to keep",
                    "id": "#GenomicsDBImport.cwl/GenomicsDBImport/keep-read-group",
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "prefix": "--keep-read-group"
                    }
                },
                {
                    "doc": "Keep only reads with length at most equal to the specified value",
                    "id": "#GenomicsDBImport.cwl/GenomicsDBImport/max-read-length",
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "prefix": "--max-read-length"
                    }
                },
                {
                    "doc": "Keep only reads with length at least equal to the specified value",
                    "id": "#GenomicsDBImport.cwl/GenomicsDBImport/min-read-length",
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "prefix": "--min-read-length"
                    }
                },
                {
                    "doc": "Keep only reads with this read name",
                    "id": "#GenomicsDBImport.cwl/GenomicsDBImport/read-name",
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "prefix": "--read-name"
                    }
                },
                {
                    "doc": "Keep only reads on the reverse strand",
                    "id": "#GenomicsDBImport.cwl/GenomicsDBImport/keep-reverse-strand-only",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--keep-reverse-strand-only",
                        "valueFrom": "$(generateGATK4BooleanValue())"
                    }
                },
                {
                    "doc": "The name of the sample(s) to keep, filtering out all others",
                    "id": "#GenomicsDBImport.cwl/GenomicsDBImport/sample",
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "string",
                            "inputBinding": {
                                "valueFrom": "$(null)"
                            }
                        },
                        "string"
                    ],
                    "inputBinding": {
                        "valueFrom": "$(generateArrayCmd(\"--sample\"))"
                    }
                },
                {
                    "doc": "If true, adds a PG tag to created SAM/BAM/CRAM files.",
                    "id": "#GenomicsDBImport.cwl/GenomicsDBImport/add-output-sam-program-record",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--add-output-sam-program-record",
                        "valueFrom": "$(generateGATK4BooleanValue())"
                    }
                },
                {
                    "doc": "If true, adds a command line header line to created VCF files.",
                    "id": "#GenomicsDBImport.cwl/GenomicsDBImport/add-output-vcf-command-line",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--add-output-vcf-command-line",
                        "valueFrom": "$(generateGATK4BooleanValue())"
                    }
                },
                {
                    "doc": "read one or more arguments files and add them to the command line",
                    "id": "#GenomicsDBImport.cwl/GenomicsDBImport/arguments_file",
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "File",
                            "inputBinding": {
                                "valueFrom": "$(null)"
                            }
                        },
                        "File"
                    ],
                    "inputBinding": {
                        "valueFrom": "$(applyTagsToArgument(\"--arguments_file\", inputs['arguments_file_tags']))"
                    }
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": [
                                "string",
                                {
                                    "type": "array",
                                    "items": "string"
                                }
                            ]
                        }
                    ],
                    "doc": "A argument to set the tags of 'arguments_file'",
                    "id": "#GenomicsDBImport.cwl/GenomicsDBImport/arguments_file_tags"
                },
                {
                    "doc": "Batch size controls the number of samples for which readers are open at once and therefore provides a way to minimize memory consumption. However, it can take longer to complete. Use the consolidate flag if more than a hundred batches were used. This will improve feature read time. batchSize=0 means no batching (i.e. readers for all samples will be opened at once) Defaults to 0",
                    "id": "#GenomicsDBImport.cwl/GenomicsDBImport/batch-size",
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "prefix": "--batch-size"
                    }
                },
                {
                    "doc": "Size of the cloud-only prefetch buffer (in MB; 0 to disable). Defaults to cloudPrefetchBuffer if unset.",
                    "id": "#GenomicsDBImport.cwl/GenomicsDBImport/cloud-index-prefetch-buffer",
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "prefix": "--cloud-index-prefetch-buffer"
                    }
                },
                {
                    "doc": "Size of the cloud-only prefetch buffer (in MB; 0 to disable).",
                    "id": "#GenomicsDBImport.cwl/GenomicsDBImport/cloud-prefetch-buffer",
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "prefix": "--cloud-prefetch-buffer"
                    }
                },
                {
                    "doc": "Boolean flag to enable consolidation. If importing data in batches, a new fragment is created for each batch. In case thousands of fragments are created, GenomicsDB feature readers will try to open ~20x as many files. Also, internally GenomicsDB would consume more memory to maintain bookkeeping data from all fragments. Use this flag to merge all fragments into one. Merging can potentially improve read performance, however overall benefit might not be noticeable as the top Java layers have significantly higher overheads. This flag has no effect if only one batch is used. Defaults to false",
                    "id": "#GenomicsDBImport.cwl/GenomicsDBImport/consolidate",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--consolidate",
                        "valueFrom": "$(generateGATK4BooleanValue())"
                    }
                },
                {
                    "doc": "If true, create a BAM/CRAM index when writing a coordinate-sorted BAM/CRAM file.",
                    "id": "#GenomicsDBImport.cwl/GenomicsDBImport/create-output-bam-index",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--create-output-bam-index",
                        "valueFrom": "$(generateGATK4BooleanValue())"
                    }
                },
                {
                    "doc": "If true, create a MD5 digest for any BAM/SAM/CRAM file created",
                    "id": "#GenomicsDBImport.cwl/GenomicsDBImport/create-output-bam-md5",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--create-output-bam-md5",
                        "valueFrom": "$(generateGATK4BooleanValue())"
                    }
                },
                {
                    "doc": "If true, create a VCF index when writing a coordinate-sorted VCF file.",
                    "id": "#GenomicsDBImport.cwl/GenomicsDBImport/create-output-variant-index",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--create-output-variant-index",
                        "valueFrom": "$(generateGATK4BooleanValue())"
                    }
                },
                {
                    "doc": "If true, create a a MD5 digest any VCF file created.",
                    "id": "#GenomicsDBImport.cwl/GenomicsDBImport/create-output-variant-md5",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--create-output-variant-md5",
                        "valueFrom": "$(generateGATK4BooleanValue())"
                    }
                },
                {
                    "doc": "If true, don't cache bam indexes, this will reduce memory requirements but may harm performance if many intervals are specified.  Caching is automatically disabled if there are no intervals specified.",
                    "id": "#GenomicsDBImport.cwl/GenomicsDBImport/disable-bam-index-caching",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--disable-bam-index-caching",
                        "valueFrom": "$(generateGATK4BooleanValue())"
                    }
                },
                {
                    "doc": "Read filters to be disabled before analysis",
                    "id": "#GenomicsDBImport.cwl/GenomicsDBImport/disable-read-filter",
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "string",
                            "inputBinding": {
                                "valueFrom": "$(null)"
                            }
                        },
                        "string"
                    ],
                    "inputBinding": {
                        "valueFrom": "$(generateArrayCmd(\"--disable-read-filter\"))"
                    }
                },
                {
                    "doc": "If specified, do not check the sequence dictionaries from our inputs for compatibility. Use at your own risk!",
                    "id": "#GenomicsDBImport.cwl/GenomicsDBImport/disable-sequence-dictionary-validation",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--disable-sequence-dictionary-validation",
                        "valueFrom": "$(generateGATK4BooleanValue())"
                    }
                },
                {
                    "doc": "Disable all tool default read filters",
                    "id": "#GenomicsDBImport.cwl/GenomicsDBImport/disable-tool-default-read-filters",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--disable-tool-default-read-filters",
                        "valueFrom": "$(generateGATK4BooleanValue())"
                    }
                },
                {
                    "doc": "One or more genomic intervals to exclude from processing",
                    "id": "#GenomicsDBImport.cwl/GenomicsDBImport/exclude-intervals",
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "string",
                            "inputBinding": {
                                "valueFrom": "$(null)"
                            }
                        },
                        "string"
                    ],
                    "inputBinding": {
                        "valueFrom": "$(generateArrayCmd(\"--exclude-intervals\"))"
                    }
                },
                {
                    "doc": "A configuration file to use with the GATK.",
                    "id": "#GenomicsDBImport.cwl/GenomicsDBImport/gatk-config-file",
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "valueFrom": "$(applyTagsToArgument(\"--gatk-config-file\", inputs['gatk-config-file_tags']))"
                    }
                },
                {
                    "type": [
                        "null",
                        "string",
                        {
                            "type": "array",
                            "items": "string"
                        }
                    ],
                    "doc": "A argument to set the tags of 'gatk-config-file'",
                    "id": "#GenomicsDBImport.cwl/GenomicsDBImport/gatk-config-file_tags"
                },
                {
                    "doc": "If the GCS bucket channel errors out, how many times it will attempt to re-initiate the connection",
                    "id": "#GenomicsDBImport.cwl/GenomicsDBImport/gcs-max-retries",
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "prefix": "--gcs-max-retries"
                    }
                },
                {
                    "doc": "Buffer size in bytes allocated for GenomicsDB attributes during import. Should be large enough to hold data from one site.  Defaults to 1048576",
                    "id": "#GenomicsDBImport.cwl/GenomicsDBImport/genomicsdb-segment-size",
                    "type": [
                        "null",
                        "long"
                    ],
                    "inputBinding": {
                        "prefix": "--genomicsdb-segment-size"
                    }
                },
                {
                    "doc": "Buffer size in bytes to store variant contexts. Larger values are better as smaller values cause frequent disk writes. Defaults to 16384 which was empirically determined to work well for many inputs.",
                    "id": "#GenomicsDBImport.cwl/GenomicsDBImport/genomicsdb-vcf-buffer-size",
                    "type": [
                        "null",
                        "long"
                    ],
                    "inputBinding": {
                        "prefix": "--genomicsdb-vcf-buffer-size"
                    }
                },
                {
                    "doc": "Workspace for GenomicsDB. Must be a POSIX file system path, but can be a relative path. Must be an empty or non-existent directory.",
                    "id": "#GenomicsDBImport.cwl/GenomicsDBImport/genomicsdb-workspace-path",
                    "type": "string",
                    "inputBinding": {
                        "prefix": "--genomicsdb-workspace-path"
                    }
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": [
                                "string",
                                {
                                    "type": "array",
                                    "items": "string"
                                }
                            ]
                        }
                    ],
                    "doc": "A argument to set the tags of 'input'",
                    "id": "#GenomicsDBImport.cwl/GenomicsDBImport/input_tags"
                },
                {
                    "doc": "Amount of padding (in bp) to add to each interval you are excluding.",
                    "id": "#GenomicsDBImport.cwl/GenomicsDBImport/interval-exclusion-padding",
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "prefix": "--interval-exclusion-padding"
                    }
                },
                {
                    "doc": "Interval merging rule for abutting intervals",
                    "id": "#GenomicsDBImport.cwl/GenomicsDBImport/interval-merging-rule",
                    "type": [
                        "null",
                        {
                            "type": "enum",
                            "symbols": [
                                "#GenomicsDBImport.cwl/GenomicsDBImport/interval-merging-rule/ALL",
                                "#GenomicsDBImport.cwl/GenomicsDBImport/interval-merging-rule/OVERLAPPING_ONLY"
                            ]
                        }
                    ],
                    "inputBinding": {
                        "prefix": "--interval-merging-rule"
                    }
                },
                {
                    "doc": "Amount of padding (in bp) to add to each interval you are including.",
                    "id": "#GenomicsDBImport.cwl/GenomicsDBImport/interval-padding",
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "prefix": "--interval-padding"
                    }
                },
                {
                    "doc": "Set merging approach to use for combining interval inputs",
                    "id": "#GenomicsDBImport.cwl/GenomicsDBImport/interval-set-rule",
                    "type": [
                        "null",
                        {
                            "type": "enum",
                            "symbols": [
                                "#GenomicsDBImport.cwl/GenomicsDBImport/interval-set-rule/UNION",
                                "#GenomicsDBImport.cwl/GenomicsDBImport/interval-set-rule/INTERSECTION"
                            ]
                        }
                    ],
                    "inputBinding": {
                        "prefix": "--interval-set-rule"
                    }
                },
                {
                    "doc": "One or more genomic intervals over which to operate",
                    "id": "#GenomicsDBImport.cwl/GenomicsDBImport/intervals",
                    "type": [
                        "File",
                        "string"
                    ],
                    "inputBinding": {
                        "valueFrom": "$(applyTagsToArgument(\"--intervals\", inputs['intervals_tags']))"
                    }
                },
                {
                    "type": [
                        "null",
                        "string",
                        {
                            "type": "array",
                            "items": "string"
                        }
                    ],
                    "doc": "A argument to set the tags of 'intervals'",
                    "id": "#GenomicsDBImport.cwl/GenomicsDBImport/intervals_tags"
                },
                {
                    "doc": "Lenient processing of VCF files",
                    "id": "#GenomicsDBImport.cwl/GenomicsDBImport/lenient",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--lenient",
                        "valueFrom": "$(generateGATK4BooleanValue())"
                    }
                },
                {
                    "doc": "Will overwrite given workspace if it exists. Otherwise a new workspace is created. Defaults to false",
                    "id": "#GenomicsDBImport.cwl/GenomicsDBImport/overwrite-existing-genomicsdb-workspace",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--overwrite-existing-genomicsdb-workspace",
                        "valueFrom": "$(generateGATK4BooleanValue())"
                    }
                },
                {
                    "doc": "Whether to suppress job-summary info on System.err.",
                    "id": "#GenomicsDBImport.cwl/GenomicsDBImport/QUIET",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--QUIET",
                        "valueFrom": "$(generateGATK4BooleanValue())"
                    }
                },
                {
                    "doc": "Read filters to be applied before analysis",
                    "id": "#GenomicsDBImport.cwl/GenomicsDBImport/read-filter",
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "string",
                            "inputBinding": {
                                "valueFrom": "$(null)"
                            }
                        },
                        "string"
                    ],
                    "inputBinding": {
                        "valueFrom": "$(generateArrayCmd(\"--read-filter\"))"
                    }
                },
                {
                    "doc": "Indices to use for the read inputs. If specified, an index must be provided for every read input and in the same order as the read inputs. If this argument is not specified, the path to the index for each input will be inferred automatically.",
                    "id": "#GenomicsDBImport.cwl/GenomicsDBImport/read-index",
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "string",
                            "inputBinding": {
                                "valueFrom": "$(null)"
                            }
                        },
                        "string"
                    ],
                    "inputBinding": {
                        "valueFrom": "$(generateArrayCmd(\"--read-index\"))"
                    }
                },
                {
                    "doc": "Validation stringency for all SAM/BAM/CRAM/SRA files read by this program.  The default stringency value SILENT can improve performance when processing a BAM file in which variable-length data (read, qualities, tags) do not otherwise need to be decoded.",
                    "id": "#GenomicsDBImport.cwl/GenomicsDBImport/read-validation-stringency",
                    "type": [
                        "null",
                        {
                            "type": "enum",
                            "symbols": [
                                "#GenomicsDBImport.cwl/GenomicsDBImport/read-validation-stringency/STRICT",
                                "#GenomicsDBImport.cwl/GenomicsDBImport/read-validation-stringency/LENIENT",
                                "#GenomicsDBImport.cwl/GenomicsDBImport/read-validation-stringency/SILENT"
                            ]
                        }
                    ],
                    "inputBinding": {
                        "prefix": "--read-validation-stringency"
                    }
                },
                {
                    "doc": "How many simultaneous threads to use when opening VCFs in batches; higher values may improve performance when network latency is an issue",
                    "id": "#GenomicsDBImport.cwl/GenomicsDBImport/reader-threads",
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "prefix": "--reader-threads"
                    }
                },
                {
                    "type": [
                        "null",
                        "string",
                        {
                            "type": "array",
                            "items": "string"
                        }
                    ],
                    "doc": "A argument to set the tags of 'reference'",
                    "id": "#GenomicsDBImport.cwl/GenomicsDBImport/reference_tags"
                },
                {
                    "doc": "Path to file containing a mapping of sample name to file uri in tab delimited format.  If this is specified then the header from the first sample will be treated as the merged header rather than merging the headers, and the sample names will be taken from this file.  This may be used to rename input samples. This is a performance optimization that relaxes the normal checks for consistent headers.  Using vcfs with incompatible headers may result in silent data corruption.",
                    "id": "#GenomicsDBImport.cwl/GenomicsDBImport/sample-name-map",
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "valueFrom": "$(applyTagsToArgument(\"--sample-name-map\", inputs['sample-name-map_tags']))"
                    }
                },
                {
                    "type": [
                        "null",
                        "string",
                        {
                            "type": "array",
                            "items": "string"
                        }
                    ],
                    "doc": "A argument to set the tags of 'sample-name-map'",
                    "id": "#GenomicsDBImport.cwl/GenomicsDBImport/sample-name-map_tags"
                },
                {
                    "doc": "Output traversal statistics every time this many seconds elapse",
                    "id": "#GenomicsDBImport.cwl/GenomicsDBImport/seconds-between-progress-updates",
                    "type": [
                        "null",
                        "double"
                    ],
                    "inputBinding": {
                        "prefix": "--seconds-between-progress-updates"
                    }
                },
                {
                    "doc": "Use the given sequence dictionary as the master/canonical sequence dictionary.  Must be a .dict file.",
                    "id": "#GenomicsDBImport.cwl/GenomicsDBImport/sequence-dictionary",
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "valueFrom": "$(applyTagsToArgument(\"--sequence-dictionary\", inputs['sequence-dictionary_tags']))"
                    }
                },
                {
                    "type": [
                        "null",
                        "string",
                        {
                            "type": "array",
                            "items": "string"
                        }
                    ],
                    "doc": "A argument to set the tags of 'sequence-dictionary'",
                    "id": "#GenomicsDBImport.cwl/GenomicsDBImport/sequence-dictionary_tags"
                },
                {
                    "doc": "display hidden arguments",
                    "id": "#GenomicsDBImport.cwl/GenomicsDBImport/showHidden",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--showHidden",
                        "valueFrom": "$(generateGATK4BooleanValue())"
                    }
                },
                {
                    "doc": "Undocumented option",
                    "id": "#GenomicsDBImport.cwl/GenomicsDBImport/TMP_DIR",
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "File",
                            "inputBinding": {
                                "valueFrom": "$(null)"
                            }
                        },
                        "File"
                    ],
                    "inputBinding": {
                        "valueFrom": "$(applyTagsToArgument(\"--TMP_DIR\", inputs['TMP_DIR_tags']))"
                    }
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": [
                                "string",
                                {
                                    "type": "array",
                                    "items": "string"
                                }
                            ]
                        }
                    ],
                    "doc": "A argument to set the tags of 'TMP_DIR'",
                    "id": "#GenomicsDBImport.cwl/GenomicsDBImport/TMP_DIR_tags"
                },
                {
                    "doc": "Whether to use the JdkDeflater (as opposed to IntelDeflater)",
                    "id": "#GenomicsDBImport.cwl/GenomicsDBImport/use-jdk-deflater",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--use-jdk-deflater",
                        "valueFrom": "$(generateGATK4BooleanValue())"
                    }
                },
                {
                    "doc": "Whether to use the JdkInflater (as opposed to IntelInflater)",
                    "id": "#GenomicsDBImport.cwl/GenomicsDBImport/use-jdk-inflater",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--use-jdk-inflater",
                        "valueFrom": "$(generateGATK4BooleanValue())"
                    }
                },
                {
                    "doc": "Boolean flag to enable checks on the sampleNameMap file. If true, tool checks whetherfeature readers are valid and shows a warning if sample names do not match with the headers. Defaults to false",
                    "id": "#GenomicsDBImport.cwl/GenomicsDBImport/validate-sample-name-map",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--validate-sample-name-map",
                        "valueFrom": "$(generateGATK4BooleanValue())"
                    }
                },
                {
                    "doc": "GVCF files to be imported to GenomicsDB. Each file must containdata for only a single sample. Either this or sample-name-map must be specified.",
                    "id": "#GenomicsDBImport.cwl/GenomicsDBImport/variant",
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "File",
                            "inputBinding": {
                                "valueFrom": "$(null)"
                            }
                        },
                        "File"
                    ],
                    "inputBinding": {
                        "valueFrom": "$(applyTagsToArgument(\"--variant\", inputs['variant_tags']))"
                    }
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": [
                                "string",
                                {
                                    "type": "array",
                                    "items": "string"
                                }
                            ]
                        }
                    ],
                    "doc": "A argument to set the tags of 'variant'",
                    "id": "#GenomicsDBImport.cwl/GenomicsDBImport/variant_tags"
                },
                {
                    "doc": "Control verbosity of logging.",
                    "id": "#GenomicsDBImport.cwl/GenomicsDBImport/verbosity",
                    "type": [
                        "null",
                        {
                            "type": "enum",
                            "symbols": [
                                "#GenomicsDBImport.cwl/GenomicsDBImport/verbosity/ERROR",
                                "#GenomicsDBImport.cwl/GenomicsDBImport/verbosity/WARNING",
                                "#GenomicsDBImport.cwl/GenomicsDBImport/verbosity/INFO",
                                "#GenomicsDBImport.cwl/GenomicsDBImport/verbosity/DEBUG"
                            ]
                        }
                    ],
                    "inputBinding": {
                        "prefix": "--verbosity"
                    }
                },
                {
                    "doc": "display the version number for this tool",
                    "id": "#GenomicsDBImport.cwl/GenomicsDBImport/version",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--version",
                        "valueFrom": "$(generateGATK4BooleanValue())"
                    }
                }
            ],
            "outputs": [
                {
                    "id": "#GenomicsDBImport.cwl/GenomicsDBImport/genomicsdb-workspace",
                    "doc": "Output folder corresponding to the input argument genomicsdb-workspace-path",
                    "type": "Directory",
                    "outputBinding": {
                        "glob": "$(inputs['genomicsdb-workspace-path'])"
                    }
                }
            ]
        },
        {
            "id": "#GenotypeGVCFs.cwl",
            "baseCommand": [
                "python3",
                "/gatk-local-io-wrapper.py",
                "[\"--variant\"]",
                "[]",
                "[\"-Xmx16000m\",\"-Xms16000m\"]",
                "GenotypeGVCFs"
            ],
            "class": "CommandLineTool",
            "doc": "Perform joint genotyping on one or more samples pre-called with HaplotypeCaller\n\n <p>\n This tool is designed to perform joint genotyping on a single input, which may contain one or many samples. In any\n case, the input samples must possess genotype likelihoods produced by HaplotypeCaller with `-ERC GVCF` or\n `-ERC BP_RESOLUTION`.\n\n\n <h3>Input</h3>\n <p>\n The GATK4 GenotypeGVCFs tool can take only one input track.  Options are 1) a single single-sample GVCF 2) a single\n multi-sample GVCF created by CombineGVCFs or 3) a GenomicsDB workspace created by GenomicsDBImport.\n A sample-level GVCF is produced by HaplotypeCaller with the `-ERC GVCF` setting.\n </p>\n\n <h3>Output</h3>\n <p>\n A final VCF in which all samples have been jointly genotyped.\n </p>\n\n <h3>Usage example</h3>\n\n <h4>Perform joint genotyping on a singular sample by providing a single-sample GVCF or on a cohort by providing a combined multi-sample GVCF</h4>\n <pre>\n gatk --java-options \"-Xmx4g\" GenotypeGVCFs \\\n   -R Homo_sapiens_assembly38.fasta \\\n   -V input.g.vcf.gz \\\n   -O output.vcf.gz\n </pre>\n\n <h4>Perform joint genotyping on GenomicsDB workspace created with GenomicsDBImport</h4>\n <pre>\n gatk --java-options \"-Xmx4g\" GenotypeGVCFs \\\n   -R Homo_sapiens_assembly38.fasta \\\n   -V gendb://my_database \\\n   -O output.vcf.gz\n </pre>\n\n <h3>Caveats</h3>\n <ul>\n   <li>Only GVCF files produced by HaplotypeCaller (or CombineGVCFs) can be used as input for this tool. Some other\n programs produce files that they call GVCFs but those lack some important information (accurate genotype likelihoods\n for every position) that GenotypeGVCFs requires for its operation.</li>\n   <li>Cannot take multiple GVCF files in one command.</li>\n </ul>\n\n <h3>Special note on ploidy</h3>\n <p>This tool is able to handle any ploidy (or mix of ploidies) intelligently; there is no need to specify ploidy\n for non-diploid organisms.</p>",
            "temporaryFailCodes": [
                3,
                250
            ],
            "requirements": [
                {
                    "class": "ShellCommandRequirement"
                },
                {
                    "class": "InlineJavascriptRequirement",
                    "expressionLib": [
                        "/**\n * File of functions to be added to cwl files\n */\n\nfunction generateGATK4BooleanValue(){\n    /**\n     * Boolean types in GATK 4 are expressed on the command line as --<PREFIX> \"true\"/\"false\",\n     * so patch here\n     */\n    if(self === true || self === false){\n        return self.toString()\n    }\n\n    return self;\n}\n\nfunction addTagToArgument(tagObject, argument, prefix){\n    var allTags = Array.isArray(tagObject) ? tagObject.join(\",\") : tagObject;\n    return [prefix + \":\" + allTags, argument];\n}\n\nfunction applyTagsToArgument(prefix, tags){\n    /**\n     * Function to be used in the field valueFrom of File objects to add gatk tags.\n     */\n\n    if(!self){\n        return null;\n    }\n    else if(!tags){\n        return generateArrayCmd(prefix);\n    }\n    else{\n        if(Array.isArray(self)){\n            if(!Array.isArray(tags) || self.length !== tags.length){\n                throw new TypeError(\"Argument '\" + prefix + \"' tag field is invalid\");\n            }\n\n            var value = self.map(function(element, i) {\n                return addTagToArgument(tags[i], element);\n            }).reduce(function(a, b){return a.concat(b)})\n\n            return value;\n        }\n        else{\n            return addTagToArgument(tags, self);\n        }\n    }\n}\n\nfunction generateArrayCmd(prefix){\n    /**\n     * Function to be used in the field valueFrom of array objects, so that arrays are optional\n     * and prefixes are handled properly.\n     *\n     * The issue that this solves is documented here:\n     * https://www.biostars.org/p/258414/#260140\n     */\n    if(!self){\n        return null;\n    }\n\n    if(!Array.isArray(self)){\n        self = [self];\n    }\n\n    var output = [];\n    self.forEach(function(element) {\n        output.push(prefix);\n        output.push(element);\n    })\n\n    return output;\n}"
                    ]
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mercury/gatk-4.0.0.0-local-io-wrapper:v4"
                }
            ],
            "inputs": [
                {
                    "doc": "Reference sequence file",
                    "id": "#GenotypeGVCFs.cwl/GenotypeGVCFs/reference",
                    "type": "File",
                    "inputBinding": {
                        "valueFrom": "$(applyTagsToArgument(\"--reference\", inputs['reference_tags']))"
                    },
                    "secondaryFiles": [
                        ".fai",
                        "^.dict"
                    ]
                },
                {
                    "doc": "BAM/SAM/CRAM file containing reads",
                    "id": "#GenotypeGVCFs.cwl/GenotypeGVCFs/input",
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "File",
                            "inputBinding": {
                                "valueFrom": "$(null)"
                            }
                        },
                        "File"
                    ],
                    "inputBinding": {
                        "valueFrom": "$(applyTagsToArgument(\"--input\", inputs['input_tags']))"
                    },
                    "secondaryFiles": ".crai"
                },
                {
                    "doc": "Threshold number of ambiguous bases. If null, uses threshold fraction; otherwise, overrides threshold fraction.",
                    "id": "#GenotypeGVCFs.cwl/GenotypeGVCFs/ambig-filter-bases",
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "prefix": "--ambig-filter-bases"
                    }
                },
                {
                    "doc": "Threshold fraction of ambiguous bases",
                    "id": "#GenotypeGVCFs.cwl/GenotypeGVCFs/ambig-filter-frac",
                    "type": [
                        "null",
                        "double"
                    ],
                    "inputBinding": {
                        "prefix": "--ambig-filter-frac"
                    }
                },
                {
                    "doc": "Maximum length of fragment (insert size)",
                    "id": "#GenotypeGVCFs.cwl/GenotypeGVCFs/max-fragment-length",
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "prefix": "--max-fragment-length"
                    }
                },
                {
                    "doc": "Name of the library to keep",
                    "id": "#GenotypeGVCFs.cwl/GenotypeGVCFs/library",
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "string",
                            "inputBinding": {
                                "valueFrom": "$(null)"
                            }
                        },
                        "string"
                    ],
                    "inputBinding": {
                        "valueFrom": "$(generateArrayCmd(\"--library\"))"
                    }
                },
                {
                    "doc": "Maximum mapping quality to keep (inclusive)",
                    "id": "#GenotypeGVCFs.cwl/GenotypeGVCFs/maximum-mapping-quality",
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "prefix": "--maximum-mapping-quality"
                    }
                },
                {
                    "doc": "Minimum mapping quality to keep (inclusive)",
                    "id": "#GenotypeGVCFs.cwl/GenotypeGVCFs/minimum-mapping-quality",
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "prefix": "--minimum-mapping-quality"
                    }
                },
                {
                    "doc": "Allow a read to be filtered out based on having only 1 soft-clipped block. By default, both ends must have a soft-clipped block, setting this flag requires only 1 soft-clipped block",
                    "id": "#GenotypeGVCFs.cwl/GenotypeGVCFs/dont-require-soft-clips-both-ends",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--dont-require-soft-clips-both-ends",
                        "valueFrom": "$(generateGATK4BooleanValue())"
                    }
                },
                {
                    "doc": "Minimum number of aligned bases",
                    "id": "#GenotypeGVCFs.cwl/GenotypeGVCFs/filter-too-short",
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "prefix": "--filter-too-short"
                    }
                },
                {
                    "doc": "Platform attribute (PL) to match",
                    "id": "#GenotypeGVCFs.cwl/GenotypeGVCFs/platform-filter-name",
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "string",
                            "inputBinding": {
                                "valueFrom": "$(null)"
                            }
                        },
                        "string"
                    ],
                    "inputBinding": {
                        "valueFrom": "$(generateArrayCmd(\"--platform-filter-name\"))"
                    }
                },
                {
                    "doc": "Platform unit (PU) to filter out",
                    "id": "#GenotypeGVCFs.cwl/GenotypeGVCFs/black-listed-lanes",
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "string",
                            "inputBinding": {
                                "valueFrom": "$(null)"
                            }
                        },
                        "string"
                    ],
                    "inputBinding": {
                        "valueFrom": "$(generateArrayCmd(\"--black-listed-lanes\"))"
                    }
                },
                {
                    "doc": "The name of the read group to filter out",
                    "id": "#GenotypeGVCFs.cwl/GenotypeGVCFs/read-group-black-list",
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "string",
                            "inputBinding": {
                                "valueFrom": "$(null)"
                            }
                        },
                        "string"
                    ],
                    "inputBinding": {
                        "valueFrom": "$(generateArrayCmd(\"--read-group-black-list\"))"
                    }
                },
                {
                    "doc": "The name of the read group to keep",
                    "id": "#GenotypeGVCFs.cwl/GenotypeGVCFs/keep-read-group",
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "prefix": "--keep-read-group"
                    }
                },
                {
                    "doc": "Keep only reads with length at most equal to the specified value",
                    "id": "#GenotypeGVCFs.cwl/GenotypeGVCFs/max-read-length",
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "prefix": "--max-read-length"
                    }
                },
                {
                    "doc": "Keep only reads with length at least equal to the specified value",
                    "id": "#GenotypeGVCFs.cwl/GenotypeGVCFs/min-read-length",
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "prefix": "--min-read-length"
                    }
                },
                {
                    "doc": "Keep only reads with this read name",
                    "id": "#GenotypeGVCFs.cwl/GenotypeGVCFs/read-name",
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "prefix": "--read-name"
                    }
                },
                {
                    "doc": "Keep only reads on the reverse strand",
                    "id": "#GenotypeGVCFs.cwl/GenotypeGVCFs/keep-reverse-strand-only",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--keep-reverse-strand-only",
                        "valueFrom": "$(generateGATK4BooleanValue())"
                    }
                },
                {
                    "doc": "The name of the sample(s) to keep, filtering out all others",
                    "id": "#GenotypeGVCFs.cwl/GenotypeGVCFs/sample",
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "string",
                            "inputBinding": {
                                "valueFrom": "$(null)"
                            }
                        },
                        "string"
                    ],
                    "inputBinding": {
                        "valueFrom": "$(generateArrayCmd(\"--sample\"))"
                    }
                },
                {
                    "doc": "If true, adds a PG tag to created SAM/BAM/CRAM files.",
                    "id": "#GenotypeGVCFs.cwl/GenotypeGVCFs/add-output-sam-program-record",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--add-output-sam-program-record",
                        "valueFrom": "$(generateGATK4BooleanValue())"
                    }
                },
                {
                    "doc": "If true, adds a command line header line to created VCF files.",
                    "id": "#GenotypeGVCFs.cwl/GenotypeGVCFs/add-output-vcf-command-line",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--add-output-vcf-command-line",
                        "valueFrom": "$(generateGATK4BooleanValue())"
                    }
                },
                {
                    "doc": "If provided, we will annotate records with the number of alternate alleles that were discovered (but not necessarily genotyped) at a given site",
                    "id": "#GenotypeGVCFs.cwl/GenotypeGVCFs/annotate-with-num-discovered-alleles",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--annotate-with-num-discovered-alleles",
                        "valueFrom": "$(generateGATK4BooleanValue())"
                    }
                },
                {
                    "doc": "One or more specific annotations to add to variant calls",
                    "id": "#GenotypeGVCFs.cwl/GenotypeGVCFs/annotation",
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "string",
                            "inputBinding": {
                                "valueFrom": "$(null)"
                            }
                        },
                        "string"
                    ],
                    "inputBinding": {
                        "valueFrom": "$(generateArrayCmd(\"--annotation\"))"
                    }
                },
                {
                    "doc": "One or more groups of annotations to apply to variant calls",
                    "id": "#GenotypeGVCFs.cwl/GenotypeGVCFs/annotation-group",
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "string",
                            "inputBinding": {
                                "valueFrom": "$(null)"
                            }
                        },
                        "string"
                    ],
                    "inputBinding": {
                        "valueFrom": "$(generateArrayCmd(\"--annotation-group\"))"
                    }
                },
                {
                    "doc": "One or more specific annotations to exclude from variant calls",
                    "id": "#GenotypeGVCFs.cwl/GenotypeGVCFs/annotations-to-exclude",
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "string",
                            "inputBinding": {
                                "valueFrom": "$(null)"
                            }
                        },
                        "string"
                    ],
                    "inputBinding": {
                        "valueFrom": "$(generateArrayCmd(\"--annotations-to-exclude\"))"
                    }
                },
                {
                    "doc": "read one or more arguments files and add them to the command line",
                    "id": "#GenotypeGVCFs.cwl/GenotypeGVCFs/arguments_file",
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "File",
                            "inputBinding": {
                                "valueFrom": "$(null)"
                            }
                        },
                        "File"
                    ],
                    "inputBinding": {
                        "valueFrom": "$(applyTagsToArgument(\"--arguments_file\", inputs['arguments_file_tags']))"
                    }
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": [
                                "string",
                                {
                                    "type": "array",
                                    "items": "string"
                                }
                            ]
                        }
                    ],
                    "doc": "A argument to set the tags of 'arguments_file'",
                    "id": "#GenotypeGVCFs.cwl/GenotypeGVCFs/arguments_file_tags"
                },
                {
                    "doc": "Size of the cloud-only prefetch buffer (in MB; 0 to disable). Defaults to cloudPrefetchBuffer if unset.",
                    "id": "#GenotypeGVCFs.cwl/GenotypeGVCFs/cloud-index-prefetch-buffer",
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "prefix": "--cloud-index-prefetch-buffer"
                    }
                },
                {
                    "doc": "Size of the cloud-only prefetch buffer (in MB; 0 to disable).",
                    "id": "#GenotypeGVCFs.cwl/GenotypeGVCFs/cloud-prefetch-buffer",
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "prefix": "--cloud-prefetch-buffer"
                    }
                },
                {
                    "doc": "If true, create a BAM/CRAM index when writing a coordinate-sorted BAM/CRAM file.",
                    "id": "#GenotypeGVCFs.cwl/GenotypeGVCFs/create-output-bam-index",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--create-output-bam-index",
                        "valueFrom": "$(generateGATK4BooleanValue())"
                    }
                },
                {
                    "doc": "If true, create a MD5 digest for any BAM/SAM/CRAM file created",
                    "id": "#GenotypeGVCFs.cwl/GenotypeGVCFs/create-output-bam-md5",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--create-output-bam-md5",
                        "valueFrom": "$(generateGATK4BooleanValue())"
                    }
                },
                {
                    "doc": "If true, create a VCF index when writing a coordinate-sorted VCF file.",
                    "id": "#GenotypeGVCFs.cwl/GenotypeGVCFs/create-output-variant-index",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--create-output-variant-index",
                        "valueFrom": "$(generateGATK4BooleanValue())"
                    }
                },
                {
                    "doc": "If true, create a a MD5 digest any VCF file created.",
                    "id": "#GenotypeGVCFs.cwl/GenotypeGVCFs/create-output-variant-md5",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--create-output-variant-md5",
                        "valueFrom": "$(generateGATK4BooleanValue())"
                    }
                },
                {
                    "doc": "dbSNP file",
                    "id": "#GenotypeGVCFs.cwl/GenotypeGVCFs/dbsnp",
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "valueFrom": "$(applyTagsToArgument(\"--dbsnp\", inputs['dbsnp_tags']))"
                    }
                },
                {
                    "type": [
                        "null",
                        "string",
                        {
                            "type": "array",
                            "items": "string"
                        }
                    ],
                    "doc": "A argument to set the tags of 'dbsnp'",
                    "id": "#GenotypeGVCFs.cwl/GenotypeGVCFs/dbsnp_tags"
                },
                {
                    "doc": "If true, don't cache bam indexes, this will reduce memory requirements but may harm performance if many intervals are specified.  Caching is automatically disabled if there are no intervals specified.",
                    "id": "#GenotypeGVCFs.cwl/GenotypeGVCFs/disable-bam-index-caching",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--disable-bam-index-caching",
                        "valueFrom": "$(generateGATK4BooleanValue())"
                    }
                },
                {
                    "doc": "Read filters to be disabled before analysis",
                    "id": "#GenotypeGVCFs.cwl/GenotypeGVCFs/disable-read-filter",
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "string",
                            "inputBinding": {
                                "valueFrom": "$(null)"
                            }
                        },
                        "string"
                    ],
                    "inputBinding": {
                        "valueFrom": "$(generateArrayCmd(\"--disable-read-filter\"))"
                    }
                },
                {
                    "doc": "If specified, do not check the sequence dictionaries from our inputs for compatibility. Use at your own risk!",
                    "id": "#GenotypeGVCFs.cwl/GenotypeGVCFs/disable-sequence-dictionary-validation",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--disable-sequence-dictionary-validation",
                        "valueFrom": "$(generateGATK4BooleanValue())"
                    }
                },
                {
                    "doc": "Disable all tool default read filters",
                    "id": "#GenotypeGVCFs.cwl/GenotypeGVCFs/disable-tool-default-read-filters",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--disable-tool-default-read-filters",
                        "valueFrom": "$(generateGATK4BooleanValue())"
                    }
                },
                {
                    "doc": "One or more genomic intervals to exclude from processing",
                    "id": "#GenotypeGVCFs.cwl/GenotypeGVCFs/exclude-intervals",
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "string",
                            "inputBinding": {
                                "valueFrom": "$(null)"
                            }
                        },
                        "string"
                    ],
                    "inputBinding": {
                        "valueFrom": "$(generateArrayCmd(\"--exclude-intervals\"))"
                    }
                },
                {
                    "doc": "A configuration file to use with the GATK.",
                    "id": "#GenotypeGVCFs.cwl/GenotypeGVCFs/gatk-config-file",
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "valueFrom": "$(applyTagsToArgument(\"--gatk-config-file\", inputs['gatk-config-file_tags']))"
                    }
                },
                {
                    "type": [
                        "null",
                        "string",
                        {
                            "type": "array",
                            "items": "string"
                        }
                    ],
                    "doc": "A argument to set the tags of 'gatk-config-file'",
                    "id": "#GenotypeGVCFs.cwl/GenotypeGVCFs/gatk-config-file_tags"
                },
                {
                    "doc": "If the GCS bucket channel errors out, how many times it will attempt to re-initiate the connection",
                    "id": "#GenotypeGVCFs.cwl/GenotypeGVCFs/gcs-max-retries",
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "prefix": "--gcs-max-retries"
                    }
                },
                {
                    "doc": "Heterozygosity value used to compute prior likelihoods for any locus.  See the GATKDocs for full details on the meaning of this population genetics concept",
                    "id": "#GenotypeGVCFs.cwl/GenotypeGVCFs/heterozygosity",
                    "type": [
                        "null",
                        "double"
                    ],
                    "inputBinding": {
                        "prefix": "--heterozygosity"
                    }
                },
                {
                    "doc": "Standard deviation of eterozygosity for SNP and indel calling.",
                    "id": "#GenotypeGVCFs.cwl/GenotypeGVCFs/heterozygosity-stdev",
                    "type": [
                        "null",
                        "double"
                    ],
                    "inputBinding": {
                        "prefix": "--heterozygosity-stdev"
                    }
                },
                {
                    "doc": "Heterozygosity for indel calling.  See the GATKDocs for heterozygosity for full details on the meaning of this population genetics concept",
                    "id": "#GenotypeGVCFs.cwl/GenotypeGVCFs/indel-heterozygosity",
                    "type": [
                        "null",
                        "double"
                    ],
                    "inputBinding": {
                        "prefix": "--indel-heterozygosity"
                    }
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": [
                                "string",
                                {
                                    "type": "array",
                                    "items": "string"
                                }
                            ]
                        }
                    ],
                    "doc": "A argument to set the tags of 'input'",
                    "id": "#GenotypeGVCFs.cwl/GenotypeGVCFs/input_tags"
                },
                {
                    "doc": "Input prior for calls",
                    "id": "#GenotypeGVCFs.cwl/GenotypeGVCFs/input-prior",
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "double",
                            "inputBinding": {
                                "valueFrom": "$(null)"
                            }
                        },
                        "double"
                    ],
                    "inputBinding": {
                        "valueFrom": "$(generateArrayCmd(\"--input-prior\"))"
                    }
                },
                {
                    "doc": "Amount of padding (in bp) to add to each interval you are excluding.",
                    "id": "#GenotypeGVCFs.cwl/GenotypeGVCFs/interval-exclusion-padding",
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "prefix": "--interval-exclusion-padding"
                    }
                },
                {
                    "doc": "Interval merging rule for abutting intervals",
                    "id": "#GenotypeGVCFs.cwl/GenotypeGVCFs/interval-merging-rule",
                    "type": [
                        "null",
                        {
                            "type": "enum",
                            "symbols": [
                                "#GenotypeGVCFs.cwl/GenotypeGVCFs/interval-merging-rule/ALL",
                                "#GenotypeGVCFs.cwl/GenotypeGVCFs/interval-merging-rule/OVERLAPPING_ONLY"
                            ]
                        }
                    ],
                    "inputBinding": {
                        "prefix": "--interval-merging-rule"
                    }
                },
                {
                    "doc": "Amount of padding (in bp) to add to each interval you are including.",
                    "id": "#GenotypeGVCFs.cwl/GenotypeGVCFs/interval-padding",
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "prefix": "--interval-padding"
                    }
                },
                {
                    "doc": "Set merging approach to use for combining interval inputs",
                    "id": "#GenotypeGVCFs.cwl/GenotypeGVCFs/interval-set-rule",
                    "type": [
                        "null",
                        {
                            "type": "enum",
                            "symbols": [
                                "#GenotypeGVCFs.cwl/GenotypeGVCFs/interval-set-rule/UNION",
                                "#GenotypeGVCFs.cwl/GenotypeGVCFs/interval-set-rule/INTERSECTION"
                            ]
                        }
                    ],
                    "inputBinding": {
                        "prefix": "--interval-set-rule"
                    }
                },
                {
                    "doc": "One or more genomic intervals over which to operate",
                    "id": "#GenotypeGVCFs.cwl/GenotypeGVCFs/intervals",
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": [
                                "File",
                                "string"
                            ],
                            "inputBinding": {
                                "valueFrom": "$(null)"
                            }
                        },
                        "File",
                        "string"
                    ],
                    "inputBinding": {
                        "valueFrom": "$(applyTagsToArgument(\"--intervals\", inputs['intervals_tags']))"
                    }
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": [
                                "string",
                                {
                                    "type": "array",
                                    "items": "string"
                                }
                            ]
                        }
                    ],
                    "doc": "A argument to set the tags of 'intervals'",
                    "id": "#GenotypeGVCFs.cwl/GenotypeGVCFs/intervals_tags"
                },
                {
                    "doc": "Lenient processing of VCF files",
                    "id": "#GenotypeGVCFs.cwl/GenotypeGVCFs/lenient",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--lenient",
                        "valueFrom": "$(generateGATK4BooleanValue())"
                    }
                },
                {
                    "doc": "Maximum number of alternate alleles to genotype",
                    "id": "#GenotypeGVCFs.cwl/GenotypeGVCFs/max-alternate-alleles",
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "prefix": "--max-alternate-alleles"
                    }
                },
                {
                    "doc": "Maximum number of genotypes to consider at any site",
                    "id": "#GenotypeGVCFs.cwl/GenotypeGVCFs/max-genotype-count",
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "prefix": "--max-genotype-count"
                    }
                },
                {
                    "doc": "Restrict variant output to sites that start within provided intervals",
                    "id": "#GenotypeGVCFs.cwl/GenotypeGVCFs/only-output-calls-starting-in-intervals",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--only-output-calls-starting-in-intervals",
                        "valueFrom": "$(generateGATK4BooleanValue())"
                    }
                },
                {
                    "doc": "File to which variants should be written",
                    "id": "#GenotypeGVCFs.cwl/GenotypeGVCFs/output-filename",
                    "type": "string",
                    "inputBinding": {
                        "prefix": "--output"
                    }
                },
                {
                    "doc": "Whether to suppress job-summary info on System.err.",
                    "id": "#GenotypeGVCFs.cwl/GenotypeGVCFs/QUIET",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--QUIET",
                        "valueFrom": "$(generateGATK4BooleanValue())"
                    }
                },
                {
                    "doc": "Read filters to be applied before analysis",
                    "id": "#GenotypeGVCFs.cwl/GenotypeGVCFs/read-filter",
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "string",
                            "inputBinding": {
                                "valueFrom": "$(null)"
                            }
                        },
                        "string"
                    ],
                    "inputBinding": {
                        "valueFrom": "$(generateArrayCmd(\"--read-filter\"))"
                    }
                },
                {
                    "doc": "Indices to use for the read inputs. If specified, an index must be provided for every read input and in the same order as the read inputs. If this argument is not specified, the path to the index for each input will be inferred automatically.",
                    "id": "#GenotypeGVCFs.cwl/GenotypeGVCFs/read-index",
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "string",
                            "inputBinding": {
                                "valueFrom": "$(null)"
                            }
                        },
                        "string"
                    ],
                    "inputBinding": {
                        "valueFrom": "$(generateArrayCmd(\"--read-index\"))"
                    }
                },
                {
                    "doc": "Validation stringency for all SAM/BAM/CRAM/SRA files read by this program.  The default stringency value SILENT can improve performance when processing a BAM file in which variable-length data (read, qualities, tags) do not otherwise need to be decoded.",
                    "id": "#GenotypeGVCFs.cwl/GenotypeGVCFs/read-validation-stringency",
                    "type": [
                        "null",
                        {
                            "type": "enum",
                            "symbols": [
                                "#GenotypeGVCFs.cwl/GenotypeGVCFs/read-validation-stringency/STRICT",
                                "#GenotypeGVCFs.cwl/GenotypeGVCFs/read-validation-stringency/LENIENT",
                                "#GenotypeGVCFs.cwl/GenotypeGVCFs/read-validation-stringency/SILENT"
                            ]
                        }
                    ],
                    "inputBinding": {
                        "prefix": "--read-validation-stringency"
                    }
                },
                {
                    "type": [
                        "null",
                        "string",
                        {
                            "type": "array",
                            "items": "string"
                        }
                    ],
                    "doc": "A argument to set the tags of 'reference'",
                    "id": "#GenotypeGVCFs.cwl/GenotypeGVCFs/reference_tags"
                },
                {
                    "doc": "Ploidy (number of chromosomes) per sample. For pooled data, set to (Number of samples in each pool * Sample Ploidy).",
                    "id": "#GenotypeGVCFs.cwl/GenotypeGVCFs/sample-ploidy",
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "prefix": "--sample-ploidy"
                    }
                },
                {
                    "doc": "Output traversal statistics every time this many seconds elapse",
                    "id": "#GenotypeGVCFs.cwl/GenotypeGVCFs/seconds-between-progress-updates",
                    "type": [
                        "null",
                        "double"
                    ],
                    "inputBinding": {
                        "prefix": "--seconds-between-progress-updates"
                    }
                },
                {
                    "doc": "Use the given sequence dictionary as the master/canonical sequence dictionary.  Must be a .dict file.",
                    "id": "#GenotypeGVCFs.cwl/GenotypeGVCFs/sequence-dictionary",
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "valueFrom": "$(applyTagsToArgument(\"--sequence-dictionary\", inputs['sequence-dictionary_tags']))"
                    }
                },
                {
                    "type": [
                        "null",
                        "string",
                        {
                            "type": "array",
                            "items": "string"
                        }
                    ],
                    "doc": "A argument to set the tags of 'sequence-dictionary'",
                    "id": "#GenotypeGVCFs.cwl/GenotypeGVCFs/sequence-dictionary_tags"
                },
                {
                    "doc": "display hidden arguments",
                    "id": "#GenotypeGVCFs.cwl/GenotypeGVCFs/showHidden",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--showHidden",
                        "valueFrom": "$(generateGATK4BooleanValue())"
                    }
                },
                {
                    "doc": "The minimum phred-scaled confidence threshold at which variants should be called",
                    "id": "#GenotypeGVCFs.cwl/GenotypeGVCFs/standard-min-confidence-threshold-for-calling",
                    "type": [
                        "null",
                        "double"
                    ],
                    "inputBinding": {
                        "prefix": "--standard-min-confidence-threshold-for-calling"
                    }
                },
                {
                    "doc": "Undocumented option",
                    "id": "#GenotypeGVCFs.cwl/GenotypeGVCFs/TMP_DIR",
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "File",
                            "inputBinding": {
                                "valueFrom": "$(null)"
                            }
                        },
                        "File"
                    ],
                    "inputBinding": {
                        "valueFrom": "$(applyTagsToArgument(\"--TMP_DIR\", inputs['TMP_DIR_tags']))"
                    }
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": [
                                "string",
                                {
                                    "type": "array",
                                    "items": "string"
                                }
                            ]
                        }
                    ],
                    "doc": "A argument to set the tags of 'TMP_DIR'",
                    "id": "#GenotypeGVCFs.cwl/GenotypeGVCFs/TMP_DIR_tags"
                },
                {
                    "doc": "Whether to use the JdkDeflater (as opposed to IntelDeflater)",
                    "id": "#GenotypeGVCFs.cwl/GenotypeGVCFs/use-jdk-deflater",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--use-jdk-deflater",
                        "valueFrom": "$(generateGATK4BooleanValue())"
                    }
                },
                {
                    "doc": "Whether to use the JdkInflater (as opposed to IntelInflater)",
                    "id": "#GenotypeGVCFs.cwl/GenotypeGVCFs/use-jdk-inflater",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--use-jdk-inflater",
                        "valueFrom": "$(generateGATK4BooleanValue())"
                    }
                },
                {
                    "doc": "If provided, we will use the new AF model instead of the so-called exact model",
                    "id": "#GenotypeGVCFs.cwl/GenotypeGVCFs/use-new-qual-calculator",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--use-new-qual-calculator",
                        "valueFrom": "$(generateGATK4BooleanValue())"
                    }
                },
                {
                    "doc": "A VCF file containing variants",
                    "id": "#GenotypeGVCFs.cwl/GenotypeGVCFs/variant",
                    "type": [
                        "File",
                        "Directory"
                    ],
                    "inputBinding": {
                        "prefix": "--variant",
                        "valueFrom": "${if(self.class==\"File\"){return self.path;} else {return \"gendb://\"+self.path;}}"
                    }
                },
                {
                    "type": [
                        "null",
                        "string",
                        {
                            "type": "array",
                            "items": "string"
                        }
                    ],
                    "doc": "A argument to set the tags of 'variant'",
                    "id": "#GenotypeGVCFs.cwl/GenotypeGVCFs/variant_tags"
                },
                {
                    "doc": "Control verbosity of logging.",
                    "id": "#GenotypeGVCFs.cwl/GenotypeGVCFs/verbosity",
                    "type": [
                        "null",
                        {
                            "type": "enum",
                            "symbols": [
                                "#GenotypeGVCFs.cwl/GenotypeGVCFs/verbosity/ERROR",
                                "#GenotypeGVCFs.cwl/GenotypeGVCFs/verbosity/WARNING",
                                "#GenotypeGVCFs.cwl/GenotypeGVCFs/verbosity/INFO",
                                "#GenotypeGVCFs.cwl/GenotypeGVCFs/verbosity/DEBUG"
                            ]
                        }
                    ],
                    "inputBinding": {
                        "prefix": "--verbosity"
                    }
                },
                {
                    "doc": "display the version number for this tool",
                    "id": "#GenotypeGVCFs.cwl/GenotypeGVCFs/version",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--version",
                        "valueFrom": "$(generateGATK4BooleanValue())"
                    }
                }
            ],
            "outputs": [
                {
                    "id": "#GenotypeGVCFs.cwl/GenotypeGVCFs/bam-index",
                    "doc": "index file generated if create-output-bam-index is true",
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": [
                            "$(inputs['output-filename']).idx",
                            "$(inputs['output-filename']).tbi"
                        ]
                    }
                },
                {
                    "id": "#GenotypeGVCFs.cwl/GenotypeGVCFs/bam-md5",
                    "doc": "md5 file generated if create-output-bam-md5 is true",
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "$(inputs['output-filename']).md5"
                    }
                },
                {
                    "id": "#GenotypeGVCFs.cwl/GenotypeGVCFs/variant-index",
                    "doc": "index file generated if create-output-variant-index is true",
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": [
                            "$(inputs['output-filename']).idx",
                            "$(inputs['output-filename']).tbi"
                        ]
                    }
                },
                {
                    "id": "#GenotypeGVCFs.cwl/GenotypeGVCFs/variant-md5",
                    "doc": "md5 file generated if create-output-variant-md5 is true",
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "$(inputs['output-filename']).md5"
                    }
                },
                {
                    "id": "#GenotypeGVCFs.cwl/GenotypeGVCFs/output",
                    "doc": "Output file corresponding to the input argument output-filename",
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs['output-filename'])"
                    }
                }
            ]
        },
        {
            "id": "#HaplotypeCaller.cwl",
            "baseCommand": [
                "python3",
                "/gatk-local-io-wrapper.py",
                "[]",
                "[]",
                "[\"-XX:MaxRAMFraction=1\",\"-XX:+UnlockExperimentalVMOptions\",\"-XX:+UseCGroupMemoryLimitForHeap\"]",
                "HaplotypeCaller"
            ],
            "class": "CommandLineTool",
            "doc": "Call germline SNPs and indels via local re-assembly of haplotypes\n\n <p>The HaplotypeCaller is capable of calling SNPs and indels simultaneously via local de-novo assembly of haplotypes in an active region. In other words, whenever the program encounters a region showing signs of variation, it discards the existing mapping information and completely reassembles the reads in that region. This allows the HaplotypeCaller to be more accurate when calling regions that are traditionally difficult to call, for example when they contain different types of variants close to each other. It also makes the HaplotypeCaller much better at calling indels than position-based callers like UnifiedGenotyper.</p>\n\n <p>In the GVCF workflow used for scalable variant calling in DNA sequence data, HaplotypeCaller runs per-sample to generate an intermediate GVCF (not to be used in final analysis), which can then be used in GenotypeGVCFs for joint genotyping of multiple samples in a very efficient way. The GVCF workflow enables rapid incremental processing of samples as they roll off the sequencer, as well as scaling to very large cohort sizes (e.g. the 92K exomes of ExAC).</p>\n\n <p>In addition, HaplotypeCaller is able to handle non-diploid organisms as well as pooled experiment data. Note however that the algorithms used to calculate variant likelihoods is not well suited to extreme allele frequencies (relative to ploidy) so its use is not recommended for somatic (cancer) variant discovery. For that purpose, use Mutect2 instead.</p>\n\n <p>Finally, HaplotypeCaller is also able to correctly handle the splice junctions that make RNAseq a challenge for most variant callers,\n on the condition that the input read data has previously been processed according to our recommendations as documented <a href='https://software.broadinstitute.org/gatk/documentation/article?id=4067'>here</a>.</p>\n\n <h3>How HaplotypeCaller works</h3>\n\n <br />\n <h4><a href='https://software.broadinstitute.org/gatk/documentation/article?id=4147'>1. Define active regions </a></h4>\n\n <p>The program determines which regions of the genome it needs to operate on (active regions), based on the presence of\n evidence for variation.\n\n <br />\n <h4><a href='https://software.broadinstitute.org/gatk/documentation/article?id=4146'>2. Determine haplotypes by assembly of the active region </a></h4>\n\n <p>For each active region, the program builds a De Bruijn-like graph to reassemble the active region and identifies\n what are the possible haplotypes present in the data. The program then realigns each haplotype against the reference\n haplotype using the Smith-Waterman algorithm in order to identify potentially variant sites. </p>\n\n <br />\n <h4><a href='https://software.broadinstitute.org/gatk/documentation/article?id=4441'>3. Determine likelihoods of the haplotypes given the read data </a></h4>\n\n <p>For each active region, the program performs a pairwise alignment of each read against each haplotype using the\n PairHMM algorithm. This produces a matrix of likelihoods of haplotypes given the read data. These likelihoods are\n then marginalized to obtain the likelihoods of alleles for each potentially variant site given the read data.   </p>\n\n <br />\n <h4><a href='https://software.broadinstitute.org/gatk/documentation/article?id=4442'>4. Assign sample genotypes </a></h4>\n\n <p>For each potentially variant site, the program applies Bayes' rule, using the likelihoods of alleles given the\n read data to calculate the likelihoods of each genotype per sample given the read data observed for that\n sample. The most likely genotype is then assigned to the sample.    </p>\n\n <h3>Input</h3>\n <p>\n Input bam file(s) from which to make variant calls\n </p>\n\n <h3>Output</h3>\n <p>\n Either a VCF or GVCF file with raw, unfiltered SNP and indel calls. Regular VCFs must be filtered either by variant\n recalibration (Best Practice) or hard-filtering before use in downstream analyses. If using the GVCF workflow, the\n output is a GVCF file that must first be run through GenotypeGVCFs and then filtering before further analysis.\n </p>\n\n <h3>Usage examples</h3>\n\n <p>These are example commands that show how to run HaplotypeCaller for typical use cases. Have a look at the <a href='https://software.broadinstitute.org/gatk/documentation/article?id=3893'>method documentation</a> for the basic GVCF workflow. </p>\n\n <br />\n <h4>Single-sample GVCF calling (outputs intermediate GVCF)</h4>\n <pre>\n gatk --java-options \"-Xmx4g\" HaplotypeCaller  \\\n   -R Homo_sapiens_assembly38.fasta \\\n   -I input.bam \\\n   -O output.g.vcf.gz \\\n   -ERC GVCF\n </pre>\n\n <h4>Single-sample GVCF calling with <a href='https://software.broadinstitute.org/gatk/documentation/article?id=9622'>allele-specific annotations</a></h4>\n <pre>\n gatk --java-options \"-Xmx4g\" HaplotypeCaller  \\\n   -R Homo_sapiens_assembly38.fasta \\\n   -I input.bam \\\n   -O output.g.vcf.gz \\\n   -ERC GVCF \\\n   -G Standard \\\n   -G AS_Standard\n </pre>\n\n <h4>Variant calling with <a href='https://software.broadinstitute.org/gatk/documentation/article?id=5484'>bamout</a> to show realigned reads</h4>\n <pre>\n gatk --java-options \"-Xmx4g\" HaplotypeCaller  \\\n   -R Homo_sapiens_assembly38.fasta \\\n   -I input.bam \\\n   -O output.vcf.gz \\\n   -bamout bamout.bam\n </pre>\n\n <h3>Caveats</h3>\n <ul>\n <li>We have not yet fully tested the interaction between the GVCF-based calling or the multisample calling and the\n RNAseq-specific functionalities. Use those in combination at your own risk.</li>\n </ul>\n\n <h3>Special note on ploidy</h3>\n <p>This tool is able to handle many non-diploid use cases; the desired ploidy can be specified using the -ploidy\n argument. Note however that very high ploidies (such as are encountered in large pooled experiments) may cause\n performance challenges including excessive slowness. We are working on resolving these limitations.</p>\n\n <h3>Additional Notes</h3>\n <ul>\n     <li>When working with PCR-free data, be sure to set `-pcr_indel_model NONE` (see argument below).</li>\n     <li>When running in `-ERC GVCF` or `-ERC BP_RESOLUTION` modes, the confidence threshold\n     is automatically set to 0. This cannot be overridden by the command line. The threshold can be set manually\n     to the desired level in the next step of the workflow (GenotypeGVCFs)</li>\n     <li>We recommend using a list of intervals to speed up analysis. See <a href='https://software.broadinstitute.org/gatk/documentation/article?id=4133'>this document</a> for details.</li>\n </ul>",
            "temporaryFailCodes": [
                3
            ],
            "requirements": [
                {
                    "class": "ShellCommandRequirement"
                },
                {
                    "class": "InlineJavascriptRequirement",
                    "expressionLib": [
                        "/**\n * File of functions to be added to cwl files\n */\n\nfunction generateGATK4BooleanValue(){\n    /**\n     * Boolean types in GATK 4 are expressed on the command line as --<PREFIX> \"true\"/\"false\",\n     * so patch here\n     */\n    if(self === true || self === false){\n        return self.toString()\n    }\n\n    return self;\n}\n\nfunction addTagToArgument(tagObject, argument, prefix){\n    var allTags = Array.isArray(tagObject) ? tagObject.join(\",\") : tagObject;\n    return [prefix + \":\" + allTags, argument];\n}\n\nfunction applyTagsToArgument(prefix, tags){\n    /**\n     * Function to be used in the field valueFrom of File objects to add gatk tags.\n     */\n\n    if(!self){\n        return null;\n    }\n    else if(!tags){\n        return generateArrayCmd(prefix);\n    }\n    else{\n        if(Array.isArray(self)){\n            if(!Array.isArray(tags) || self.length !== tags.length){\n                throw new TypeError(\"Argument '\" + prefix + \"' tag field is invalid\");\n            }\n\n            var value = self.map(function(element, i) {\n                return addTagToArgument(tags[i], element, prefix);\n            }).reduce(function(a, b){return a.concat(b)})\n\n            return value;\n        }\n        else{\n            return addTagToArgument(tags, self, prefix);\n        }\n    }\n}\n\nfunction generateArrayCmd(prefix){\n    /**\n     * Function to be used in the field valueFrom of array objects, so that arrays are optional\n     * and prefixes are handled properly.\n     *\n     * The issue that this solves is documented here:\n     * https://www.biostars.org/p/258414/#260140\n     */\n    if(!self){\n        return null;\n    }\n\n    if(!Array.isArray(self)){\n        self = [self];\n    }\n\n    var output = [];\n    self.forEach(function(element) {\n        output.push(prefix);\n        output.push(element);\n    })\n\n    return output;\n}"
                    ]
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mercury/gatk-4.0.0.0-local-io-wrapper:v4"
                }
            ],
            "inputs": [
                {
                    "doc": "Reference sequence file",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/reference",
                    "type": "File",
                    "inputBinding": {
                        "valueFrom": "$(applyTagsToArgument(\"--reference\", inputs['reference_tags']))"
                    },
                    "secondaryFiles": [
                        ".fai",
                        "^.dict"
                    ]
                },
                {
                    "doc": "BAM/SAM/CRAM file containing reads",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/input",
                    "type": [
                        {
                            "type": "array",
                            "items": "File",
                            "inputBinding": {
                                "valueFrom": "$(null)"
                            }
                        },
                        "File"
                    ],
                    "inputBinding": {
                        "valueFrom": "$(applyTagsToArgument(\"--input\", inputs['input_tags']))"
                    },
                    "secondaryFiles": ".crai"
                },
                {
                    "doc": "Threshold number of ambiguous bases. If null, uses threshold fraction; otherwise, overrides threshold fraction.",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/ambig-filter-bases",
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "prefix": "--ambig-filter-bases"
                    }
                },
                {
                    "doc": "Threshold fraction of ambiguous bases",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/ambig-filter-frac",
                    "type": [
                        "null",
                        "double"
                    ],
                    "inputBinding": {
                        "prefix": "--ambig-filter-frac"
                    }
                },
                {
                    "doc": "Maximum length of fragment (insert size)",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/max-fragment-length",
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "prefix": "--max-fragment-length"
                    }
                },
                {
                    "doc": "Name of the library to keep",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/library",
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "string",
                            "inputBinding": {
                                "valueFrom": "$(null)"
                            }
                        },
                        "string"
                    ],
                    "inputBinding": {
                        "valueFrom": "$(generateArrayCmd(\"--library\"))"
                    }
                },
                {
                    "doc": "Maximum mapping quality to keep (inclusive)",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/maximum-mapping-quality",
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "prefix": "--maximum-mapping-quality"
                    }
                },
                {
                    "doc": "Minimum mapping quality to keep (inclusive)",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/minimum-mapping-quality",
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "prefix": "--minimum-mapping-quality"
                    }
                },
                {
                    "doc": "Allow a read to be filtered out based on having only 1 soft-clipped block. By default, both ends must have a soft-clipped block, setting this flag requires only 1 soft-clipped block",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/dont-require-soft-clips-both-ends",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--dont-require-soft-clips-both-ends",
                        "valueFrom": "$(generateGATK4BooleanValue())"
                    }
                },
                {
                    "doc": "Minimum number of aligned bases",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/filter-too-short",
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "prefix": "--filter-too-short"
                    }
                },
                {
                    "doc": "Platform attribute (PL) to match",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/platform-filter-name",
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "string",
                            "inputBinding": {
                                "valueFrom": "$(null)"
                            }
                        },
                        "string"
                    ],
                    "inputBinding": {
                        "valueFrom": "$(generateArrayCmd(\"--platform-filter-name\"))"
                    }
                },
                {
                    "doc": "Platform unit (PU) to filter out",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/black-listed-lanes",
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "string",
                            "inputBinding": {
                                "valueFrom": "$(null)"
                            }
                        },
                        "string"
                    ],
                    "inputBinding": {
                        "valueFrom": "$(generateArrayCmd(\"--black-listed-lanes\"))"
                    }
                },
                {
                    "doc": "The name of the read group to filter out",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/read-group-black-list",
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "string",
                            "inputBinding": {
                                "valueFrom": "$(null)"
                            }
                        },
                        "string"
                    ],
                    "inputBinding": {
                        "valueFrom": "$(generateArrayCmd(\"--read-group-black-list\"))"
                    }
                },
                {
                    "doc": "The name of the read group to keep",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/keep-read-group",
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "prefix": "--keep-read-group"
                    }
                },
                {
                    "doc": "Keep only reads with length at most equal to the specified value",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/max-read-length",
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "prefix": "--max-read-length"
                    }
                },
                {
                    "doc": "Keep only reads with length at least equal to the specified value",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/min-read-length",
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "prefix": "--min-read-length"
                    }
                },
                {
                    "doc": "Keep only reads with this read name",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/read-name",
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "prefix": "--read-name"
                    }
                },
                {
                    "doc": "Keep only reads on the reverse strand",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/keep-reverse-strand-only",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--keep-reverse-strand-only",
                        "valueFrom": "$(generateGATK4BooleanValue())"
                    }
                },
                {
                    "doc": "The name of the sample(s) to keep, filtering out all others",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/sample",
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "string",
                            "inputBinding": {
                                "valueFrom": "$(null)"
                            }
                        },
                        "string"
                    ],
                    "inputBinding": {
                        "valueFrom": "$(generateArrayCmd(\"--sample\"))"
                    }
                },
                {
                    "doc": "Minimum probability for a locus to be considered active.",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/active-probability-threshold",
                    "type": [
                        "null",
                        "double"
                    ],
                    "inputBinding": {
                        "prefix": "--active-probability-threshold"
                    }
                },
                {
                    "doc": "Output the raw activity profile results in IGV format",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/activity-profile-out-filename",
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "prefix": "--activity-profile-out"
                    }
                },
                {
                    "doc": "If true, adds a PG tag to created SAM/BAM/CRAM files.",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/add-output-sam-program-record",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--add-output-sam-program-record",
                        "valueFrom": "$(generateGATK4BooleanValue())"
                    }
                },
                {
                    "doc": "If true, adds a command line header line to created VCF files.",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/add-output-vcf-command-line",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--add-output-vcf-command-line",
                        "valueFrom": "$(generateGATK4BooleanValue())"
                    }
                },
                {
                    "doc": "Annotate all sites with PLs",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/all-site-pls",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--all-site-pls",
                        "valueFrom": "$(generateGATK4BooleanValue())"
                    }
                },
                {
                    "doc": "The set of alleles at which to genotype when --genotyping_mode is GENOTYPE_GIVEN_ALLELES",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/alleles",
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "valueFrom": "$(applyTagsToArgument(\"--alleles\", inputs['alleles_tags']))"
                    }
                },
                {
                    "type": [
                        "null",
                        "string",
                        {
                            "type": "array",
                            "items": "string"
                        }
                    ],
                    "doc": "A argument to set the tags of 'alleles'",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/alleles_tags"
                },
                {
                    "doc": "Allow graphs that have non-unique kmers in the reference",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/allow-non-unique-kmers-in-ref",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--allow-non-unique-kmers-in-ref",
                        "valueFrom": "$(generateGATK4BooleanValue())"
                    }
                },
                {
                    "doc": "If provided, we will annotate records with the number of alternate alleles that were discovered (but not necessarily genotyped) at a given site",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/annotate-with-num-discovered-alleles",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--annotate-with-num-discovered-alleles",
                        "valueFrom": "$(generateGATK4BooleanValue())"
                    }
                },
                {
                    "doc": "One or more specific annotations to add to variant calls",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/annotation",
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "string",
                            "inputBinding": {
                                "valueFrom": "$(null)"
                            }
                        },
                        "string"
                    ],
                    "inputBinding": {
                        "valueFrom": "$(generateArrayCmd(\"--annotation\"))"
                    }
                },
                {
                    "doc": "One or more groups of annotations to apply to variant calls",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/annotation-group",
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "string",
                            "inputBinding": {
                                "valueFrom": "$(null)"
                            }
                        },
                        "string"
                    ],
                    "inputBinding": {
                        "valueFrom": "$(generateArrayCmd(\"--annotation-group\"))"
                    }
                },
                {
                    "doc": "One or more specific annotations to exclude from variant calls",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/annotations-to-exclude",
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "string",
                            "inputBinding": {
                                "valueFrom": "$(null)"
                            }
                        },
                        "string"
                    ],
                    "inputBinding": {
                        "valueFrom": "$(generateArrayCmd(\"--annotations-to-exclude\"))"
                    }
                },
                {
                    "doc": "read one or more arguments files and add them to the command line",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/arguments_file",
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "File",
                            "inputBinding": {
                                "valueFrom": "$(null)"
                            }
                        },
                        "File"
                    ],
                    "inputBinding": {
                        "valueFrom": "$(applyTagsToArgument(\"--arguments_file\", inputs['arguments_file_tags']))"
                    }
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": [
                                "string",
                                {
                                    "type": "array",
                                    "items": "string"
                                }
                            ]
                        }
                    ],
                    "doc": "A argument to set the tags of 'arguments_file'",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/arguments_file_tags"
                },
                {
                    "doc": "Output the assembly region to this IGV formatted file",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/assembly-region-out-filename",
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "prefix": "--assembly-region-out"
                    }
                },
                {
                    "doc": "Number of additional bases of context to include around each assembly region",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/assembly-region-padding",
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "prefix": "--assembly-region-padding"
                    }
                },
                {
                    "doc": "File to which assembled haplotypes should be written",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/bam-output-filename",
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "prefix": "--bam-output"
                    }
                },
                {
                    "doc": "Which haplotypes should be written to the BAM",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/bam-writer-type",
                    "type": [
                        "null",
                        {
                            "type": "enum",
                            "symbols": [
                                "#HaplotypeCaller.cwl/HaplotypeCaller/bam-writer-type/ALL_POSSIBLE_HAPLOTYPES",
                                "#HaplotypeCaller.cwl/HaplotypeCaller/bam-writer-type/CALLED_HAPLOTYPES"
                            ]
                        }
                    ],
                    "inputBinding": {
                        "prefix": "--bam-writer-type"
                    }
                },
                {
                    "doc": "Base qualities below this threshold will be reduced to the minimum (6)",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/base-quality-score-threshold",
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "prefix": "--base-quality-score-threshold"
                    }
                },
                {
                    "doc": "Size of the cloud-only prefetch buffer (in MB; 0 to disable). Defaults to cloudPrefetchBuffer if unset.",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/cloud-index-prefetch-buffer",
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "prefix": "--cloud-index-prefetch-buffer"
                    }
                },
                {
                    "doc": "Size of the cloud-only prefetch buffer (in MB; 0 to disable).",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/cloud-prefetch-buffer",
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "prefix": "--cloud-prefetch-buffer"
                    }
                },
                {
                    "doc": "Comparison VCF file(s)",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/comp",
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "File",
                            "inputBinding": {
                                "valueFrom": "$(null)"
                            }
                        },
                        "File"
                    ],
                    "inputBinding": {
                        "valueFrom": "$(applyTagsToArgument(\"--comp\", inputs['comp_tags']))"
                    }
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": [
                                "string",
                                {
                                    "type": "array",
                                    "items": "string"
                                }
                            ]
                        }
                    ],
                    "doc": "A argument to set the tags of 'comp'",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/comp_tags"
                },
                {
                    "doc": "1000G consensus mode",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/consensus",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--consensus",
                        "valueFrom": "$(generateGATK4BooleanValue())"
                    }
                },
                {
                    "doc": "Tab-separated File containing fraction of contamination in sequencing data (per sample) to aggressively remove. Format should be \"<SampleID><TAB><Contamination>\" (Contamination is double) per line; No header.",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/contamination-fraction-per-sample-file",
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "valueFrom": "$(applyTagsToArgument(\"--contamination-fraction-per-sample-file\", inputs['contamination-fraction-per-sample-file_tags']))"
                    }
                },
                {
                    "type": [
                        "null",
                        "string",
                        {
                            "type": "array",
                            "items": "string"
                        }
                    ],
                    "doc": "A argument to set the tags of 'contamination-fraction-per-sample-file'",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/contamination-fraction-per-sample-file_tags"
                },
                {
                    "doc": "Fraction of contamination in sequencing data (for all samples) to aggressively remove",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/contamination-fraction-to-filter",
                    "type": [
                        "null",
                        "double"
                    ],
                    "inputBinding": {
                        "prefix": "--contamination-fraction-to-filter"
                    }
                },
                {
                    "doc": "If true, create a BAM/CRAM index when writing a coordinate-sorted BAM/CRAM file.",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/create-output-bam-index",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--create-output-bam-index",
                        "valueFrom": "$(generateGATK4BooleanValue())"
                    }
                },
                {
                    "doc": "If true, create a MD5 digest for any BAM/SAM/CRAM file created",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/create-output-bam-md5",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--create-output-bam-md5",
                        "valueFrom": "$(generateGATK4BooleanValue())"
                    }
                },
                {
                    "doc": "If true, create a VCF index when writing a coordinate-sorted VCF file.",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/create-output-variant-index",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--create-output-variant-index",
                        "valueFrom": "$(generateGATK4BooleanValue())"
                    }
                },
                {
                    "doc": "If true, create a a MD5 digest any VCF file created.",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/create-output-variant-md5",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--create-output-variant-md5",
                        "valueFrom": "$(generateGATK4BooleanValue())"
                    }
                },
                {
                    "doc": "dbSNP file",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/dbsnp",
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "valueFrom": "$(applyTagsToArgument(\"--dbsnp\", inputs['dbsnp_tags']))"
                    }
                },
                {
                    "type": [
                        "null",
                        "string",
                        {
                            "type": "array",
                            "items": "string"
                        }
                    ],
                    "doc": "A argument to set the tags of 'dbsnp'",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/dbsnp_tags"
                },
                {
                    "doc": "Print out very verbose debug information about each triggering active region",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/debug",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--debug",
                        "valueFrom": "$(generateGATK4BooleanValue())"
                    }
                },
                {
                    "doc": "If true, don't cache bam indexes, this will reduce memory requirements but may harm performance if many intervals are specified.  Caching is automatically disabled if there are no intervals specified.",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/disable-bam-index-caching",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--disable-bam-index-caching",
                        "valueFrom": "$(generateGATK4BooleanValue())"
                    }
                },
                {
                    "doc": "Don't skip calculations in ActiveRegions with no variants",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/disable-optimizations",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--disable-optimizations",
                        "valueFrom": "$(generateGATK4BooleanValue())"
                    }
                },
                {
                    "doc": "Read filters to be disabled before analysis",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/disable-read-filter",
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "string",
                            "inputBinding": {
                                "valueFrom": "$(null)"
                            }
                        },
                        "string"
                    ],
                    "inputBinding": {
                        "valueFrom": "$(generateArrayCmd(\"--disable-read-filter\"))"
                    }
                },
                {
                    "doc": "If specified, do not check the sequence dictionaries from our inputs for compatibility. Use at your own risk!",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/disable-sequence-dictionary-validation",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--disable-sequence-dictionary-validation",
                        "valueFrom": "$(generateGATK4BooleanValue())"
                    }
                },
                {
                    "doc": "Disable all tool default read filters",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/disable-tool-default-read-filters",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--disable-tool-default-read-filters",
                        "valueFrom": "$(generateGATK4BooleanValue())"
                    }
                },
                {
                    "doc": "Disable physical phasing",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/do-not-run-physical-phasing",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--do-not-run-physical-phasing",
                        "valueFrom": "$(generateGATK4BooleanValue())"
                    }
                },
                {
                    "doc": "Disable iterating over kmer sizes when graph cycles are detected",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/dont-increase-kmer-sizes-for-cycles",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--dont-increase-kmer-sizes-for-cycles",
                        "valueFrom": "$(generateGATK4BooleanValue())"
                    }
                },
                {
                    "doc": "If specified, we will not trim down the active region from the full region (active + extension) to just the active interval for genotyping",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/dont-trim-active-regions",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--dont-trim-active-regions",
                        "valueFrom": "$(generateGATK4BooleanValue())"
                    }
                },
                {
                    "doc": "Do not analyze soft clipped bases in the reads",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/dont-use-soft-clipped-bases",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--dont-use-soft-clipped-bases",
                        "valueFrom": "$(generateGATK4BooleanValue())"
                    }
                },
                {
                    "doc": "Mode for emitting reference confidence scores",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/emit-ref-confidence",
                    "type": [
                        "null",
                        {
                            "type": "enum",
                            "symbols": [
                                "#HaplotypeCaller.cwl/HaplotypeCaller/emit-ref-confidence/NONE",
                                "#HaplotypeCaller.cwl/HaplotypeCaller/emit-ref-confidence/BP_RESOLUTION",
                                "#HaplotypeCaller.cwl/HaplotypeCaller/emit-ref-confidence/GVCF"
                            ]
                        }
                    ],
                    "inputBinding": {
                        "prefix": "--emit-ref-confidence"
                    }
                },
                {
                    "doc": "One or more genomic intervals to exclude from processing",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/exclude-intervals",
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "string",
                            "inputBinding": {
                                "valueFrom": "$(null)"
                            }
                        },
                        "string"
                    ],
                    "inputBinding": {
                        "valueFrom": "$(generateArrayCmd(\"--exclude-intervals\"))"
                    }
                },
                {
                    "doc": "A configuration file to use with the GATK.",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/gatk-config-file",
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "valueFrom": "$(applyTagsToArgument(\"--gatk-config-file\", inputs['gatk-config-file_tags']))"
                    }
                },
                {
                    "type": [
                        "null",
                        "string",
                        {
                            "type": "array",
                            "items": "string"
                        }
                    ],
                    "doc": "A argument to set the tags of 'gatk-config-file'",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/gatk-config-file_tags"
                },
                {
                    "doc": "If the GCS bucket channel errors out, how many times it will attempt to re-initiate the connection",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/gcs-max-retries",
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "prefix": "--gcs-max-retries"
                    }
                },
                {
                    "doc": "Specifies how to determine the alternate alleles to use for genotyping",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/genotyping-mode",
                    "type": [
                        "null",
                        {
                            "type": "enum",
                            "symbols": [
                                "#HaplotypeCaller.cwl/HaplotypeCaller/genotyping-mode/DISCOVERY",
                                "#HaplotypeCaller.cwl/HaplotypeCaller/genotyping-mode/GENOTYPE_GIVEN_ALLELES"
                            ]
                        }
                    ],
                    "inputBinding": {
                        "prefix": "--genotyping-mode"
                    }
                },
                {
                    "doc": "Write debug assembly graph information to this file",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/graph-output-filename",
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "prefix": "--graph-output"
                    }
                },
                {
                    "doc": "Exclusive upper bounds for reference confidence GQ bands (must be in [1, 100] and specified in increasing order)",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/gvcf-gq-bands",
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "int",
                            "inputBinding": {
                                "valueFrom": "$(null)"
                            }
                        },
                        "int"
                    ],
                    "inputBinding": {
                        "valueFrom": "$(generateArrayCmd(\"--gvcf-gq-bands\"))"
                    }
                },
                {
                    "doc": "Heterozygosity value used to compute prior likelihoods for any locus.  See the GATKDocs for full details on the meaning of this population genetics concept",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/heterozygosity",
                    "type": [
                        "null",
                        "double"
                    ],
                    "inputBinding": {
                        "prefix": "--heterozygosity"
                    }
                },
                {
                    "doc": "Standard deviation of eterozygosity for SNP and indel calling.",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/heterozygosity-stdev",
                    "type": [
                        "null",
                        "double"
                    ],
                    "inputBinding": {
                        "prefix": "--heterozygosity-stdev"
                    }
                },
                {
                    "doc": "Heterozygosity for indel calling.  See the GATKDocs for heterozygosity for full details on the meaning of this population genetics concept",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/indel-heterozygosity",
                    "type": [
                        "null",
                        "double"
                    ],
                    "inputBinding": {
                        "prefix": "--indel-heterozygosity"
                    }
                },
                {
                    "doc": "The size of an indel to check for in the reference model",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/indel-size-to-eliminate-in-ref-model",
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "prefix": "--indel-size-to-eliminate-in-ref-model"
                    }
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": [
                                "string",
                                {
                                    "type": "array",
                                    "items": "string"
                                }
                            ]
                        }
                    ],
                    "doc": "A argument to set the tags of 'input'",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/input_tags"
                },
                {
                    "doc": "Input prior for calls",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/input-prior",
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "double",
                            "inputBinding": {
                                "valueFrom": "$(null)"
                            }
                        },
                        "double"
                    ],
                    "inputBinding": {
                        "valueFrom": "$(generateArrayCmd(\"--input-prior\"))"
                    }
                },
                {
                    "doc": "Amount of padding (in bp) to add to each interval you are excluding.",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/interval-exclusion-padding",
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "prefix": "--interval-exclusion-padding"
                    }
                },
                {
                    "doc": "Interval merging rule for abutting intervals",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/interval-merging-rule",
                    "type": [
                        "null",
                        {
                            "type": "enum",
                            "symbols": [
                                "#HaplotypeCaller.cwl/HaplotypeCaller/interval-merging-rule/ALL",
                                "#HaplotypeCaller.cwl/HaplotypeCaller/interval-merging-rule/OVERLAPPING_ONLY"
                            ]
                        }
                    ],
                    "inputBinding": {
                        "prefix": "--interval-merging-rule"
                    }
                },
                {
                    "doc": "Amount of padding (in bp) to add to each interval you are including.",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/interval-padding",
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "prefix": "--interval-padding"
                    }
                },
                {
                    "doc": "Set merging approach to use for combining interval inputs",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/interval-set-rule",
                    "type": [
                        "null",
                        {
                            "type": "enum",
                            "symbols": [
                                "#HaplotypeCaller.cwl/HaplotypeCaller/interval-set-rule/UNION",
                                "#HaplotypeCaller.cwl/HaplotypeCaller/interval-set-rule/INTERSECTION"
                            ]
                        }
                    ],
                    "inputBinding": {
                        "prefix": "--interval-set-rule"
                    }
                },
                {
                    "doc": "One or more genomic intervals over which to operate",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/intervals",
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": [
                                "File",
                                "string"
                            ],
                            "inputBinding": {
                                "valueFrom": "$(null)"
                            }
                        },
                        "File",
                        "string"
                    ],
                    "inputBinding": {
                        "valueFrom": "$(applyTagsToArgument(\"--intervals\", inputs['intervals_tags']))"
                    }
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": [
                                "string",
                                {
                                    "type": "array",
                                    "items": "string"
                                }
                            ]
                        }
                    ],
                    "doc": "A argument to set the tags of 'intervals'",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/intervals_tags"
                },
                {
                    "doc": "Kmer size to use in the read threading assembler",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/kmer-size",
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "int",
                            "inputBinding": {
                                "valueFrom": "$(null)"
                            }
                        },
                        "int"
                    ],
                    "inputBinding": {
                        "valueFrom": "$(generateArrayCmd(\"--kmer-size\"))"
                    }
                },
                {
                    "doc": "Lenient processing of VCF files",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/lenient",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--lenient",
                        "valueFrom": "$(generateGATK4BooleanValue())"
                    }
                },
                {
                    "doc": "Maximum number of alternate alleles to genotype",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/max-alternate-alleles",
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "prefix": "--max-alternate-alleles"
                    }
                },
                {
                    "doc": "Maximum size of an assembly region",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/max-assembly-region-size",
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "prefix": "--max-assembly-region-size"
                    }
                },
                {
                    "doc": "Maximum number of genotypes to consider at any site",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/max-genotype-count",
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "prefix": "--max-genotype-count"
                    }
                },
                {
                    "doc": "Maximum number of haplotypes to consider for your population",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/max-num-haplotypes-in-population",
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "prefix": "--max-num-haplotypes-in-population"
                    }
                },
                {
                    "doc": "Upper limit on how many bases away probability mass can be moved around when calculating the boundaries between active and inactive assembly regions",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/max-prob-propagation-distance",
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "prefix": "--max-prob-propagation-distance"
                    }
                },
                {
                    "doc": "Maximum number of reads to retain per alignment start position. Reads above this threshold will be downsampled. Set to 0 to disable.",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/max-reads-per-alignment-start",
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "prefix": "--max-reads-per-alignment-start"
                    }
                },
                {
                    "doc": "Minimum size of an assembly region",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/min-assembly-region-size",
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "prefix": "--min-assembly-region-size"
                    }
                },
                {
                    "doc": "Minimum base quality required to consider a base for calling",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/min-base-quality-score",
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "prefix": "--min-base-quality-score"
                    }
                },
                {
                    "doc": "Minimum length of a dangling branch to attempt recovery",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/min-dangling-branch-length",
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "prefix": "--min-dangling-branch-length"
                    }
                },
                {
                    "doc": "Minimum support to not prune paths in the graph",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/min-pruning",
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "prefix": "--min-pruning"
                    }
                },
                {
                    "doc": "How many threads should a native pairHMM implementation use",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/native-pair-hmm-threads",
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "prefix": "--native-pair-hmm-threads"
                    }
                },
                {
                    "doc": "use double precision in the native pairHmm. This is slower but matches the java implementation better",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/native-pair-hmm-use-double-precision",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--native-pair-hmm-use-double-precision",
                        "valueFrom": "$(generateGATK4BooleanValue())"
                    }
                },
                {
                    "doc": "Number of samples that must pass the minPruning threshold",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/num-pruning-samples",
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "prefix": "--num-pruning-samples"
                    }
                },
                {
                    "doc": "File to which variants should be written",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/output-filename",
                    "type": "string",
                    "inputBinding": {
                        "prefix": "--output"
                    }
                },
                {
                    "doc": "Specifies which type of calls we should output",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/output-mode",
                    "type": [
                        "null",
                        {
                            "type": "enum",
                            "symbols": [
                                "#HaplotypeCaller.cwl/HaplotypeCaller/output-mode/EMIT_VARIANTS_ONLY",
                                "#HaplotypeCaller.cwl/HaplotypeCaller/output-mode/EMIT_ALL_CONFIDENT_SITES",
                                "#HaplotypeCaller.cwl/HaplotypeCaller/output-mode/EMIT_ALL_SITES"
                            ]
                        }
                    ],
                    "inputBinding": {
                        "prefix": "--output-mode"
                    }
                },
                {
                    "doc": "Flat gap continuation penalty for use in the Pair HMM",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/pair-hmm-gap-continuation-penalty",
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "prefix": "--pair-hmm-gap-continuation-penalty"
                    }
                },
                {
                    "doc": "The PCR indel model to use",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/pcr-indel-model",
                    "type": [
                        "null",
                        {
                            "type": "enum",
                            "symbols": [
                                "#HaplotypeCaller.cwl/HaplotypeCaller/pcr-indel-model/NONE",
                                "#HaplotypeCaller.cwl/HaplotypeCaller/pcr-indel-model/HOSTILE",
                                "#HaplotypeCaller.cwl/HaplotypeCaller/pcr-indel-model/AGGRESSIVE",
                                "#HaplotypeCaller.cwl/HaplotypeCaller/pcr-indel-model/CONSERVATIVE"
                            ]
                        }
                    ],
                    "inputBinding": {
                        "prefix": "--pcr-indel-model"
                    }
                },
                {
                    "doc": "The global assumed mismapping rate for reads",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/phred-scaled-global-read-mismapping-rate",
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "prefix": "--phred-scaled-global-read-mismapping-rate"
                    }
                },
                {
                    "doc": "Whether to suppress job-summary info on System.err.",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/QUIET",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--QUIET",
                        "valueFrom": "$(generateGATK4BooleanValue())"
                    }
                },
                {
                    "doc": "Read filters to be applied before analysis",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/read-filter",
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "string",
                            "inputBinding": {
                                "valueFrom": "$(null)"
                            }
                        },
                        "string"
                    ],
                    "inputBinding": {
                        "valueFrom": "$(generateArrayCmd(\"--read-filter\"))"
                    }
                },
                {
                    "doc": "Indices to use for the read inputs. If specified, an index must be provided for every read input and in the same order as the read inputs. If this argument is not specified, the path to the index for each input will be inferred automatically.",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/read-index",
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "string",
                            "inputBinding": {
                                "valueFrom": "$(null)"
                            }
                        },
                        "string"
                    ],
                    "inputBinding": {
                        "valueFrom": "$(generateArrayCmd(\"--read-index\"))"
                    }
                },
                {
                    "doc": "Validation stringency for all SAM/BAM/CRAM/SRA files read by this program.  The default stringency value SILENT can improve performance when processing a BAM file in which variable-length data (read, qualities, tags) do not otherwise need to be decoded.",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/read-validation-stringency",
                    "type": [
                        "null",
                        {
                            "type": "enum",
                            "symbols": [
                                "#HaplotypeCaller.cwl/HaplotypeCaller/read-validation-stringency/STRICT",
                                "#HaplotypeCaller.cwl/HaplotypeCaller/read-validation-stringency/LENIENT",
                                "#HaplotypeCaller.cwl/HaplotypeCaller/read-validation-stringency/SILENT"
                            ]
                        }
                    ],
                    "inputBinding": {
                        "prefix": "--read-validation-stringency"
                    }
                },
                {
                    "doc": "This argument is deprecated since version 3.3",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/recover-dangling-heads",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--recover-dangling-heads",
                        "valueFrom": "$(generateGATK4BooleanValue())"
                    }
                },
                {
                    "type": [
                        "null",
                        "string",
                        {
                            "type": "array",
                            "items": "string"
                        }
                    ],
                    "doc": "A argument to set the tags of 'reference'",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/reference_tags"
                },
                {
                    "doc": "Name of single sample to use from a multi-sample bam",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/sample-name",
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "prefix": "--sample-name"
                    }
                },
                {
                    "doc": "Ploidy (number of chromosomes) per sample. For pooled data, set to (Number of samples in each pool * Sample Ploidy).",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/sample-ploidy",
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "prefix": "--sample-ploidy"
                    }
                },
                {
                    "doc": "Output traversal statistics every time this many seconds elapse",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/seconds-between-progress-updates",
                    "type": [
                        "null",
                        "double"
                    ],
                    "inputBinding": {
                        "prefix": "--seconds-between-progress-updates"
                    }
                },
                {
                    "doc": "Use the given sequence dictionary as the master/canonical sequence dictionary.  Must be a .dict file.",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/sequence-dictionary",
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "valueFrom": "$(applyTagsToArgument(\"--sequence-dictionary\", inputs['sequence-dictionary_tags']))"
                    }
                },
                {
                    "type": [
                        "null",
                        "string",
                        {
                            "type": "array",
                            "items": "string"
                        }
                    ],
                    "doc": "A argument to set the tags of 'sequence-dictionary'",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/sequence-dictionary_tags"
                },
                {
                    "doc": "display hidden arguments",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/showHidden",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--showHidden",
                        "valueFrom": "$(generateGATK4BooleanValue())"
                    }
                },
                {
                    "doc": "Which Smith-Waterman implementation to use, generally FASTEST_AVAILABLE is the right choice",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/smith-waterman",
                    "type": [
                        "null",
                        {
                            "type": "enum",
                            "symbols": [
                                "#HaplotypeCaller.cwl/HaplotypeCaller/smith-waterman/FASTEST_AVAILABLE",
                                "#HaplotypeCaller.cwl/HaplotypeCaller/smith-waterman/AVX_ENABLED",
                                "#HaplotypeCaller.cwl/HaplotypeCaller/smith-waterman/JAVA"
                            ]
                        }
                    ],
                    "inputBinding": {
                        "prefix": "--smith-waterman"
                    }
                },
                {
                    "doc": "The minimum phred-scaled confidence threshold at which variants should be called",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/standard-min-confidence-threshold-for-calling",
                    "type": [
                        "null",
                        "double"
                    ],
                    "inputBinding": {
                        "prefix": "--standard-min-confidence-threshold-for-calling"
                    }
                },
                {
                    "doc": "Undocumented option",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/TMP_DIR",
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "File",
                            "inputBinding": {
                                "valueFrom": "$(null)"
                            }
                        },
                        "File"
                    ],
                    "inputBinding": {
                        "valueFrom": "$(applyTagsToArgument(\"--TMP_DIR\", inputs['TMP_DIR_tags']))"
                    }
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": [
                                "string",
                                {
                                    "type": "array",
                                    "items": "string"
                                }
                            ]
                        }
                    ],
                    "doc": "A argument to set the tags of 'TMP_DIR'",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/TMP_DIR_tags"
                },
                {
                    "doc": "Use additional trigger on variants found in an external alleles file",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/use-alleles-trigger",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--use-alleles-trigger",
                        "valueFrom": "$(generateGATK4BooleanValue())"
                    }
                },
                {
                    "doc": "Use the contamination-filtered read maps for the purposes of annotating variants",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/use-filtered-reads-for-annotations",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--use-filtered-reads-for-annotations",
                        "valueFrom": "$(generateGATK4BooleanValue())"
                    }
                },
                {
                    "doc": "Whether to use the JdkDeflater (as opposed to IntelDeflater)",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/use-jdk-deflater",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--use-jdk-deflater",
                        "valueFrom": "$(generateGATK4BooleanValue())"
                    }
                },
                {
                    "doc": "Whether to use the JdkInflater (as opposed to IntelInflater)",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/use-jdk-inflater",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--use-jdk-inflater",
                        "valueFrom": "$(generateGATK4BooleanValue())"
                    }
                },
                {
                    "doc": "If provided, we will use the new AF model instead of the so-called exact model",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/use-new-qual-calculator",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--use-new-qual-calculator",
                        "valueFrom": "$(generateGATK4BooleanValue())"
                    }
                },
                {
                    "doc": "Control verbosity of logging.",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/verbosity",
                    "type": [
                        "null",
                        {
                            "type": "enum",
                            "symbols": [
                                "#HaplotypeCaller.cwl/HaplotypeCaller/verbosity/ERROR",
                                "#HaplotypeCaller.cwl/HaplotypeCaller/verbosity/WARNING",
                                "#HaplotypeCaller.cwl/HaplotypeCaller/verbosity/INFO",
                                "#HaplotypeCaller.cwl/HaplotypeCaller/verbosity/DEBUG"
                            ]
                        }
                    ],
                    "inputBinding": {
                        "prefix": "--verbosity"
                    }
                },
                {
                    "doc": "display the version number for this tool",
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/version",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--version",
                        "valueFrom": "$(generateGATK4BooleanValue())"
                    }
                }
            ],
            "outputs": [
                {
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/activity-profile-out",
                    "doc": "Output file from corresponding to the input argument activity-profile-out-filename",
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "$(inputs['activity-profile-out-filename'])"
                    }
                },
                {
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/assembly-region-out",
                    "doc": "Output file from corresponding to the input argument assembly-region-out-filename",
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "$(inputs['assembly-region-out-filename'])"
                    }
                },
                {
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/bam-output",
                    "doc": "Output file from corresponding to the input argument bam-output-filename",
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "$(inputs['bam-output-filename'])"
                    }
                },
                {
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/bam-index",
                    "doc": "index file generated if create-output-bam-index is true",
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": [
                            "$(inputs['output-filename']).idx",
                            "$(inputs['output-filename']).tbi"
                        ]
                    }
                },
                {
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/bam-md5",
                    "doc": "md5 file generated if create-output-bam-md5 is true",
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "$(inputs['output-filename']).md5"
                    }
                },
                {
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/variant-index",
                    "doc": "index file generated if create-output-variant-index is true",
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": [
                            "$(inputs['output-filename']).idx",
                            "$(inputs['output-filename']).tbi"
                        ]
                    }
                },
                {
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/variant-md5",
                    "doc": "md5 file generated if create-output-variant-md5 is true",
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "$(inputs['output-filename']).md5"
                    }
                },
                {
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/graph-output",
                    "doc": "Output file from corresponding to the input argument graph-output-filename",
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "$(inputs['graph-output-filename'])"
                    }
                },
                {
                    "id": "#HaplotypeCaller.cwl/HaplotypeCaller/output",
                    "doc": "Output file from corresponding to the input argument output-filename",
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs['output-filename'])"
                    }
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "dockerPull": "mercury/get-read-group-caps:v3",
                    "class": "DockerRequirement"
                }
            ],
            "baseCommand": [
                "python",
                "/get_read_group_caps.py"
            ],
            "inputs": [
                {
                    "id": "#get_read_group_caps.cwl/read_groups",
                    "type": {
                        "type": "array",
                        "items": "string",
                        "inputBinding": {
                            "prefix": "--read_groups"
                        }
                    }
                },
                {
                    "id": "#get_read_group_caps.cwl/verify_bam_id_files",
                    "type": {
                        "type": "array",
                        "items": "File",
                        "inputBinding": {
                            "prefix": "--verify_bam_id_files"
                        }
                    }
                }
            ],
            "outputs": [
                {
                    "id": "#get_read_group_caps.cwl/read_group_caps_file",
                    "type": "File",
                    "outputBinding": {
                        "glob": "caps_file"
                    }
                }
            ],
            "id": "#get_read_group_caps.cwl"
        },
        {
            "class": "CommandLineTool",
            "hints": [
                {
                    "dockerPull": "mercury/bed-to-interval-list:v1",
                    "class": "DockerRequirement"
                }
            ],
            "baseCommand": [
                "python",
                "/bed_to_il.py"
            ],
            "inputs": [
                {
                    "id": "#bed_to_interval_list.cwl/input",
                    "type": "File",
                    "inputBinding": {
                        "prefix": "--input"
                    }
                },
                {
                    "id": "#bed_to_interval_list.cwl/header",
                    "type": "File",
                    "inputBinding": {
                        "prefix": "--header"
                    }
                }
            ],
            "outputs": [
                {
                    "id": "#bed_to_interval_list.cwl/interval_list",
                    "type": "File",
                    "outputBinding": {
                        "glob": "output.bed"
                    }
                }
            ],
            "id": "#bed_to_interval_list.cwl"
        },
        {
            "class": "CommandLineTool",
            "hints": [
                {
                    "dockerPull": "mercury/interval-list-to-bed:v1",
                    "class": "DockerRequirement"
                }
            ],
            "baseCommand": [
                "python",
                "/il_to_bed.py"
            ],
            "inputs": [
                {
                    "id": "#interval_list_to_bed.cwl/input",
                    "type": "File",
                    "inputBinding": {
                        "prefix": "--input"
                    }
                }
            ],
            "outputs": [
                {
                    "id": "#interval_list_to_bed.cwl/bed_file",
                    "type": "File",
                    "outputBinding": {
                        "glob": "output.bed"
                    }
                },
                {
                    "id": "#interval_list_to_bed.cwl/header",
                    "type": "File",
                    "outputBinding": {
                        "glob": "header.txt"
                    }
                }
            ],
            "id": "#interval_list_to_bed.cwl"
        },
        {
            "class": "CommandLineTool",
            "baseCommand": [
                "bash",
                "/interval_list_to_json.sh"
            ],
            "hints": [
                {
                    "dockerPull": "mercury/interval-list-to-json:v1",
                    "class": "DockerRequirement"
                }
            ],
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "stdout": "stdout_file",
            "inputs": [
                {
                    "id": "#interval_list_to_json.cwl/interval_list_file",
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    }
                }
            ],
            "outputs": [
                {
                    "id": "#interval_list_to_json.cwl/list_of_intervals",
                    "type": {
                        "type": "array",
                        "items": "string"
                    },
                    "outputBinding": {
                        "glob": "stdout_file",
                        "loadContents": true,
                        "outputEval": "$(JSON.parse(self[0].contents))"
                    }
                }
            ],
            "id": "#interval_list_to_json.cwl"
        },
        {
            "class": "CommandLineTool",
            "baseCommand": [
                "bash",
                "-c"
            ],
            "requirements": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mercury/samtools-1.6:v2"
                },
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "arguments": [
                "samtools view -H $(inputs.cram.path) | awk 'BEGIN {\n  FS=\"\\\\t\";\n} /^@RG/ {\n  for(i=1;i<=NF;i++) {\n    if($i~/^ID:/) {\n      print substr($i,4);\n    }\n  }\n}' > $(inputs.filename)\n"
            ],
            "inputs": [
                {
                    "type": "File",
                    "doc": "Input file with header to be simplified\n",
                    "id": "#list_rgs.cwl/cram"
                },
                {
                    "type": "string",
                    "default": "rg_list.sam",
                    "doc": "Output file name of rg list\n",
                    "id": "#list_rgs.cwl/filename"
                }
            ],
            "outputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "string"
                    },
                    "outputBinding": {
                        "loadContents": true,
                        "glob": "$(inputs.filename)",
                        "outputEval": "$(self[0].contents.split(\"\\n\").slice(0, -1))"
                    },
                    "id": "#list_rgs.cwl/rg_values"
                }
            ],
            "id": "#list_rgs.cwl"
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mercury/samtools-1.6:v2"
                },
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "InitialWorkDirRequirement",
                    "listing": [
                        {
                            "entry": "$(inputs.fasta)",
                            "entryname": "$(inputs.fasta.path.split('/').slice(-1)[0])"
                        }
                    ]
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "prefix": "-a"
                    },
                    "id": "#samtools-dict.cwl/assembly"
                },
                {
                    "type": "File",
                    "doc": "<file.fa|file.fa.gz>",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#samtools-dict.cwl/fasta"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "-H"
                    },
                    "id": "#samtools-dict.cwl/no-header"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "-o"
                    },
                    "id": "#samtools-dict.cwl/output"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "prefix": "-s"
                    },
                    "id": "#samtools-dict.cwl/species"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "prefix": "-u"
                    },
                    "id": "#samtools-dict.cwl/uri"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.output)"
                    },
                    "id": "#samtools-dict.cwl/fasta_dict"
                }
            ],
            "baseCommand": [
                "samtools",
                "dict"
            ],
            "id": "#samtools-dict.cwl"
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mercury/samtools-1.6:v2"
                },
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "InitialWorkDirRequirement",
                    "listing": [
                        {
                            "entry": "$(inputs.fasta)",
                            "entryname": "$(inputs.fasta.basename)"
                        }
                    ]
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "doc": "<file.fa|file.fa.gz>",
                    "id": "#samtools-faidx.cwl/fasta"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 2
                    },
                    "id": "#samtools-faidx.cwl/region"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.fasta.basename).fai"
                    },
                    "id": "#samtools-faidx.cwl/fasta_index"
                }
            ],
            "baseCommand": [
                "samtools",
                "faidx"
            ],
            "arguments": [
                {
                    "valueFrom": "$(inputs.fasta.basename)",
                    "position": 1
                }
            ],
            "id": "#samtools-faidx.cwl"
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "dockerPull": "mercury/samtools-fastaref",
                    "class": "DockerRequirement"
                },
                {
                    "envDef": [
                        {
                            "envValue": "$(inputs.ref_path_dir.path)/%2s/%2s/%s",
                            "envName": "REF_PATH"
                        }
                    ],
                    "class": "EnvVarRequirement"
                }
            ],
            "baseCommand": [
                "samtools",
                "fastaref"
            ],
            "inputs": [
                {
                    "id": "#samtools-fastaref.cwl/output_file_name",
                    "doc": "Output file name",
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "reference.fa",
                    "inputBinding": {
                        "prefix": "-o"
                    }
                },
                {
                    "id": "#samtools-fastaref.cwl/keys",
                    "doc": "Output the specified keys into the fasta file",
                    "inputBinding": {
                        "prefix": "-k",
                        "itemSeparator": ","
                    },
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "string"
                        }
                    ]
                },
                {
                    "id": "#samtools-fastaref.cwl/ref_path_dir",
                    "type": "Directory"
                },
                {
                    "id": "#samtools-fastaref.cwl/max_line_length",
                    "doc": "Maximum length of outputted lines",
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "prefix": "-l"
                    }
                },
                {
                    "id": "#samtools-fastaref.cwl/input",
                    "doc": "Input sam/bam/cram file",
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    }
                }
            ],
            "outputs": [
                {
                    "id": "#samtools-fastaref.cwl/reference_fasta",
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.output_file_name)"
                    }
                }
            ],
            "id": "#samtools-fastaref.cwl"
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mercury/samtools-1.6:v2"
                },
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "doc": "Generate BAI-format index for BAM files [default]",
                    "inputBinding": {
                        "prefix": "-b"
                    },
                    "id": "#samtools-index.cwl/generate_bai_index"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "doc": "Generate CSI-format index for BAM files",
                    "inputBinding": {
                        "prefix": "-c"
                    },
                    "id": "#samtools-index.cwl/generate_csi_index"
                },
                {
                    "type": "File",
                    "doc": "Input bam file.",
                    "inputBinding": {
                        "position": 0
                    },
                    "id": "#samtools-index.cwl/input"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "prefix": "-m"
                    },
                    "id": "#samtools-index.cwl/minimum_interval_size"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "prefix": "-@"
                    },
                    "id": "#samtools-index.cwl/number_of_threads"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "",
                    "inputBinding": {
                        "position": 1,
                        "valueFrom": "$(self || inputs.input.basename + \".crai\")"
                    },
                    "doc": "Filename of the the output file",
                    "id": "#samtools-index.cwl/output_filename"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.output_filename || inputs.input.basename + \".crai\")"
                    },
                    "id": "#samtools-index.cwl/cram_index"
                }
            ],
            "baseCommand": [
                "samtools",
                "index"
            ],
            "id": "#samtools-index.cwl"
        },
        {
            "class": "CommandLineTool",
            "hints": [
                {
                    "dockerPull": "mercury/samtools-seq_cache_populate",
                    "class": "DockerRequirement"
                }
            ],
            "baseCommand": [
                "seq_cache_populate.pl"
            ],
            "arguments": [
                {
                    "prefix": "-root",
                    "valueFrom": "$(runtime.outdir)",
                    "position": 1
                }
            ],
            "inputs": [
                {
                    "id": "#samtools_seq_cache_populate.cwl/ref_fasta_files",
                    "doc": "Reference fasta files",
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "inputBinding": {
                        "prefix": null,
                        "position": 2
                    }
                }
            ],
            "outputs": [
                {
                    "id": "#samtools_seq_cache_populate.cwl/ref_cache",
                    "type": "Directory",
                    "outputBinding": {
                        "glob": "."
                    }
                }
            ],
            "id": "#samtools_seq_cache_populate.cwl"
        },
        {
            "class": "CommandLineTool",
            "baseCommand": [
                "python",
                "/split_interval_list.py"
            ],
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "hints": [
                {
                    "dockerPull": "mercury/split-interval-list:v1",
                    "class": "DockerRequirement"
                }
            ],
            "inputs": [
                {
                    "id": "#split_interval_list.cwl/number_of_intervals",
                    "type": "int",
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--chunks"
                    }
                },
                {
                    "id": "#split_interval_list.cwl/interval_list",
                    "type": "File",
                    "inputBinding": {
                        "position": 2,
                        "prefix": "--path"
                    }
                }
            ],
            "arguments": [
                {
                    "prefix": "--output_dir",
                    "valueFrom": "$(runtime.outdir)"
                }
            ],
            "outputs": [
                {
                    "id": "#split_interval_list.cwl/interval_lists",
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputBinding": {
                        "glob": "*.*_of_*.interval_list",
                        "outputEval": "${\n  var files={};\n  var output=[];\n  var re = /^.*[.]([0-9]+)_of_[0-9]+[.]interval_list$/;\n  if (self.length == 0) {\n    return output;\n  }\n  for (var i = 0; i < self.length; ++i) {\n    var fn = self[i].basename\n    var result = re.exec(fn);\n    if (result === null) {\n      throw new Error(\"Unexpected filename in output \" + fn);\n    } else {\n      var index = result[1];\n    }\n    files[index] = self[i];\n  }\n  var sorted_indices = Object.keys(files);\n  sorted_indices.sort(function(a,b){return parseInt(a) - parseInt(b);});\n  for (var i = 0; i < sorted_indices.length; ++i) {\n   index = sorted_indices[i];\n    output.push(files[index]);\n  }\n  return output;\n}\n"
                    }
                }
            ],
            "id": "#split_interval_list.cwl"
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "dockerPull": "mercury/verifybamid2-1.0.4-samtools-1.6:v3",
                    "class": "DockerRequirement"
                }
            ],
            "baseCommand": [
                "verifybamid_rg"
            ],
            "inputs": [
                {
                    "id": "#verifybamid2-rg.cwl/cram",
                    "doc": "Input cram file",
                    "type": "File",
                    "inputBinding": {
                        "prefix": "--cram-file"
                    }
                },
                {
                    "id": "#verifybamid2-rg.cwl/rg",
                    "doc": "Read group",
                    "type": "string",
                    "inputBinding": {
                        "prefix": "--rg"
                    }
                },
                {
                    "id": "#verifybamid2-rg.cwl/ref",
                    "type": "File",
                    "inputBinding": {
                        "prefix": "--ref-file"
                    }
                },
                {
                    "id": "#verifybamid2-rg.cwl/svdset",
                    "doc": "SVD set to use",
                    "type": "string",
                    "default": "hgdp.100k",
                    "inputBinding": {
                        "prefix": "--svd-set"
                    }
                }
            ],
            "outputs": [
                {
                    "id": "#verifybamid2-rg.cwl/out-file",
                    "type": "File",
                    "outputBinding": {
                        "glob": "*.out"
                    }
                }
            ],
            "id": "#verifybamid2-rg.cwl"
        },
        {
            "class": "Workflow",
            "requirements": [
                {
                    "class": "SubworkflowFeatureRequirement"
                },
                {
                    "class": "ScatterFeatureRequirement"
                },
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "inputs": [
                {
                    "id": "#capmq.cwl_2/library_cram",
                    "type": "File"
                },
                {
                    "id": "#capmq.cwl_2/reference_fasta",
                    "type": "File"
                }
            ],
            "steps": [
                {
                    "id": "#capmq.cwl_2/get_rg_values",
                    "run": "#list_rgs.cwl",
                    "in": [
                        {
                            "source": "#capmq.cwl_2/library_cram",
                            "id": "#capmq.cwl_2/get_rg_values/cram"
                        }
                    ],
                    "out": [
                        "#capmq.cwl_2/get_rg_values/rg_values"
                    ]
                },
                {
                    "id": "#capmq.cwl_2/verify_bam_id",
                    "run": "#verifybamid2-rg.cwl",
                    "scatter": "#capmq.cwl_2/verify_bam_id/rg",
                    "scatterMethod": "dotproduct",
                    "in": [
                        {
                            "source": "#capmq.cwl_2/library_cram",
                            "id": "#capmq.cwl_2/verify_bam_id/cram"
                        },
                        {
                            "source": "#capmq.cwl_2/reference_fasta",
                            "id": "#capmq.cwl_2/verify_bam_id/ref"
                        },
                        {
                            "source": "#capmq.cwl_2/get_rg_values/rg_values",
                            "id": "#capmq.cwl_2/verify_bam_id/rg"
                        }
                    ],
                    "out": [
                        "#capmq.cwl_2/verify_bam_id/out-file"
                    ]
                },
                {
                    "id": "#capmq.cwl_2/get_read_group_caps",
                    "run": "#get_read_group_caps.cwl",
                    "in": [
                        {
                            "source": "#capmq.cwl_2/get_rg_values/rg_values",
                            "id": "#capmq.cwl_2/get_read_group_caps/read_groups"
                        },
                        {
                            "source": "#capmq.cwl_2/verify_bam_id/out-file",
                            "id": "#capmq.cwl_2/get_read_group_caps/verify_bam_id_files"
                        }
                    ],
                    "out": [
                        "#capmq.cwl_2/get_read_group_caps/read_group_caps_file"
                    ]
                },
                {
                    "id": "#capmq.cwl_2/get_capmq_ref_cache",
                    "run": "#samtools_seq_cache_populate.cwl",
                    "in": [
                        {
                            "source": "#capmq.cwl_2/reference_fasta",
                            "valueFrom": "$([self])",
                            "id": "#capmq.cwl_2/get_capmq_ref_cache/ref_fasta_files"
                        }
                    ],
                    "out": [
                        "#capmq.cwl_2/get_capmq_ref_cache/ref_cache"
                    ]
                },
                {
                    "id": "#capmq.cwl_2/capmq",
                    "run": "#capmq.cwl",
                    "in": [
                        {
                            "valueFrom": "cram",
                            "id": "#capmq.cwl_2/capmq/htslib_output_options"
                        },
                        {
                            "source": "#capmq.cwl_2/library_cram",
                            "id": "#capmq.cwl_2/capmq/input_file"
                        },
                        {
                            "default": 20,
                            "id": "#capmq.cwl_2/capmq/minimum_MAPQ"
                        },
                        {
                            "source": "#capmq.cwl_2/library_cram",
                            "valueFrom": "$(self.nameroot).capmq.cram",
                            "id": "#capmq.cwl_2/capmq/output_filename"
                        },
                        {
                            "source": "#capmq.cwl_2/get_read_group_caps/read_group_caps_file",
                            "id": "#capmq.cwl_2/capmq/readgroup_caps_file"
                        },
                        {
                            "source": "#capmq.cwl_2/get_capmq_ref_cache/ref_cache",
                            "id": "#capmq.cwl_2/capmq/ref_path_dir"
                        },
                        {
                            "default": true,
                            "id": "#capmq.cwl_2/capmq/use_max_contamination"
                        }
                    ],
                    "out": [
                        "#capmq.cwl_2/capmq/capped_file"
                    ]
                },
                {
                    "id": "#capmq.cwl_2/cram_index",
                    "run": "#samtools-index.cwl",
                    "in": [
                        {
                            "source": "#capmq.cwl_2/capmq/capped_file",
                            "id": "#capmq.cwl_2/cram_index/input"
                        }
                    ],
                    "out": [
                        "#capmq.cwl_2/cram_index/cram_index"
                    ]
                },
                {
                    "id": "#capmq.cwl_2/combine_cram_index",
                    "run": "#combine_files.cwl",
                    "in": [
                        {
                            "source": "#capmq.cwl_2/capmq/capped_file",
                            "id": "#capmq.cwl_2/combine_cram_index/main_file"
                        },
                        {
                            "source": "#capmq.cwl_2/cram_index/cram_index",
                            "id": "#capmq.cwl_2/combine_cram_index/secondary_files"
                        }
                    ],
                    "out": [
                        "#capmq.cwl_2/combine_cram_index/file_with_secondary_files"
                    ]
                }
            ],
            "outputs": [
                {
                    "id": "#capmq.cwl_2/capped_file",
                    "type": "File",
                    "outputSource": "#capmq.cwl_2/combine_cram_index/file_with_secondary_files"
                }
            ],
            "id": "#capmq.cwl_2"
        },
        {
            "class": "Workflow",
            "requirements": [
                {
                    "class": "SubworkflowFeatureRequirement"
                },
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "StepInputExpressionRequirement"
                }
            ],
            "inputs": [
                {
                    "id": "#cram-get-fasta.cwl/input_cram",
                    "type": "File"
                },
                {
                    "id": "#cram-get-fasta.cwl/ref_fasta_files",
                    "type": {
                        "type": "array",
                        "items": "File"
                    }
                }
            ],
            "steps": [
                {
                    "id": "#cram-get-fasta.cwl/samtools_seq_cache_populate",
                    "run": "#samtools_seq_cache_populate.cwl",
                    "in": [
                        {
                            "source": "#cram-get-fasta.cwl/ref_fasta_files",
                            "id": "#cram-get-fasta.cwl/samtools_seq_cache_populate/ref_fasta_files"
                        }
                    ],
                    "out": [
                        "#cram-get-fasta.cwl/samtools_seq_cache_populate/ref_cache"
                    ],
                    "hints": [
                        {
                            "ramMin": 100000,
                            "coresMin": 1,
                            "tmpdirMin": 1000,
                            "class": "ResourceRequirement"
                        }
                    ]
                },
                {
                    "id": "#cram-get-fasta.cwl/samtools_fastaref",
                    "run": "#samtools-fastaref.cwl",
                    "in": [
                        {
                            "source": "#cram-get-fasta.cwl/input_cram",
                            "id": "#cram-get-fasta.cwl/samtools_fastaref/input"
                        },
                        {
                            "default": "reference.fa",
                            "id": "#cram-get-fasta.cwl/samtools_fastaref/output_file_name"
                        },
                        {
                            "source": "#cram-get-fasta.cwl/samtools_seq_cache_populate/ref_cache",
                            "id": "#cram-get-fasta.cwl/samtools_fastaref/ref_path_dir"
                        }
                    ],
                    "out": [
                        "#cram-get-fasta.cwl/samtools_fastaref/reference_fasta"
                    ],
                    "hints": [
                        {
                            "ramMin": 8000,
                            "coresMin": 1,
                            "tmpdirMin": 1000,
                            "class": "ResourceRequirement"
                        }
                    ]
                },
                {
                    "id": "#cram-get-fasta.cwl/samtools_faidx",
                    "run": "#samtools-faidx.cwl",
                    "in": [
                        {
                            "source": "#cram-get-fasta.cwl/samtools_fastaref/reference_fasta",
                            "id": "#cram-get-fasta.cwl/samtools_faidx/fasta"
                        }
                    ],
                    "out": [
                        "#cram-get-fasta.cwl/samtools_faidx/fasta_index"
                    ]
                },
                {
                    "id": "#cram-get-fasta.cwl/samtools_dict",
                    "run": "#samtools-dict.cwl",
                    "in": [
                        {
                            "source": "#cram-get-fasta.cwl/samtools_fastaref/reference_fasta",
                            "id": "#cram-get-fasta.cwl/samtools_dict/fasta"
                        },
                        {
                            "default": "reference.dict",
                            "id": "#cram-get-fasta.cwl/samtools_dict/output"
                        }
                    ],
                    "out": [
                        "#cram-get-fasta.cwl/samtools_dict/fasta_dict"
                    ]
                },
                {
                    "id": "#cram-get-fasta.cwl/combine_reference_files",
                    "in": [
                        {
                            "source": "#cram-get-fasta.cwl/samtools_fastaref/reference_fasta",
                            "id": "#cram-get-fasta.cwl/combine_reference_files/main_file"
                        },
                        {
                            "source": [
                                "#cram-get-fasta.cwl/samtools_faidx/fasta_index",
                                "#cram-get-fasta.cwl/samtools_dict/fasta_dict"
                            ],
                            "id": "#cram-get-fasta.cwl/combine_reference_files/secondary_files"
                        }
                    ],
                    "out": [
                        "#cram-get-fasta.cwl/combine_reference_files/file_with_secondary_files"
                    ],
                    "run": "#combine_files.cwl"
                }
            ],
            "outputs": [
                {
                    "id": "#cram-get-fasta.cwl/reference_fasta",
                    "type": "File",
                    "outputSource": "#cram-get-fasta.cwl/combine_reference_files/file_with_secondary_files"
                },
                {
                    "id": "#cram-get-fasta.cwl/reference_dict",
                    "type": "File",
                    "outputSource": "#cram-get-fasta.cwl/samtools_dict/fasta_dict"
                }
            ],
            "id": "#cram-get-fasta.cwl"
        },
        {
            "class": "Workflow",
            "requirements": [
                {
                    "class": "ScatterFeatureRequirement"
                },
                {
                    "class": "SubworkflowFeatureRequirement"
                }
            ],
            "hints": [
                {
                    "ramMin": 4000,
                    "coresMin": 1,
                    "tmpdirMin": 1000,
                    "class": "ResourceRequirement"
                },
                {
                    "outputTTL": 2592000,
                    "class": "http://arvados.org/cwl#IntermediateOutput"
                },
                {
                    "keep_cache": 1024,
                    "outputDirType": "keep_output_dir",
                    "class": "http://arvados.org/cwl#RuntimeConstraints"
                },
                {
                    "loadListing": "no_listing",
                    "class": "http://commonwl.org/cwltool#LoadListingRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "id": "#gatk-4.0.0.0-genomics-db-and-genotypegvcfs-per-interval-list.cwl/interval_list"
                },
                {
                    "type": "File",
                    "id": "#gatk-4.0.0.0-genomics-db-and-genotypegvcfs-per-interval-list.cwl/reference"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "id": "#gatk-4.0.0.0-genomics-db-and-genotypegvcfs-per-interval-list.cwl/variants"
                }
            ],
            "steps": [
                {
                    "id": "#gatk-4.0.0.0-genomics-db-and-genotypegvcfs-per-interval-list.cwl/interval_list_to_cwl_list",
                    "run": "#interval_list_to_json.cwl",
                    "in": [
                        {
                            "source": "#gatk-4.0.0.0-genomics-db-and-genotypegvcfs-per-interval-list.cwl/interval_list",
                            "id": "#gatk-4.0.0.0-genomics-db-and-genotypegvcfs-per-interval-list.cwl/interval_list_to_cwl_list/interval_list_file"
                        }
                    ],
                    "out": [
                        "#gatk-4.0.0.0-genomics-db-and-genotypegvcfs-per-interval-list.cwl/interval_list_to_cwl_list/list_of_intervals"
                    ]
                },
                {
                    "id": "#gatk-4.0.0.0-genomics-db-and-genotypegvcfs-per-interval-list.cwl/gatk_4.0.0.0_genomics_db_and_genotypegvcfs_per_interval",
                    "scatter": "#gatk-4.0.0.0-genomics-db-and-genotypegvcfs-per-interval-list.cwl/gatk_4.0.0.0_genomics_db_and_genotypegvcfs_per_interval/interval",
                    "run": "#gatk-4.0.0.0-genomics-db-and-genotypegvcfs-per-interval.cwl",
                    "in": [
                        {
                            "source": "#gatk-4.0.0.0-genomics-db-and-genotypegvcfs-per-interval-list.cwl/interval_list_to_cwl_list/list_of_intervals",
                            "id": "#gatk-4.0.0.0-genomics-db-and-genotypegvcfs-per-interval-list.cwl/gatk_4.0.0.0_genomics_db_and_genotypegvcfs_per_interval/interval"
                        },
                        {
                            "source": "#gatk-4.0.0.0-genomics-db-and-genotypegvcfs-per-interval-list.cwl/reference",
                            "id": "#gatk-4.0.0.0-genomics-db-and-genotypegvcfs-per-interval-list.cwl/gatk_4.0.0.0_genomics_db_and_genotypegvcfs_per_interval/reference"
                        },
                        {
                            "source": "#gatk-4.0.0.0-genomics-db-and-genotypegvcfs-per-interval-list.cwl/variants",
                            "id": "#gatk-4.0.0.0-genomics-db-and-genotypegvcfs-per-interval-list.cwl/gatk_4.0.0.0_genomics_db_and_genotypegvcfs_per_interval/variants"
                        }
                    ],
                    "out": [
                        "#gatk-4.0.0.0-genomics-db-and-genotypegvcfs-per-interval-list.cwl/gatk_4.0.0.0_genomics_db_and_genotypegvcfs_per_interval/multisample-gvcf-output"
                    ]
                }
            ],
            "outputs": [
                {
                    "id": "#gatk-4.0.0.0-genomics-db-and-genotypegvcfs-per-interval-list.cwl/multisample-gvcf-outputs",
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#gatk-4.0.0.0-genomics-db-and-genotypegvcfs-per-interval-list.cwl/gatk_4.0.0.0_genomics_db_and_genotypegvcfs_per_interval/multisample-gvcf-output"
                }
            ],
            "id": "#gatk-4.0.0.0-genomics-db-and-genotypegvcfs-per-interval-list.cwl"
        },
        {
            "class": "Workflow",
            "hints": [
                {
                    "ramMin": 4000,
                    "coresMin": 1,
                    "tmpdirMin": 1000,
                    "class": "ResourceRequirement"
                },
                {
                    "outputTTL": 2592000,
                    "class": "http://arvados.org/cwl#IntermediateOutput"
                },
                {
                    "keep_cache": 1024,
                    "outputDirType": "keep_output_dir",
                    "class": "http://arvados.org/cwl#RuntimeConstraints"
                },
                {
                    "loadListing": "no_listing",
                    "class": "http://commonwl.org/cwltool#LoadListingRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "string",
                    "id": "#gatk-4.0.0.0-genomics-db-and-genotypegvcfs-per-interval.cwl/interval"
                },
                {
                    "type": "File",
                    "id": "#gatk-4.0.0.0-genomics-db-and-genotypegvcfs-per-interval.cwl/reference"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "id": "#gatk-4.0.0.0-genomics-db-and-genotypegvcfs-per-interval.cwl/variants"
                }
            ],
            "steps": [
                {
                    "id": "#gatk-4.0.0.0-genomics-db-and-genotypegvcfs-per-interval.cwl/genomics_db_import_gvcfs",
                    "run": "#GenomicsDBImport.cwl",
                    "hints": [
                        {
                            "coresMin": 6,
                            "ramMin": 18000,
                            "tmpdirMin": 1000,
                            "class": "ResourceRequirement"
                        },
                        {
                            "keep_cache": 1280,
                            "class": "http://arvados.org/cwl#RuntimeConstraints"
                        }
                    ],
                    "in": [
                        {
                            "default": 50,
                            "id": "#gatk-4.0.0.0-genomics-db-and-genotypegvcfs-per-interval.cwl/genomics_db_import_gvcfs/batch-size"
                        },
                        {
                            "default": "genomicsdb",
                            "id": "#gatk-4.0.0.0-genomics-db-and-genotypegvcfs-per-interval.cwl/genomics_db_import_gvcfs/genomicsdb-workspace-path"
                        },
                        {
                            "default": 500,
                            "id": "#gatk-4.0.0.0-genomics-db-and-genotypegvcfs-per-interval.cwl/genomics_db_import_gvcfs/interval-padding"
                        },
                        {
                            "source": "#gatk-4.0.0.0-genomics-db-and-genotypegvcfs-per-interval.cwl/interval",
                            "id": "#gatk-4.0.0.0-genomics-db-and-genotypegvcfs-per-interval.cwl/genomics_db_import_gvcfs/intervals"
                        },
                        {
                            "default": 5,
                            "id": "#gatk-4.0.0.0-genomics-db-and-genotypegvcfs-per-interval.cwl/genomics_db_import_gvcfs/reader-threads"
                        },
                        {
                            "source": "#gatk-4.0.0.0-genomics-db-and-genotypegvcfs-per-interval.cwl/variants",
                            "id": "#gatk-4.0.0.0-genomics-db-and-genotypegvcfs-per-interval.cwl/genomics_db_import_gvcfs/variant"
                        }
                    ],
                    "out": [
                        "#gatk-4.0.0.0-genomics-db-and-genotypegvcfs-per-interval.cwl/genomics_db_import_gvcfs/genomicsdb-workspace"
                    ]
                },
                {
                    "id": "#gatk-4.0.0.0-genomics-db-and-genotypegvcfs-per-interval.cwl/genotype_gvcfs",
                    "run": "#GenotypeGVCFs.cwl",
                    "hints": [
                        {
                            "ramMin": 20000,
                            "coresMin": 1,
                            "tmpdirMin": 1000,
                            "class": "ResourceRequirement"
                        }
                    ],
                    "in": [
                        {
                            "default": true,
                            "id": "#gatk-4.0.0.0-genomics-db-and-genotypegvcfs-per-interval.cwl/genotype_gvcfs/create-output-variant-index"
                        },
                        {
                            "source": "#gatk-4.0.0.0-genomics-db-and-genotypegvcfs-per-interval.cwl/interval",
                            "id": "#gatk-4.0.0.0-genomics-db-and-genotypegvcfs-per-interval.cwl/genotype_gvcfs/intervals"
                        },
                        {
                            "default": true,
                            "id": "#gatk-4.0.0.0-genomics-db-and-genotypegvcfs-per-interval.cwl/genotype_gvcfs/only-output-calls-starting-in-intervals"
                        },
                        {
                            "valueFrom": "output.g.vcf.gz",
                            "id": "#gatk-4.0.0.0-genomics-db-and-genotypegvcfs-per-interval.cwl/genotype_gvcfs/output-filename"
                        },
                        {
                            "source": "#gatk-4.0.0.0-genomics-db-and-genotypegvcfs-per-interval.cwl/reference",
                            "id": "#gatk-4.0.0.0-genomics-db-and-genotypegvcfs-per-interval.cwl/genotype_gvcfs/reference"
                        },
                        {
                            "default": true,
                            "id": "#gatk-4.0.0.0-genomics-db-and-genotypegvcfs-per-interval.cwl/genotype_gvcfs/use-new-qual-calculator"
                        },
                        {
                            "source": "#gatk-4.0.0.0-genomics-db-and-genotypegvcfs-per-interval.cwl/genomics_db_import_gvcfs/genomicsdb-workspace",
                            "id": "#gatk-4.0.0.0-genomics-db-and-genotypegvcfs-per-interval.cwl/genotype_gvcfs/variant"
                        }
                    ],
                    "out": [
                        "#gatk-4.0.0.0-genomics-db-and-genotypegvcfs-per-interval.cwl/genotype_gvcfs/output",
                        "#gatk-4.0.0.0-genomics-db-and-genotypegvcfs-per-interval.cwl/genotype_gvcfs/variant-index"
                    ]
                },
                {
                    "id": "#gatk-4.0.0.0-genomics-db-and-genotypegvcfs-per-interval.cwl/multisample_gvcf_output_with_index",
                    "in": [
                        {
                            "source": "#gatk-4.0.0.0-genomics-db-and-genotypegvcfs-per-interval.cwl/genotype_gvcfs/output",
                            "id": "#gatk-4.0.0.0-genomics-db-and-genotypegvcfs-per-interval.cwl/multisample_gvcf_output_with_index/main_file"
                        },
                        {
                            "source": "#gatk-4.0.0.0-genomics-db-and-genotypegvcfs-per-interval.cwl/genotype_gvcfs/variant-index",
                            "id": "#gatk-4.0.0.0-genomics-db-and-genotypegvcfs-per-interval.cwl/multisample_gvcf_output_with_index/secondary_files"
                        }
                    ],
                    "out": [
                        "#gatk-4.0.0.0-genomics-db-and-genotypegvcfs-per-interval.cwl/multisample_gvcf_output_with_index/file_with_secondary_files"
                    ],
                    "run": "#combine_files.cwl"
                }
            ],
            "outputs": [
                {
                    "id": "#gatk-4.0.0.0-genomics-db-and-genotypegvcfs-per-interval.cwl/multisample-gvcf-output",
                    "type": "File",
                    "outputSource": "#gatk-4.0.0.0-genomics-db-and-genotypegvcfs-per-interval.cwl/multisample_gvcf_output_with_index/file_with_secondary_files"
                }
            ],
            "id": "#gatk-4.0.0.0-genomics-db-and-genotypegvcfs-per-interval.cwl"
        },
        {
            "class": "Workflow",
            "requirements": [
                {
                    "class": "SubworkflowFeatureRequirement"
                },
                {
                    "class": "StepInputExpressionRequirement"
                },
                {
                    "class": "ScatterFeatureRequirement"
                }
            ],
            "hints": [
                {
                    "ramMin": 4000,
                    "coresMin": 1,
                    "tmpdirMin": 1000,
                    "class": "ResourceRequirement"
                },
                {
                    "outputTTL": 2592000,
                    "class": "http://arvados.org/cwl#IntermediateOutput"
                },
                {
                    "keep_cache": 1024,
                    "outputDirType": "keep_output_dir",
                    "class": "http://arvados.org/cwl#RuntimeConstraints"
                },
                {
                    "loadListing": "no_listing",
                    "class": "http://commonwl.org/cwltool#LoadListingRequirement"
                }
            ],
            "inputs": [
                {
                    "id": "#main/library_crams",
                    "type": {
                        "type": "array",
                        "items": "File"
                    }
                },
                {
                    "id": "#main/chunks",
                    "type": "int"
                },
                {
                    "id": "#main/intersect_file",
                    "type": "File"
                },
                {
                    "id": "#main/ref_fasta_files",
                    "type": {
                        "type": "array",
                        "items": "File"
                    }
                },
                {
                    "id": "#main/output_basename",
                    "type": "string",
                    "default": "output"
                },
                {
                    "id": "#main/haploid_chromosome_regex",
                    "type": "string",
                    "default": "^(chr)?Y$"
                }
            ],
            "steps": [
                {
                    "id": "#main/haplotype_caller",
                    "scatter": [
                        "#main/haplotype_caller/library_cram"
                    ],
                    "run": "#gatk-4.0.0.0-library-cram-to-gvcfs.cwl",
                    "in": [
                        {
                            "source": "#main/chunks",
                            "id": "#main/haplotype_caller/chunks"
                        },
                        {
                            "source": "#main/haploid_chromosome_regex",
                            "id": "#main/haplotype_caller/haploid_chromosome_regex"
                        },
                        {
                            "source": "#main/intersect_file",
                            "id": "#main/haplotype_caller/intersect_file"
                        },
                        {
                            "source": "#main/library_crams",
                            "id": "#main/haplotype_caller/library_cram"
                        },
                        {
                            "source": "#main/ref_fasta_files",
                            "id": "#main/haplotype_caller/ref_fasta_files"
                        }
                    ],
                    "out": [
                        "#main/haplotype_caller/gvcf_files_diploid",
                        "#main/haplotype_caller/intervals_diploid",
                        "#main/haplotype_caller/gvcf_files_haploid",
                        "#main/haplotype_caller/intervals_haploid",
                        "#main/haplotype_caller/reference"
                    ]
                },
                {
                    "id": "#main/joint_calling_diploid",
                    "run": "#gatk-4.0.0.0-joint-calling.cwl",
                    "in": [
                        {
                            "source": "#main/haplotype_caller/gvcf_files_diploid",
                            "id": "#main/joint_calling_diploid/gvcf_files"
                        },
                        {
                            "source": "#main/haplotype_caller/intervals_diploid",
                            "valueFrom": "$(self[0])",
                            "id": "#main/joint_calling_diploid/intervals"
                        },
                        {
                            "source": "#main/output_basename",
                            "valueFrom": "$(self).diploid.vcf.gz",
                            "id": "#main/joint_calling_diploid/output_filename"
                        },
                        {
                            "source": "#main/haplotype_caller/reference",
                            "valueFrom": "$(self[0])",
                            "id": "#main/joint_calling_diploid/reference"
                        }
                    ],
                    "out": [
                        "#main/joint_calling_diploid/out"
                    ]
                },
                {
                    "id": "#main/joint_calling_haploid",
                    "run": "#gatk-4.0.0.0-joint-calling.cwl",
                    "in": [
                        {
                            "source": "#main/haplotype_caller/gvcf_files_haploid",
                            "id": "#main/joint_calling_haploid/gvcf_files"
                        },
                        {
                            "source": "#main/haplotype_caller/intervals_haploid",
                            "valueFrom": "$(self[0])",
                            "id": "#main/joint_calling_haploid/intervals"
                        },
                        {
                            "source": "#main/output_basename",
                            "valueFrom": "$(self).haploid.vcf.gz",
                            "id": "#main/joint_calling_haploid/output_filename"
                        },
                        {
                            "source": "#main/haplotype_caller/reference",
                            "valueFrom": "$(self[0])",
                            "id": "#main/joint_calling_haploid/reference"
                        }
                    ],
                    "out": [
                        "#main/joint_calling_haploid/out"
                    ]
                }
            ],
            "outputs": [
                {
                    "id": "#main/output_diploid",
                    "type": "File",
                    "outputSource": "#main/joint_calling_diploid/out"
                },
                {
                    "id": "#main/output_haploid",
                    "type": "File",
                    "outputSource": "#main/joint_calling_haploid/out"
                }
            ],
            "id": "#main"
        },
        {
            "class": "Workflow",
            "requirements": [
                {
                    "class": "SubworkflowFeatureRequirement"
                },
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "StepInputExpressionRequirement"
                },
                {
                    "class": "MultipleInputFeatureRequirement"
                },
                {
                    "class": "ScatterFeatureRequirement"
                }
            ],
            "hints": [
                {
                    "ramMin": 4000,
                    "coresMin": 1,
                    "tmpdirMin": 1000,
                    "class": "ResourceRequirement"
                }
            ],
            "inputs": [
                {
                    "id": "#gatk-4.0.0.0-haplotypecaller.cwl/library_cram",
                    "type": "File"
                },
                {
                    "id": "#gatk-4.0.0.0-haplotypecaller.cwl/chunks",
                    "type": "int"
                },
                {
                    "id": "#gatk-4.0.0.0-haplotypecaller.cwl/intersect_file",
                    "type": "File"
                },
                {
                    "id": "#gatk-4.0.0.0-haplotypecaller.cwl/reference_dict",
                    "type": "File"
                },
                {
                    "id": "#gatk-4.0.0.0-haplotypecaller.cwl/reference_fasta",
                    "type": "File"
                },
                {
                    "id": "#gatk-4.0.0.0-haplotypecaller.cwl/ploidy",
                    "type": "int"
                },
                {
                    "id": "#gatk-4.0.0.0-haplotypecaller.cwl/include_chromosome_regex",
                    "type": "string",
                    "default": "."
                },
                {
                    "id": "#gatk-4.0.0.0-haplotypecaller.cwl/pcr_free",
                    "type": "boolean",
                    "default": true
                }
            ],
            "steps": [
                {
                    "id": "#gatk-4.0.0.0-haplotypecaller.cwl/dict_to_interval_list",
                    "run": "#dict_to_interval_list.cwl",
                    "in": [
                        {
                            "source": "#gatk-4.0.0.0-haplotypecaller.cwl/reference_dict",
                            "id": "#gatk-4.0.0.0-haplotypecaller.cwl/dict_to_interval_list/dictionary"
                        }
                    ],
                    "out": [
                        "#gatk-4.0.0.0-haplotypecaller.cwl/dict_to_interval_list/interval_list"
                    ]
                },
                {
                    "id": "#gatk-4.0.0.0-haplotypecaller.cwl/intersect",
                    "run": "#intersect_intervals.cwl",
                    "in": [
                        {
                            "source": "#gatk-4.0.0.0-haplotypecaller.cwl/intersect_file",
                            "id": "#gatk-4.0.0.0-haplotypecaller.cwl/intersect/interval_list_A"
                        },
                        {
                            "source": "#gatk-4.0.0.0-haplotypecaller.cwl/dict_to_interval_list/interval_list",
                            "id": "#gatk-4.0.0.0-haplotypecaller.cwl/intersect/interval_list_B"
                        }
                    ],
                    "out": [
                        "#gatk-4.0.0.0-haplotypecaller.cwl/intersect/intersected_interval_list"
                    ]
                },
                {
                    "id": "#gatk-4.0.0.0-haplotypecaller.cwl/filter_interval_list",
                    "run": "#filter_interval_list.cwl",
                    "in": [
                        {
                            "source": "#gatk-4.0.0.0-haplotypecaller.cwl/include_chromosome_regex",
                            "id": "#gatk-4.0.0.0-haplotypecaller.cwl/filter_interval_list/chromosome_regex"
                        },
                        {
                            "source": "#gatk-4.0.0.0-haplotypecaller.cwl/intersect/intersected_interval_list",
                            "id": "#gatk-4.0.0.0-haplotypecaller.cwl/filter_interval_list/interval_list"
                        }
                    ],
                    "out": [
                        "#gatk-4.0.0.0-haplotypecaller.cwl/filter_interval_list/output"
                    ]
                },
                {
                    "id": "#gatk-4.0.0.0-haplotypecaller.cwl/split_interval_list",
                    "run": "#split_interval_list.cwl",
                    "in": [
                        {
                            "source": "#gatk-4.0.0.0-haplotypecaller.cwl/filter_interval_list/output",
                            "id": "#gatk-4.0.0.0-haplotypecaller.cwl/split_interval_list/interval_list"
                        },
                        {
                            "source": "#gatk-4.0.0.0-haplotypecaller.cwl/chunks",
                            "id": "#gatk-4.0.0.0-haplotypecaller.cwl/split_interval_list/number_of_intervals"
                        }
                    ],
                    "out": [
                        "#gatk-4.0.0.0-haplotypecaller.cwl/split_interval_list/interval_lists"
                    ]
                },
                {
                    "id": "#gatk-4.0.0.0-haplotypecaller.cwl/haplotype_caller",
                    "scatter": [
                        "#gatk-4.0.0.0-haplotypecaller.cwl/haplotype_caller/intervals"
                    ],
                    "hints": [
                        {
                            "ramMin": 6000,
                            "coresMin": 1,
                            "tmpdirMin": 1000,
                            "class": "ResourceRequirement"
                        }
                    ],
                    "run": "#HaplotypeCaller.cwl",
                    "in": [
                        {
                            "valueFrom": "$( false )",
                            "id": "#gatk-4.0.0.0-haplotypecaller.cwl/haplotype_caller/add-output-vcf-command-line"
                        },
                        {
                            "valueFrom": "$([\"DepthPerAlleleBySample\",\"StrandBiasBySample\"])",
                            "id": "#gatk-4.0.0.0-haplotypecaller.cwl/haplotype_caller/annotation"
                        },
                        {
                            "valueFrom": "$( true )",
                            "id": "#gatk-4.0.0.0-haplotypecaller.cwl/haplotype_caller/create-output-variant-index"
                        },
                        {
                            "valueFrom": "$( true )",
                            "id": "#gatk-4.0.0.0-haplotypecaller.cwl/haplotype_caller/create-output-variant-md5"
                        },
                        {
                            "valueFrom": "GVCF",
                            "id": "#gatk-4.0.0.0-haplotypecaller.cwl/haplotype_caller/emit-ref-confidence"
                        },
                        {
                            "source": "#gatk-4.0.0.0-haplotypecaller.cwl/library_cram",
                            "id": "#gatk-4.0.0.0-haplotypecaller.cwl/haplotype_caller/input"
                        },
                        {
                            "source": "#gatk-4.0.0.0-haplotypecaller.cwl/split_interval_list/interval_lists",
                            "id": "#gatk-4.0.0.0-haplotypecaller.cwl/haplotype_caller/intervals"
                        },
                        {
                            "valueFrom": "$(inputs.input.nameroot)_$(inputs.intervals.nameroot).g.vcf.gz",
                            "id": "#gatk-4.0.0.0-haplotypecaller.cwl/haplotype_caller/output-filename"
                        },
                        {
                            "source": "#gatk-4.0.0.0-haplotypecaller.cwl/pcr_free",
                            "valueFrom": "${ if(self) { return \"NONE\" } else { return \"CONSERVATIVE\" }}",
                            "id": "#gatk-4.0.0.0-haplotypecaller.cwl/haplotype_caller/pcr-indel-model"
                        },
                        {
                            "source": "#gatk-4.0.0.0-haplotypecaller.cwl/reference_fasta",
                            "id": "#gatk-4.0.0.0-haplotypecaller.cwl/haplotype_caller/reference"
                        },
                        {
                            "source": "#gatk-4.0.0.0-haplotypecaller.cwl/ploidy",
                            "id": "#gatk-4.0.0.0-haplotypecaller.cwl/haplotype_caller/sample-ploidy"
                        },
                        {
                            "valueFrom": "INFO",
                            "id": "#gatk-4.0.0.0-haplotypecaller.cwl/haplotype_caller/verbosity"
                        }
                    ],
                    "out": [
                        "#gatk-4.0.0.0-haplotypecaller.cwl/haplotype_caller/output",
                        "#gatk-4.0.0.0-haplotypecaller.cwl/haplotype_caller/variant-index",
                        "#gatk-4.0.0.0-haplotypecaller.cwl/haplotype_caller/variant-md5"
                    ]
                },
                {
                    "id": "#gatk-4.0.0.0-haplotypecaller.cwl/combine_haplotype_index",
                    "scatter": [
                        "#gatk-4.0.0.0-haplotypecaller.cwl/combine_haplotype_index/main_file",
                        "#gatk-4.0.0.0-haplotypecaller.cwl/combine_haplotype_index/secondary_files"
                    ],
                    "scatterMethod": "dotproduct",
                    "in": [
                        {
                            "source": "#gatk-4.0.0.0-haplotypecaller.cwl/haplotype_caller/output",
                            "id": "#gatk-4.0.0.0-haplotypecaller.cwl/combine_haplotype_index/main_file"
                        },
                        {
                            "source": "#gatk-4.0.0.0-haplotypecaller.cwl/haplotype_caller/variant-index",
                            "id": "#gatk-4.0.0.0-haplotypecaller.cwl/combine_haplotype_index/secondary_files"
                        }
                    ],
                    "out": [
                        "#gatk-4.0.0.0-haplotypecaller.cwl/combine_haplotype_index/file_with_secondary_files"
                    ],
                    "run": "#combine_files.cwl"
                }
            ],
            "outputs": [
                {
                    "id": "#gatk-4.0.0.0-haplotypecaller.cwl/gvcf_files",
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#gatk-4.0.0.0-haplotypecaller.cwl/combine_haplotype_index/file_with_secondary_files"
                },
                {
                    "id": "#gatk-4.0.0.0-haplotypecaller.cwl/intervals",
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#gatk-4.0.0.0-haplotypecaller.cwl/split_interval_list/interval_lists"
                }
            ],
            "id": "#gatk-4.0.0.0-haplotypecaller.cwl"
        },
        {
            "class": "Workflow",
            "requirements": [
                {
                    "class": "SubworkflowFeatureRequirement"
                },
                {
                    "class": "ScatterFeatureRequirement"
                },
                {
                    "class": "StepInputExpressionRequirement"
                },
                {
                    "class": "MultipleInputFeatureRequirement"
                }
            ],
            "hints": [
                {
                    "ramMin": 4000,
                    "coresMin": 1,
                    "tmpdirMin": 1000,
                    "class": "ResourceRequirement"
                },
                {
                    "outputTTL": 2592000,
                    "class": "http://arvados.org/cwl#IntermediateOutput"
                },
                {
                    "keep_cache": 1024,
                    "outputDirType": "keep_output_dir",
                    "class": "http://arvados.org/cwl#RuntimeConstraints"
                },
                {
                    "loadListing": "no_listing",
                    "class": "http://commonwl.org/cwltool#LoadListingRequirement"
                }
            ],
            "inputs": [
                {
                    "id": "#gatk-4.0.0.0-joint-calling.cwl/gvcf_files",
                    "doc": "Array of array of GVCF files. Each inner array contains vcfs called for the corresponding interval\\ in the interval input. The outer array represents each sample.",
                    "type": {
                        "type": "array",
                        "items": {
                            "type": "array",
                            "items": "File"
                        }
                    }
                },
                {
                    "id": "#gatk-4.0.0.0-joint-calling.cwl/intervals",
                    "doc": "List of intervals_list files",
                    "type": {
                        "type": "array",
                        "items": "File"
                    }
                },
                {
                    "id": "#gatk-4.0.0.0-joint-calling.cwl/reference",
                    "doc": "The reference file for all the samples",
                    "type": "File"
                },
                {
                    "id": "#gatk-4.0.0.0-joint-calling.cwl/output_filename",
                    "doc": "The name of the output VCF to produce",
                    "type": "string",
                    "default": "output.vcf.gz"
                }
            ],
            "steps": [
                {
                    "id": "#gatk-4.0.0.0-joint-calling.cwl/transpose_gvcf_files_list",
                    "run": "#matrix_transpose.cwl",
                    "in": [
                        {
                            "source": "#gatk-4.0.0.0-joint-calling.cwl/gvcf_files",
                            "id": "#gatk-4.0.0.0-joint-calling.cwl/transpose_gvcf_files_list/array"
                        }
                    ],
                    "out": [
                        "#gatk-4.0.0.0-joint-calling.cwl/transpose_gvcf_files_list/transposed_array"
                    ]
                },
                {
                    "id": "#gatk-4.0.0.0-joint-calling.cwl/genomicsdbimport-and-genotype-gvcfs-per-interval-list",
                    "scatter": [
                        "#gatk-4.0.0.0-joint-calling.cwl/genomicsdbimport-and-genotype-gvcfs-per-interval-list/variants",
                        "#gatk-4.0.0.0-joint-calling.cwl/genomicsdbimport-and-genotype-gvcfs-per-interval-list/interval_list"
                    ],
                    "scatterMethod": "dotproduct",
                    "run": "#gatk-4.0.0.0-genomics-db-and-genotypegvcfs-per-interval-list.cwl",
                    "in": [
                        {
                            "source": "#gatk-4.0.0.0-joint-calling.cwl/intervals",
                            "id": "#gatk-4.0.0.0-joint-calling.cwl/genomicsdbimport-and-genotype-gvcfs-per-interval-list/interval_list"
                        },
                        {
                            "source": "#gatk-4.0.0.0-joint-calling.cwl/reference",
                            "id": "#gatk-4.0.0.0-joint-calling.cwl/genomicsdbimport-and-genotype-gvcfs-per-interval-list/reference"
                        },
                        {
                            "source": "#gatk-4.0.0.0-joint-calling.cwl/transpose_gvcf_files_list/transposed_array",
                            "id": "#gatk-4.0.0.0-joint-calling.cwl/genomicsdbimport-and-genotype-gvcfs-per-interval-list/variants"
                        }
                    ],
                    "out": [
                        "#gatk-4.0.0.0-joint-calling.cwl/genomicsdbimport-and-genotype-gvcfs-per-interval-list/multisample-gvcf-outputs"
                    ]
                },
                {
                    "id": "#gatk-4.0.0.0-joint-calling.cwl/flatten-multisample-gvcf-outputs",
                    "run": "#flatten-array-file.cwl",
                    "in": [
                        {
                            "source": "#gatk-4.0.0.0-joint-calling.cwl/genomicsdbimport-and-genotype-gvcfs-per-interval-list/multisample-gvcf-outputs",
                            "id": "#gatk-4.0.0.0-joint-calling.cwl/flatten-multisample-gvcf-outputs/2d-array"
                        }
                    ],
                    "out": [
                        "#gatk-4.0.0.0-joint-calling.cwl/flatten-multisample-gvcf-outputs/flattened_array"
                    ]
                },
                {
                    "id": "#gatk-4.0.0.0-joint-calling.cwl/concat_multisample_gvcfs",
                    "run": "#bcftools-concat.cwl",
                    "hints": [
                        {
                            "ramMin": 60000,
                            "coresMin": 8,
                            "tmpdirMin": 1000,
                            "class": "ResourceRequirement"
                        },
                        {
                            "keep_cache": 32768,
                            "class": "http://arvados.org/cwl#RuntimeConstraints"
                        }
                    ],
                    "in": [
                        {
                            "source": "#gatk-4.0.0.0-joint-calling.cwl/output_filename",
                            "id": "#gatk-4.0.0.0-joint-calling.cwl/concat_multisample_gvcfs/filename"
                        },
                        {
                            "valueFrom": "z",
                            "id": "#gatk-4.0.0.0-joint-calling.cwl/concat_multisample_gvcfs/output_type"
                        },
                        {
                            "default": 8,
                            "id": "#gatk-4.0.0.0-joint-calling.cwl/concat_multisample_gvcfs/threads"
                        },
                        {
                            "source": "#gatk-4.0.0.0-joint-calling.cwl/flatten-multisample-gvcf-outputs/flattened_array",
                            "id": "#gatk-4.0.0.0-joint-calling.cwl/concat_multisample_gvcfs/vcfs"
                        }
                    ],
                    "out": [
                        "#gatk-4.0.0.0-joint-calling.cwl/concat_multisample_gvcfs/output"
                    ]
                },
                {
                    "id": "#gatk-4.0.0.0-joint-calling.cwl/index_multisample_gvcfs_csi",
                    "run": "#bcftools-index.cwl",
                    "hints": [
                        {
                            "coresMin": 8,
                            "ramMin": 4000,
                            "tmpdirMin": 1000,
                            "class": "ResourceRequirement"
                        }
                    ],
                    "in": [
                        {
                            "source": "#gatk-4.0.0.0-joint-calling.cwl/concat_multisample_gvcfs/output",
                            "valueFrom": "$(self.basename).csi",
                            "id": "#gatk-4.0.0.0-joint-calling.cwl/index_multisample_gvcfs_csi/output_filename"
                        },
                        {
                            "default": 8,
                            "id": "#gatk-4.0.0.0-joint-calling.cwl/index_multisample_gvcfs_csi/threads"
                        },
                        {
                            "source": "#gatk-4.0.0.0-joint-calling.cwl/concat_multisample_gvcfs/output",
                            "id": "#gatk-4.0.0.0-joint-calling.cwl/index_multisample_gvcfs_csi/vcf"
                        }
                    ],
                    "out": [
                        "#gatk-4.0.0.0-joint-calling.cwl/index_multisample_gvcfs_csi/index"
                    ]
                },
                {
                    "id": "#gatk-4.0.0.0-joint-calling.cwl/index_multisample_gvcfs_tbi",
                    "run": "#bcftools-index-tbi.cwl",
                    "hints": [
                        {
                            "coresMin": 8,
                            "ramMin": 4000,
                            "tmpdirMin": 1000,
                            "class": "ResourceRequirement"
                        }
                    ],
                    "in": [
                        {
                            "source": "#gatk-4.0.0.0-joint-calling.cwl/concat_multisample_gvcfs/output",
                            "valueFrom": "$(self.basename).tbi",
                            "id": "#gatk-4.0.0.0-joint-calling.cwl/index_multisample_gvcfs_tbi/output_filename"
                        },
                        {
                            "default": 8,
                            "id": "#gatk-4.0.0.0-joint-calling.cwl/index_multisample_gvcfs_tbi/threads"
                        },
                        {
                            "source": "#gatk-4.0.0.0-joint-calling.cwl/concat_multisample_gvcfs/output",
                            "id": "#gatk-4.0.0.0-joint-calling.cwl/index_multisample_gvcfs_tbi/vcf"
                        }
                    ],
                    "out": [
                        "#gatk-4.0.0.0-joint-calling.cwl/index_multisample_gvcfs_tbi/index"
                    ]
                },
                {
                    "id": "#gatk-4.0.0.0-joint-calling.cwl/combine_multisample_gvcf_indices",
                    "run": "#combine_files.cwl",
                    "in": [
                        {
                            "source": "#gatk-4.0.0.0-joint-calling.cwl/concat_multisample_gvcfs/output",
                            "id": "#gatk-4.0.0.0-joint-calling.cwl/combine_multisample_gvcf_indices/main_file"
                        },
                        {
                            "source": [
                                "#gatk-4.0.0.0-joint-calling.cwl/index_multisample_gvcfs_csi/index",
                                "#gatk-4.0.0.0-joint-calling.cwl/index_multisample_gvcfs_tbi/index"
                            ],
                            "id": "#gatk-4.0.0.0-joint-calling.cwl/combine_multisample_gvcf_indices/secondary_files"
                        }
                    ],
                    "out": [
                        "#gatk-4.0.0.0-joint-calling.cwl/combine_multisample_gvcf_indices/file_with_secondary_files"
                    ]
                }
            ],
            "outputs": [
                {
                    "id": "#gatk-4.0.0.0-joint-calling.cwl/out",
                    "type": "File",
                    "outputSource": "#gatk-4.0.0.0-joint-calling.cwl/combine_multisample_gvcf_indices/file_with_secondary_files"
                }
            ],
            "id": "#gatk-4.0.0.0-joint-calling.cwl"
        },
        {
            "class": "Workflow",
            "requirements": [
                {
                    "class": "SubworkflowFeatureRequirement"
                },
                {
                    "class": "StepInputExpressionRequirement"
                },
                {
                    "class": "ScatterFeatureRequirement"
                },
                {
                    "class": "MultipleInputFeatureRequirement"
                }
            ],
            "hints": [
                {
                    "ramMin": 4000,
                    "coresMin": 1,
                    "tmpdirMin": 1000,
                    "class": "ResourceRequirement"
                },
                {
                    "outputTTL": 2592000,
                    "class": "http://arvados.org/cwl#IntermediateOutput"
                },
                {
                    "keep_cache": 1024,
                    "outputDirType": "keep_output_dir",
                    "class": "http://arvados.org/cwl#RuntimeConstraints"
                },
                {
                    "loadListing": "no_listing",
                    "class": "http://commonwl.org/cwltool#LoadListingRequirement"
                }
            ],
            "inputs": [
                {
                    "id": "#gatk-4.0.0.0-library-cram-to-gvcfs.cwl/library_cram",
                    "type": "File"
                },
                {
                    "id": "#gatk-4.0.0.0-library-cram-to-gvcfs.cwl/chunks",
                    "type": "int"
                },
                {
                    "id": "#gatk-4.0.0.0-library-cram-to-gvcfs.cwl/intersect_file",
                    "type": "File"
                },
                {
                    "id": "#gatk-4.0.0.0-library-cram-to-gvcfs.cwl/ref_fasta_files",
                    "type": {
                        "type": "array",
                        "items": "File"
                    }
                },
                {
                    "id": "#gatk-4.0.0.0-library-cram-to-gvcfs.cwl/haploid_chromosome_regex",
                    "type": "string",
                    "default": "^(chr)?Y$"
                },
                {
                    "id": "#gatk-4.0.0.0-library-cram-to-gvcfs.cwl/pcr_free",
                    "type": "boolean",
                    "default": true
                }
            ],
            "steps": [
                {
                    "id": "#gatk-4.0.0.0-library-cram-to-gvcfs.cwl/cram_get_fasta",
                    "run": "#cram-get-fasta.cwl",
                    "in": [
                        {
                            "source": "#gatk-4.0.0.0-library-cram-to-gvcfs.cwl/library_cram",
                            "id": "#gatk-4.0.0.0-library-cram-to-gvcfs.cwl/cram_get_fasta/input_cram"
                        },
                        {
                            "source": "#gatk-4.0.0.0-library-cram-to-gvcfs.cwl/ref_fasta_files",
                            "id": "#gatk-4.0.0.0-library-cram-to-gvcfs.cwl/cram_get_fasta/ref_fasta_files"
                        }
                    ],
                    "out": [
                        "#gatk-4.0.0.0-library-cram-to-gvcfs.cwl/cram_get_fasta/reference_fasta",
                        "#gatk-4.0.0.0-library-cram-to-gvcfs.cwl/cram_get_fasta/reference_dict"
                    ]
                },
                {
                    "id": "#gatk-4.0.0.0-library-cram-to-gvcfs.cwl/cap_crams",
                    "run": "#capmq.cwl_2",
                    "in": [
                        {
                            "source": "#gatk-4.0.0.0-library-cram-to-gvcfs.cwl/library_cram",
                            "id": "#gatk-4.0.0.0-library-cram-to-gvcfs.cwl/cap_crams/library_cram"
                        },
                        {
                            "source": "#gatk-4.0.0.0-library-cram-to-gvcfs.cwl/cram_get_fasta/reference_fasta",
                            "id": "#gatk-4.0.0.0-library-cram-to-gvcfs.cwl/cap_crams/reference_fasta"
                        }
                    ],
                    "out": [
                        "#gatk-4.0.0.0-library-cram-to-gvcfs.cwl/cap_crams/capped_file"
                    ]
                },
                {
                    "id": "#gatk-4.0.0.0-library-cram-to-gvcfs.cwl/haplotype_caller_diploid",
                    "run": "#gatk-4.0.0.0-haplotypecaller.cwl",
                    "in": [
                        {
                            "source": "#gatk-4.0.0.0-library-cram-to-gvcfs.cwl/chunks",
                            "id": "#gatk-4.0.0.0-library-cram-to-gvcfs.cwl/haplotype_caller_diploid/chunks"
                        },
                        {
                            "source": "#gatk-4.0.0.0-library-cram-to-gvcfs.cwl/intersect_file",
                            "id": "#gatk-4.0.0.0-library-cram-to-gvcfs.cwl/haplotype_caller_diploid/intersect_file"
                        },
                        {
                            "source": "#gatk-4.0.0.0-library-cram-to-gvcfs.cwl/cap_crams/capped_file",
                            "id": "#gatk-4.0.0.0-library-cram-to-gvcfs.cwl/haplotype_caller_diploid/library_cram"
                        },
                        {
                            "source": "#gatk-4.0.0.0-library-cram-to-gvcfs.cwl/pcr_free",
                            "id": "#gatk-4.0.0.0-library-cram-to-gvcfs.cwl/haplotype_caller_diploid/pcr_free"
                        },
                        {
                            "default": 2,
                            "id": "#gatk-4.0.0.0-library-cram-to-gvcfs.cwl/haplotype_caller_diploid/ploidy"
                        },
                        {
                            "source": "#gatk-4.0.0.0-library-cram-to-gvcfs.cwl/cram_get_fasta/reference_dict",
                            "id": "#gatk-4.0.0.0-library-cram-to-gvcfs.cwl/haplotype_caller_diploid/reference_dict"
                        },
                        {
                            "source": "#gatk-4.0.0.0-library-cram-to-gvcfs.cwl/cram_get_fasta/reference_fasta",
                            "id": "#gatk-4.0.0.0-library-cram-to-gvcfs.cwl/haplotype_caller_diploid/reference_fasta"
                        }
                    ],
                    "out": [
                        "#gatk-4.0.0.0-library-cram-to-gvcfs.cwl/haplotype_caller_diploid/gvcf_files",
                        "#gatk-4.0.0.0-library-cram-to-gvcfs.cwl/haplotype_caller_diploid/intervals"
                    ]
                },
                {
                    "id": "#gatk-4.0.0.0-library-cram-to-gvcfs.cwl/haplotype_caller_haploid",
                    "run": "#gatk-4.0.0.0-haplotypecaller.cwl",
                    "in": [
                        {
                            "default": 1,
                            "id": "#gatk-4.0.0.0-library-cram-to-gvcfs.cwl/haplotype_caller_haploid/chunks"
                        },
                        {
                            "source": "#gatk-4.0.0.0-library-cram-to-gvcfs.cwl/haploid_chromosome_regex",
                            "id": "#gatk-4.0.0.0-library-cram-to-gvcfs.cwl/haplotype_caller_haploid/include_chromosome_regex"
                        },
                        {
                            "source": "#gatk-4.0.0.0-library-cram-to-gvcfs.cwl/intersect_file",
                            "id": "#gatk-4.0.0.0-library-cram-to-gvcfs.cwl/haplotype_caller_haploid/intersect_file"
                        },
                        {
                            "source": "#gatk-4.0.0.0-library-cram-to-gvcfs.cwl/cap_crams/capped_file",
                            "id": "#gatk-4.0.0.0-library-cram-to-gvcfs.cwl/haplotype_caller_haploid/library_cram"
                        },
                        {
                            "source": "#gatk-4.0.0.0-library-cram-to-gvcfs.cwl/pcr_free",
                            "id": "#gatk-4.0.0.0-library-cram-to-gvcfs.cwl/haplotype_caller_haploid/pcr_free"
                        },
                        {
                            "default": 1,
                            "id": "#gatk-4.0.0.0-library-cram-to-gvcfs.cwl/haplotype_caller_haploid/ploidy"
                        },
                        {
                            "source": "#gatk-4.0.0.0-library-cram-to-gvcfs.cwl/cram_get_fasta/reference_dict",
                            "id": "#gatk-4.0.0.0-library-cram-to-gvcfs.cwl/haplotype_caller_haploid/reference_dict"
                        },
                        {
                            "source": "#gatk-4.0.0.0-library-cram-to-gvcfs.cwl/cram_get_fasta/reference_fasta",
                            "id": "#gatk-4.0.0.0-library-cram-to-gvcfs.cwl/haplotype_caller_haploid/reference_fasta"
                        }
                    ],
                    "out": [
                        "#gatk-4.0.0.0-library-cram-to-gvcfs.cwl/haplotype_caller_haploid/gvcf_files",
                        "#gatk-4.0.0.0-library-cram-to-gvcfs.cwl/haplotype_caller_haploid/intervals"
                    ]
                }
            ],
            "outputs": [
                {
                    "id": "#gatk-4.0.0.0-library-cram-to-gvcfs.cwl/gvcf_files_diploid",
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "linkMerge": "merge_flattened",
                    "outputSource": [
                        "#gatk-4.0.0.0-library-cram-to-gvcfs.cwl/haplotype_caller_diploid/gvcf_files"
                    ]
                },
                {
                    "id": "#gatk-4.0.0.0-library-cram-to-gvcfs.cwl/intervals_diploid",
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "linkMerge": "merge_flattened",
                    "outputSource": [
                        "#gatk-4.0.0.0-library-cram-to-gvcfs.cwl/haplotype_caller_diploid/intervals"
                    ]
                },
                {
                    "id": "#gatk-4.0.0.0-library-cram-to-gvcfs.cwl/gvcf_files_haploid",
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "linkMerge": "merge_flattened",
                    "outputSource": [
                        "#gatk-4.0.0.0-library-cram-to-gvcfs.cwl/haplotype_caller_haploid/gvcf_files"
                    ]
                },
                {
                    "id": "#gatk-4.0.0.0-library-cram-to-gvcfs.cwl/intervals_haploid",
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "linkMerge": "merge_flattened",
                    "outputSource": [
                        "#gatk-4.0.0.0-library-cram-to-gvcfs.cwl/haplotype_caller_haploid/intervals"
                    ]
                },
                {
                    "id": "#gatk-4.0.0.0-library-cram-to-gvcfs.cwl/reference",
                    "type": "File",
                    "outputSource": "#gatk-4.0.0.0-library-cram-to-gvcfs.cwl/cram_get_fasta/reference_fasta"
                }
            ],
            "id": "#gatk-4.0.0.0-library-cram-to-gvcfs.cwl"
        },
        {
            "class": "Workflow",
            "inputs": [
                {
                    "id": "#intersect_intervals.cwl/interval_list_A",
                    "type": "File"
                },
                {
                    "id": "#intersect_intervals.cwl/interval_list_B",
                    "type": "File"
                }
            ],
            "steps": [
                {
                    "id": "#intersect_intervals.cwl/interval_list_to_bed_A",
                    "run": "#interval_list_to_bed.cwl",
                    "in": [
                        {
                            "source": "#intersect_intervals.cwl/interval_list_A",
                            "id": "#intersect_intervals.cwl/interval_list_to_bed_A/input"
                        }
                    ],
                    "out": [
                        "#intersect_intervals.cwl/interval_list_to_bed_A/bed_file",
                        "#intersect_intervals.cwl/interval_list_to_bed_A/header"
                    ]
                },
                {
                    "id": "#intersect_intervals.cwl/interval_list_to_bed_B",
                    "run": "#interval_list_to_bed.cwl",
                    "in": [
                        {
                            "source": "#intersect_intervals.cwl/interval_list_B",
                            "id": "#intersect_intervals.cwl/interval_list_to_bed_B/input"
                        }
                    ],
                    "out": [
                        "#intersect_intervals.cwl/interval_list_to_bed_B/bed_file",
                        "#intersect_intervals.cwl/interval_list_to_bed_B/header"
                    ]
                },
                {
                    "id": "#intersect_intervals.cwl/intersect",
                    "run": "#bedtools-intersect.cwl",
                    "in": [
                        {
                            "source": "#intersect_intervals.cwl/interval_list_to_bed_A/bed_file",
                            "id": "#intersect_intervals.cwl/intersect/a"
                        },
                        {
                            "source": "#intersect_intervals.cwl/interval_list_to_bed_B/bed_file",
                            "id": "#intersect_intervals.cwl/intersect/b"
                        }
                    ],
                    "out": [
                        "#intersect_intervals.cwl/intersect/intersect_output"
                    ]
                },
                {
                    "id": "#intersect_intervals.cwl/bed_to_interval_list",
                    "run": "#bed_to_interval_list.cwl",
                    "in": [
                        {
                            "source": "#intersect_intervals.cwl/interval_list_to_bed_A/header",
                            "id": "#intersect_intervals.cwl/bed_to_interval_list/header"
                        },
                        {
                            "source": "#intersect_intervals.cwl/intersect/intersect_output",
                            "id": "#intersect_intervals.cwl/bed_to_interval_list/input"
                        }
                    ],
                    "out": [
                        "#intersect_intervals.cwl/bed_to_interval_list/interval_list"
                    ]
                }
            ],
            "outputs": [
                {
                    "id": "#intersect_intervals.cwl/intersected_interval_list",
                    "type": "File",
                    "outputSource": "#intersect_intervals.cwl/bed_to_interval_list/interval_list"
                }
            ],
            "id": "#intersect_intervals.cwl"
        }
    ],
    "cwlVersion": "v1.0",
    "$namespaces": {
        "arv": "http://arvados.org/cwl#",
        "cwltool": "http://commonwl.org/cwltool#"
    }
}
